/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "AnnotatedSentence.AnnotatedWord",
        "sources": [
            "AnnotatedSentence/AnnotatedWord.pyx"
        ]
    },
    "module_name": "AnnotatedSentence.AnnotatedWord"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__AnnotatedSentence__AnnotatedWord
#define __PYX_HAVE_API__AnnotatedSentence__AnnotatedWord
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "AnnotatedSentence/AnnotatedWord.pyx",
  "stringsource",
  "DependencyRelation.pxd",
  "ParserEvaluationScore.pxd",
  "UniversalDependencyRelation.pxd",
  "FrameElement.pxd",
  "InflectionalGroup.pxd",
  "MorphologicalParse.pxd",
  "MetamorphicParse.pxd",
  "Gazetteer.pxd",
  "Slot.pxd",
  "Argument.pxd",
  "State.pxd",
  "FsmParse.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation;
struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore;
struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation;
struct __pyx_obj_10Dictionary_4Word_Word;
struct __pyx_obj_8FrameNet_12FrameElement_FrameElement;
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;
struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse;
struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer;
struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot;
struct __pyx_obj_8PropBank_8Argument_Argument;
struct __pyx_obj_21MorphologicalAnalysis_5State_State;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse;
struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord;

/* "DependencyParser/DependencyRelation.pxd":1
 * cdef class DependencyRelation:             # <<<<<<<<<<<<<<
 * 
 *     cdef int to_word
 */
struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation {
  PyObject_HEAD
  struct __pyx_vtabstruct_16DependencyParser_18DependencyRelation_DependencyRelation *__pyx_vtab;
  int to_word;
};


/* "DependencyParser/ParserEvaluationScore.pxd":1
 * cdef class ParserEvaluationScore:             # <<<<<<<<<<<<<<
 * 
 *     cdef float LAS
 */
struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore {
  PyObject_HEAD
  struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *__pyx_vtab;
  float LAS;
  float UAS;
  float LS;
  int word_count;
};


/* "DependencyParser/Universal/UniversalDependencyRelation.pxd":4
 * from DependencyParser.ParserEvaluationScore cimport ParserEvaluationScore
 * 
 * cdef class UniversalDependencyRelation(DependencyRelation):             # <<<<<<<<<<<<<<
 * 
 *     cdef object __universal_dependency_type
 */
struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation {
  struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation __pyx_base;
  PyObject *__pyx___universal_dependency_type;
};


/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_10Dictionary_4Word_Word {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtab;
  PyObject *name;
};


/* "FrameNet/FrameElement.pxd":1
 * cdef class FrameElement(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __frameElementType
 */
struct __pyx_obj_8FrameNet_12FrameElement_FrameElement {
  PyObject_HEAD
  struct __pyx_vtabstruct_8FrameNet_12FrameElement_FrameElement *__pyx_vtab;
  PyObject *__pyx___frameElementType;
  PyObject *__pyx___frame;
  PyObject *__pyx___id;
};


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtab;
  PyObject *__pyx___IG;
};


/* "MorphologicalAnalysis/MorphologicalParse.pxd":6
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectional_groups
 */
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtab;
  PyObject *inflectional_groups;
  struct __pyx_obj_10Dictionary_4Word_Word *root;
};


/* "MorphologicalAnalysis/MetamorphicParse.pxd":6
 * 
 * 
 * cdef class MetamorphicParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __meta_morpheme_list
 */
struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_vtab;
  PyObject *__pyx___meta_morpheme_list;
  struct __pyx_obj_10Dictionary_4Word_Word *__pyx___root;
};


/* "NamedEntityRecognition/Gazetteer.pxd":1
 * cdef class Gazetteer:             # <<<<<<<<<<<<<<
 * 
 *     cdef set __data
 */
struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer {
  PyObject_HEAD
  struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer *__pyx_vtab;
  PyObject *__pyx___data;
  PyObject *__pyx___name;
};


/* "NamedEntityRecognition/Slot.pxd":1
 * cdef class Slot:             # <<<<<<<<<<<<<<
 * 
 *     cdef object type
 */
struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot {
  PyObject_HEAD
  struct __pyx_vtabstruct_22NamedEntityRecognition_4Slot_Slot *__pyx_vtab;
  PyObject *type;
  PyObject *tag;
};


/* "PropBank/Argument.pxd":1
 * cdef class Argument(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __argumentType
 */
struct __pyx_obj_8PropBank_8Argument_Argument {
  PyObject_HEAD
  struct __pyx_vtabstruct_8PropBank_8Argument_Argument *__pyx_vtab;
  PyObject *__pyx___argumentType;
  PyObject *__pyx___id;
};


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __start_state, __end_state
 */
struct __pyx_obj_21MorphologicalAnalysis_5State_State {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtab;
  int __pyx___start_state;
  int __pyx___end_state;
  PyObject *__pyx___name;
  PyObject *__pyx___pos;
};


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffix_list
 */
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *__pyx___suffix_list;
  PyObject *__pyx___form_list;
  PyObject *__pyx___transition_list;
  PyObject *__pyx___with_list;
  PyObject *__pyx___initial_pos;
  PyObject *__pyx___pos;
  PyObject *__pyx___form;
  PyObject *__pyx___verb_agreement;
  PyObject *__pyx___possesive_agreement;
};


/* "AnnotatedSentence/AnnotatedWord.pxd":11
 * 
 * 
 * cdef class AnnotatedWord(Word):             # <<<<<<<<<<<<<<
 *     """
 *      * In order to add another layer, do the following:
 */
struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord {
  struct __pyx_obj_10Dictionary_4Word_Word __pyx_base;
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx___parse;
  struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx___metamorphic_parse;
  PyObject *__pyx___semantic;
  PyObject *__pyx___named_entity_type;
  struct __pyx_obj_8PropBank_8Argument_Argument *__pyx___argument;
  struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *__pyx___frame_element;
  PyObject *__pyx___shallow_parse;
  struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *__pyx___universal_dependency;
  struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *__pyx___slot;
  PyObject *__pyx___polarity;
  PyObject *__pyx___ccg;
  PyObject *__pyx___pos_tag;
  PyObject *__pyx___language;
};



/* "DependencyParser/DependencyRelation.pxd":1
 * cdef class DependencyRelation:             # <<<<<<<<<<<<<<
 * 
 *     cdef int to_word
 */

struct __pyx_vtabstruct_16DependencyParser_18DependencyRelation_DependencyRelation {
  int (*to)(struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_16DependencyParser_18DependencyRelation_DependencyRelation *__pyx_vtabptr_16DependencyParser_18DependencyRelation_DependencyRelation;


/* "DependencyParser/ParserEvaluationScore.pxd":1
 * cdef class ParserEvaluationScore:             # <<<<<<<<<<<<<<
 * 
 *     cdef float LAS
 */

struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore {
  float (*getLS)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  float (*getLAS)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  float (*getUAS)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  int (*getWordCount)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
  PyObject *(*add)(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *__pyx_vtabptr_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore;


/* "DependencyParser/Universal/UniversalDependencyRelation.pxd":4
 * from DependencyParser.ParserEvaluationScore cimport ParserEvaluationScore
 * 
 * cdef class UniversalDependencyRelation(DependencyRelation):             # <<<<<<<<<<<<<<
 * 
 *     cdef object __universal_dependency_type
 */

struct __pyx_vtabstruct_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation {
  struct __pyx_vtabstruct_16DependencyParser_18DependencyRelation_DependencyRelation __pyx_base;
  struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore *(*compareRelations)(struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *, struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *__pyx_vtabptr_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation;


/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_10Dictionary_4Word_Word {
  int (*charCount)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_10Dictionary_4Word_Word *, PyObject *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*toCharacters)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtabptr_10Dictionary_4Word_Word;


/* "FrameNet/FrameElement.pxd":1
 * cdef class FrameElement(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __frameElementType
 */

struct __pyx_vtabstruct_8FrameNet_12FrameElement_FrameElement {
  PyObject *(*initWithId)(struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getFrameElementType)(struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *, int __pyx_skip_dispatch);
  PyObject *(*getFrame)(struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *, int __pyx_skip_dispatch);
  PyObject *(*getId)(struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8FrameNet_12FrameElement_FrameElement *__pyx_vtabptr_8FrameNet_12FrameElement_FrameElement;


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  PyObject *(*containsCase)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsPlural)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, PyObject *, int __pyx_skip_dispatch);
  int (*containsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;


/* "MorphologicalAnalysis/MorphologicalParse.pxd":6
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectional_groups
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTransitionList)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getInflectionalGroupString)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getLastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  int (*tagSize)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*firstInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*lastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWordWithPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getRootPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*lastIGContainsCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*lastIGContainsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*lastIGContainsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCapitalWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRootVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCardinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isHashTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isEmail)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAuxiliary)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getTreePos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPronType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getReflex)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDefinite)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDegree)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPolarity)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPerson)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVoice)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getAspect)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTense)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getMood)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbForm)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyFeatures)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;


/* "MorphologicalAnalysis/MetamorphicParse.pxd":6
 * 
 * 
 * cdef class MetamorphicParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __meta_morpheme_list
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse {
  PyObject *(*getMetaMorphemeTag)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  PyObject *(*getMetaMorphemeTagForParse)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int __pyx_skip_dispatch);
  PyObject *(*addMetaMorphemeList)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeMetaMorphemeFromIndex)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int, int __pyx_skip_dispatch);
  PyObject *(*getMetaMorpheme)(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse;


/* "NamedEntityRecognition/Gazetteer.pxd":1
 * cdef class Gazetteer:             # <<<<<<<<<<<<<<
 * 
 *     cdef set __data
 */

struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer {
  PyObject *(*getName)(struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *, int __pyx_skip_dispatch);
  int (*contains)(struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer *__pyx_vtabptr_22NamedEntityRecognition_9Gazetteer_Gazetteer;


/* "NamedEntityRecognition/Slot.pxd":1
 * cdef class Slot:             # <<<<<<<<<<<<<<
 * 
 *     cdef object type
 */

struct __pyx_vtabstruct_22NamedEntityRecognition_4Slot_Slot {
  PyObject *(*getType)(struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *, int __pyx_skip_dispatch);
  PyObject *(*getTag)(struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_22NamedEntityRecognition_4Slot_Slot *__pyx_vtabptr_22NamedEntityRecognition_4Slot_Slot;


/* "PropBank/Argument.pxd":1
 * cdef class Argument(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef str __argumentType
 */

struct __pyx_vtabstruct_8PropBank_8Argument_Argument {
  PyObject *(*initWithId)(struct __pyx_obj_8PropBank_8Argument_Argument *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getArgumentType)(struct __pyx_obj_8PropBank_8Argument_Argument *, int __pyx_skip_dispatch);
  PyObject *(*getId)(struct __pyx_obj_8PropBank_8Argument_Argument *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_8PropBank_8Argument_Argument *__pyx_vtabptr_8PropBank_8Argument_Argument;


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __start_state, __end_state
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State {
  PyObject *(*getName)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  int (*isEndState)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtabptr_21MorphologicalAnalysis_5State_State;


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffix_list
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *(*constructInflectionalGroups)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getPossesiveAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemmaWithTag)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemma)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*addSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSurfaceForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getStartState)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getFinalPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getInitialPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getFinalSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*headerTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*pronounTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*transitionList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*suffixList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*withList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getWithList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse;


/* "AnnotatedSentence/AnnotatedWord.pyx":11
 * 
 * 
 * cdef class AnnotatedWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self,
 */

struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord {
  struct __pyx_vtabstruct_10Dictionary_4Word_Word __pyx_base;
  PyObject *(*getLayerInfo)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *(*getParse)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setParse)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *(*getMetamorphicParse)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setMetamorphicParse)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSemantic)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setSemantic)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getNamedEntityType)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setNamedEntityType)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_8PropBank_8Argument_Argument *(*getArgument)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setArgument)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *(*getFrameElement)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setFrameElement)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *(*getSlot)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setSlot)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getPolarity)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*getPolarityString)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setPolarity)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getShallowParse)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setShallowParse)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getCcg)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setCcg)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getPosTag)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setPosTag)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *(*getUniversalDependency)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
  PyObject *(*setUniversalDependency)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyFormat)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int, int __pyx_skip_dispatch);
  PyObject *(*getFormattedString)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*checkGazetteer)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *, int __pyx_skip_dispatch);
  PyObject *(*getLanguage)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_vtabptr_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyUnicode_Substring.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_dealloc);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLayerInfo(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_viewLayerType, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_semantic, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_namedEntity, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_8PropBank_8Argument_Argument *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_argument, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_frameElement, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_slot, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarityString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_polarity, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parse, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_ccg, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_posTag, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_to, PyObject *__pyx_v_dependencyType, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependencyFormat(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_sentenceLength, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFormattedString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_wordFormat, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_checkGazetteer(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *__pyx_v_gazetteer, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLanguage(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'DependencyParser.DependencyRelation' */
static PyTypeObject *__pyx_ptype_16DependencyParser_18DependencyRelation_DependencyRelation = 0;

/* Module declarations from 'DependencyParser.ParserEvaluationScore' */
static PyTypeObject *__pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore = 0;

/* Module declarations from 'DependencyParser.Universal.UniversalDependencyRelation' */
static PyTypeObject *__pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation = 0;

/* Module declarations from 'Dictionary.Word' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Word_Word = 0;

/* Module declarations from 'FrameNet.FrameElement' */
static PyTypeObject *__pyx_ptype_8FrameNet_12FrameElement_FrameElement = 0;

/* Module declarations from 'MorphologicalAnalysis.InflectionalGroup' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = 0;

/* Module declarations from 'MorphologicalAnalysis.MorphologicalParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = 0;

/* Module declarations from 'MorphologicalAnalysis.MetamorphicParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = 0;

/* Module declarations from 'NamedEntityRecognition.Gazetteer' */
static PyTypeObject *__pyx_ptype_22NamedEntityRecognition_9Gazetteer_Gazetteer = 0;

/* Module declarations from 'NamedEntityRecognition.Slot' */
static PyTypeObject *__pyx_ptype_22NamedEntityRecognition_4Slot_Slot = 0;

/* Module declarations from 'PropBank.Argument' */
static PyTypeObject *__pyx_ptype_8PropBank_8Argument_Argument = 0;

/* Module declarations from 'MorphologicalAnalysis.State' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_5State_State = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = 0;

/* Module declarations from 'AnnotatedSentence.AnnotatedWord' */
static PyTypeObject *__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord = 0;
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord___pyx_unpickle_AnnotatedWord__set_state(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "AnnotatedSentence.AnnotatedWord"
extern int __pyx_module_is_main_AnnotatedSentence__AnnotatedWord;
int __pyx_module_is_main_AnnotatedSentence__AnnotatedWord = 0;

/* Implementation of 'AnnotatedSentence.AnnotatedWord' */
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_super;
static const char __pyx_k_[] = "[{}]";
static const char __pyx_k__2[] = "=";
static const char __pyx_k__3[] = "$";
static const char __pyx_k__5[] = "";
static const char __pyx_k__6[] = "}";
static const char __pyx_k__7[] = "\t";
static const char __pyx_k__8[] = "\t_\t";
static const char __pyx_k__9[] = "_";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_to[] = "to";
static const char __pyx_k_CCG[] = "CCG";
static const char __pyx_k_NER[] = "NER";
static const char __pyx_k__10[] = "|";
static const char __pyx_k__11[] = "_\t_\t";
static const char __pyx_k__12[] = "_\t_";
static const char __pyx_k__13[] = "\t_\t_\t_\t_\t_\t_\t_";
static const char __pyx_k__14[] = "'";
static const char __pyx_k_ccg[] = "ccg";
static const char __pyx_k_neg[] = "neg";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pos[] = "pos";
static const char __pyx_k_str[] = "__str__";
static const char __pyx_k_NONE[] = "NONE";
static const char __pyx_k_SLOT[] = "SLOT";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_slot[] = "slot";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_word[] = "word";
static const char __pyx_k_ccg_2[] = "{ccg=";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_getCcg[] = "getCcg";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_posTag[] = "posTag";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_setCcg[] = "setCcg";
static const char __pyx_k_slot_2[] = "{slot=";
  static const char __pyx_k_update[] = "update";
  static const char __pyx_k_ENGLISH[] = "ENGLISH";
  static const char __pyx_k_English[] = "English";
  static const char __pyx_k_NEUTRAL[] = "NEUTRAL";
  static const char __pyx_k_PERSIAN[] = "PERSIAN";
  static const char __pyx_k_POS_TAG[] = "POS_TAG";
  static const char __pyx_k_Persian[] = "Persian";
  static const char __pyx_k_SURFACE[] = "SURFACE";
  static const char __pyx_k_TURKISH[] = "TURKISH";
  static const char __pyx_k_Turkish[] = "Turkish";
  static const char __pyx_k_compile[] = "compile";
  static const char __pyx_k_english[] = "english";
  static const char __pyx_k_getSlot[] = "getSlot";
  static const char __pyx_k_neutral[] = "neutral";
  static const char __pyx_k_persian[] = "persian";
  static const char __pyx_k_setSlot[] = "setSlot";
  static const char __pyx_k_turkish[] = "turkish";
  static const char __pyx_k_FRAMENET[] = "FRAMENET";
  static const char __pyx_k_Language[] = "Language";
  static const char __pyx_k_NEGATIVE[] = "NEGATIVE";
  static const char __pyx_k_POLARITY[] = "POLARITY";
  static const char __pyx_k_POSITIVE[] = "POSITIVE";
  static const char __pyx_k_PROPBANK[] = "PROPBANK";
  static const char __pyx_k_frameNet[] = "frameNet";
  static const char __pyx_k_framenet[] = "framenet";
  static const char __pyx_k_getParse[] = "getParse";
  static const char __pyx_k_getstate[] = "__getstate__";
  static const char __pyx_k_negative[] = "negative";
  static const char __pyx_k_polarity[] = "polarity";
  static const char __pyx_k_posTag_2[] = "{posTag=";
    static const char __pyx_k_positive[] = "positive";
    static const char __pyx_k_propBank[] = "propBank";
    static const char __pyx_k_propbank[] = "propbank";
    static const char __pyx_k_pyx_type[] = "__pyx_type";
    static const char __pyx_k_setParse[] = "setParse";
    static const char __pyx_k_setstate[] = "__setstate__";
    static const char __pyx_k_withList[] = "withList";
    static const char __pyx_k_SEMANTICS[] = "SEMANTICS";
    static const char __pyx_k_english_2[] = "{english=";
      static const char __pyx_k_getPosTag[] = "getPosTag";
      static const char __pyx_k_layerType[] = "layerType";
      static const char __pyx_k_persian_2[] = "{persian=";
        static const char __pyx_k_pyx_state[] = "__pyx_state";
        static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
        static const char __pyx_k_semantics[] = "semantics";
        static const char __pyx_k_setPosTag[] = "setPosTag";
        static const char __pyx_k_turkish_2[] = "{turkish=";
          static const char __pyx_k_DEPENDENCY[] = "DEPENDENCY";
          static const char __pyx_k_PROPERNOUN[] = "PROPERNOUN";
          static const char __pyx_k_WordFormat[] = "WordFormat";
          static const char __pyx_k_framenet_2[] = "{framenet=";
            static const char __pyx_k_polarity_2[] = "{polarity=";
              static const char __pyx_k_propbank_2[] = "{propbank=";
                static const char __pyx_k_pyx_result[] = "__pyx_result";
                static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
                static const char __pyx_k_PickleError[] = "PickleError";
                static const char __pyx_k_getArgument[] = "getArgument";
                static const char __pyx_k_getLanguage[] = "getLanguage";
                static const char __pyx_k_getPolarity[] = "getPolarity";
                static const char __pyx_k_getSemantic[] = "getSemantic";
                static const char __pyx_k_namedEntity[] = "namedEntity";
                static const char __pyx_k_semantics_2[] = "{semantics=";
                  static const char __pyx_k_setArgument[] = "setArgument";
                  static const char __pyx_k_setPolarity[] = "setPolarity";
                  static const char __pyx_k_setSemantic[] = "setSemantic";
                  static const char __pyx_k_PolarityType[] = "PolarityType";
                  static const char __pyx_k_TURKISH_WORD[] = "TURKISH_WORD";
                  static const char __pyx_k_getLayerInfo[] = "getLayerInfo";
                  static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
                  static const char __pyx_k_shallowParse[] = "shallowParse";
                  static const char __pyx_k_staticmethod[] = "staticmethod";
                  static const char __pyx_k_stringsource[] = "stringsource";
                  static const char __pyx_k_AnnotatedWord[] = "AnnotatedWord";
                  static const char __pyx_k_META_MORPHEME[] = "META_MORPHEME";
                  static const char __pyx_k_SHALLOW_PARSE[] = "SHALLOW_PARSE";
                  static const char __pyx_k_ViewLayerType[] = "ViewLayerType";
                  static const char __pyx_k_metaMorphemes[] = "metaMorphemes";
                  static const char __pyx_k_namedEntity_2[] = "{namedEntity=";
                    static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
                    static const char __pyx_k_checkGazetteer[] = "checkGazetteer";
                    static const char __pyx_k_dependencyType[] = "dependencyType";
                    static const char __pyx_k_languageString[] = "languageString";
                    static const char __pyx_k_shallowParse_2[] = "{shallowParse=";
                      static const char __pyx_k_NamedEntityType[] = "NamedEntityType";
                      static const char __pyx_k_getFrameElement[] = "getFrameElement";
                      static const char __pyx_k_getShallowParse[] = "getShallowParse";
                      static const char __pyx_k_metaMorphemes_2[] = "{metaMorphemes=";
                        static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
                        static const char __pyx_k_setFrameElement[] = "setFrameElement";
                        static const char __pyx_k_setShallowParse[] = "setShallowParse";
                        static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
                        static const char __pyx_k_MorphologicalTag[] = "MorphologicalTag";
                        static const char __pyx_k_Corpus_WordFormat[] = "Corpus.WordFormat";
                        static const char __pyx_k_getPolarityString[] = "getPolarityString";
                        static const char __pyx_k_INFLECTIONAL_GROUP[] = "INFLECTIONAL_GROUP";
                        static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
                        static const char __pyx_k_getFormattedString[] = "getFormattedString";
                        static const char __pyx_k_getNamedEntityType[] = "getNamedEntityType";
                        static const char __pyx_k_setNamedEntityType[] = "setNamedEntityType";
                        static const char __pyx_k_getMetamorphicParse[] = "getMetamorphicParse";
                        static const char __pyx_k_setMetamorphicParse[] = "setMetamorphicParse";
                        static const char __pyx_k_universalDependency[] = "universalDependency";
                        static const char __pyx_k_getNamedEntityString[] = "getNamedEntityString";
                        static const char __pyx_k_SentiNet_PolarityType[] = "SentiNet.PolarityType";
                        static const char __pyx_k_getLanguageFromString[] = "getLanguageFromString";
                        static const char __pyx_k_morphologicalAnalysis[] = "morphologicalAnalysis";
                        static const char __pyx_k_universalDependency_2[] = "{universalDependency=";
                          static const char __pyx_k_getUniversalDependency[] = "getUniversalDependency";
                          static const char __pyx_k_setUniversalDependency[] = "setUniversalDependency";
                          static const char __pyx_k_morphologicalAnalysis_2[] = "{morphologicalAnalysis=";
                            static const char __pyx_k_AnnotatedSentence_Language[] = "AnnotatedSentence.Language";
                            static const char __pyx_k_pyx_unpickle_AnnotatedWord[] = "__pyx_unpickle_AnnotatedWord";
                            static const char __pyx_k_getUniversalDependencyFormat[] = "getUniversalDependencyFormat";
                            static const char __pyx_k_AnnotatedSentence_AnnotatedWord[] = "AnnotatedSentence/AnnotatedWord.pyx";
                            static const char __pyx_k_AnnotatedSentence_ViewLayerType[] = "AnnotatedSentence.ViewLayerType";
                            static const char __pyx_k_Incompatible_checksums_s_vs_0x28[] = "Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))";
                            static const char __pyx_k_MorphologicalAnalysis_Morphologi[] = "MorphologicalAnalysis.MorphologicalTag";
                            static const char __pyx_k_NamedEntityRecognition_NamedEnti[] = "NamedEntityRecognition.NamedEntityType";
                            static const char __pyx_k_AnnotatedSentence_AnnotatedWord_2[] = "AnnotatedSentence.AnnotatedWord";
                            static PyObject *__pyx_kp_u_;
                            static PyObject *__pyx_kp_s_AnnotatedSentence_AnnotatedWord;
                            static PyObject *__pyx_n_s_AnnotatedSentence_AnnotatedWord_2;
                            static PyObject *__pyx_n_s_AnnotatedSentence_Language;
                            static PyObject *__pyx_n_s_AnnotatedSentence_ViewLayerType;
                            static PyObject *__pyx_n_s_AnnotatedWord;
                            static PyObject *__pyx_n_s_CCG;
                            static PyObject *__pyx_n_s_Corpus_WordFormat;
                            static PyObject *__pyx_n_s_DEPENDENCY;
                            static PyObject *__pyx_n_s_ENGLISH;
                            static PyObject *__pyx_n_u_English;
                            static PyObject *__pyx_n_s_FRAMENET;
                            static PyObject *__pyx_n_s_INFLECTIONAL_GROUP;
                            static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x28;
                            static PyObject *__pyx_n_s_Language;
                            static PyObject *__pyx_n_s_META_MORPHEME;
                            static PyObject *__pyx_n_s_MorphologicalAnalysis_Morphologi;
                            static PyObject *__pyx_n_s_MorphologicalTag;
                            static PyObject *__pyx_n_s_NEGATIVE;
                            static PyObject *__pyx_n_s_NER;
                            static PyObject *__pyx_n_s_NEUTRAL;
                            static PyObject *__pyx_n_s_NONE;
                            static PyObject *__pyx_n_u_NONE;
                            static PyObject *__pyx_n_s_NamedEntityRecognition_NamedEnti;
                            static PyObject *__pyx_n_s_NamedEntityType;
                            static PyObject *__pyx_n_s_PERSIAN;
                            static PyObject *__pyx_n_s_POLARITY;
                            static PyObject *__pyx_n_s_POSITIVE;
                            static PyObject *__pyx_n_s_POS_TAG;
                            static PyObject *__pyx_n_s_PROPBANK;
                            static PyObject *__pyx_n_s_PROPERNOUN;
                            static PyObject *__pyx_n_u_Persian;
                            static PyObject *__pyx_n_s_PickleError;
                            static PyObject *__pyx_n_s_PolarityType;
                            static PyObject *__pyx_n_s_SEMANTICS;
                            static PyObject *__pyx_n_s_SHALLOW_PARSE;
                            static PyObject *__pyx_n_s_SLOT;
                            static PyObject *__pyx_n_s_SURFACE;
                            static PyObject *__pyx_n_s_SentiNet_PolarityType;
                            static PyObject *__pyx_n_s_TURKISH;
                            static PyObject *__pyx_n_s_TURKISH_WORD;
                            static PyObject *__pyx_n_u_Turkish;
                            static PyObject *__pyx_n_s_ViewLayerType;
                            static PyObject *__pyx_n_s_WordFormat;
                            static PyObject *__pyx_kp_u__10;
                            static PyObject *__pyx_kp_u__11;
                            static PyObject *__pyx_kp_u__12;
                            static PyObject *__pyx_kp_u__13;
                            static PyObject *__pyx_kp_u__14;
                            static PyObject *__pyx_kp_u__2;
                            static PyObject *__pyx_kp_u__3;
                            static PyObject *__pyx_kp_u__5;
                            static PyObject *__pyx_kp_u__6;
                            static PyObject *__pyx_kp_u__7;
                            static PyObject *__pyx_kp_u__8;
                            static PyObject *__pyx_n_u__9;
                            static PyObject *__pyx_n_u_ccg;
                            static PyObject *__pyx_kp_u_ccg_2;
                            static PyObject *__pyx_n_s_checkGazetteer;
                            static PyObject *__pyx_n_s_cline_in_traceback;
                            static PyObject *__pyx_n_s_compile;
                            static PyObject *__pyx_n_s_dependencyType;
                            static PyObject *__pyx_n_s_dict;
                            static PyObject *__pyx_n_u_english;
                            static PyObject *__pyx_kp_u_english_2;
                            static PyObject *__pyx_n_u_frameNet;
                            static PyObject *__pyx_n_u_framenet;
                            static PyObject *__pyx_kp_u_framenet_2;
                            static PyObject *__pyx_n_s_getArgument;
                            static PyObject *__pyx_n_s_getCcg;
                            static PyObject *__pyx_n_s_getFormattedString;
                            static PyObject *__pyx_n_s_getFrameElement;
                            static PyObject *__pyx_n_s_getLanguage;
                            static PyObject *__pyx_n_s_getLanguageFromString;
                            static PyObject *__pyx_n_s_getLayerInfo;
                            static PyObject *__pyx_n_s_getMetamorphicParse;
                            static PyObject *__pyx_n_s_getNamedEntityString;
                            static PyObject *__pyx_n_s_getNamedEntityType;
                            static PyObject *__pyx_n_s_getParse;
                            static PyObject *__pyx_n_s_getPolarity;
                            static PyObject *__pyx_n_s_getPolarityString;
                            static PyObject *__pyx_n_s_getPosTag;
                            static PyObject *__pyx_n_s_getSemantic;
                            static PyObject *__pyx_n_s_getShallowParse;
                            static PyObject *__pyx_n_s_getSlot;
                            static PyObject *__pyx_n_s_getUniversalDependency;
                            static PyObject *__pyx_n_s_getUniversalDependencyFormat;
                            static PyObject *__pyx_n_s_getstate;
                            static PyObject *__pyx_n_s_import;
                            static PyObject *__pyx_n_s_index;
                            static PyObject *__pyx_n_s_init;
                            static PyObject *__pyx_n_s_languageString;
                            static PyObject *__pyx_n_s_layerType;
                            static PyObject *__pyx_n_s_lower;
                            static PyObject *__pyx_n_s_main;
                            static PyObject *__pyx_n_u_metaMorphemes;
                            static PyObject *__pyx_kp_u_metaMorphemes_2;
                            static PyObject *__pyx_n_u_morphologicalAnalysis;
                            static PyObject *__pyx_kp_u_morphologicalAnalysis_2;
                            static PyObject *__pyx_n_s_name;
                            static PyObject *__pyx_n_u_namedEntity;
                            static PyObject *__pyx_kp_u_namedEntity_2;
                            static PyObject *__pyx_n_u_neg;
                            static PyObject *__pyx_n_u_negative;
                            static PyObject *__pyx_n_u_neutral;
                            static PyObject *__pyx_n_s_new;
                            static PyObject *__pyx_n_u_persian;
                            static PyObject *__pyx_kp_u_persian_2;
                            static PyObject *__pyx_n_s_pickle;
                            static PyObject *__pyx_n_u_polarity;
                            static PyObject *__pyx_kp_u_polarity_2;
                            static PyObject *__pyx_n_u_pos;
                            static PyObject *__pyx_n_u_posTag;
                            static PyObject *__pyx_kp_u_posTag_2;
                            static PyObject *__pyx_n_u_positive;
                            static PyObject *__pyx_n_u_propBank;
                            static PyObject *__pyx_n_u_propbank;
                            static PyObject *__pyx_kp_u_propbank_2;
                            static PyObject *__pyx_n_s_pyx_PickleError;
                            static PyObject *__pyx_n_s_pyx_checksum;
                            static PyObject *__pyx_n_s_pyx_result;
                            static PyObject *__pyx_n_s_pyx_state;
                            static PyObject *__pyx_n_s_pyx_type;
                            static PyObject *__pyx_n_s_pyx_unpickle_AnnotatedWord;
                            static PyObject *__pyx_n_s_pyx_vtable;
                            static PyObject *__pyx_n_s_re;
                            static PyObject *__pyx_n_s_reduce;
                            static PyObject *__pyx_n_s_reduce_cython;
                            static PyObject *__pyx_n_s_reduce_ex;
                            static PyObject *__pyx_n_u_semantics;
                            static PyObject *__pyx_kp_u_semantics_2;
                            static PyObject *__pyx_n_s_setArgument;
                            static PyObject *__pyx_n_s_setCcg;
                            static PyObject *__pyx_n_s_setFrameElement;
                            static PyObject *__pyx_n_s_setMetamorphicParse;
                            static PyObject *__pyx_n_s_setNamedEntityType;
                            static PyObject *__pyx_n_s_setParse;
                            static PyObject *__pyx_n_s_setPolarity;
                            static PyObject *__pyx_n_s_setPosTag;
                            static PyObject *__pyx_n_s_setSemantic;
                            static PyObject *__pyx_n_s_setShallowParse;
                            static PyObject *__pyx_n_s_setSlot;
                            static PyObject *__pyx_n_s_setUniversalDependency;
                            static PyObject *__pyx_n_s_setstate;
                            static PyObject *__pyx_n_s_setstate_cython;
                            static PyObject *__pyx_n_u_shallowParse;
                            static PyObject *__pyx_kp_u_shallowParse_2;
                            static PyObject *__pyx_n_u_slot;
                            static PyObject *__pyx_kp_u_slot_2;
                            static PyObject *__pyx_n_s_split;
                            static PyObject *__pyx_n_s_staticmethod;
                            static PyObject *__pyx_n_s_str;
                            static PyObject *__pyx_kp_s_stringsource;
                            static PyObject *__pyx_n_s_super;
                            static PyObject *__pyx_n_s_test;
                            static PyObject *__pyx_n_s_to;
                            static PyObject *__pyx_n_u_turkish;
                            static PyObject *__pyx_kp_u_turkish_2;
                            static PyObject *__pyx_n_u_universalDependency;
                            static PyObject *__pyx_kp_u_universalDependency_2;
                            static PyObject *__pyx_n_s_update;
                            static PyObject *__pyx_n_s_withList;
                            static PyObject *__pyx_n_s_word;
static int __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_word, PyObject *__pyx_v_layerType); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_4getLayerInfo(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_viewLayerType); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_6getParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_8setParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_10getMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_12setMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_14getSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_16setSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_semantic); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_18getNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_20setNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_namedEntity); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_22getArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_24setArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_argument); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_26getFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_28setFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_frameElement); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_30getSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_32setSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_slot); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_34getPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_36getPolarityString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_38setPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_polarity); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_40getShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_42setShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parse); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_44getCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_46setCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_ccg); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_48getPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_50setPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_posTag); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_52getUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_54setUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_to, PyObject *__pyx_v_dependencyType); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_56getUniversalDependencyFormat(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_sentenceLength); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_58getFormattedString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_wordFormat); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_60checkGazetteer(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *__pyx_v_gazetteer); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_62getLanguage(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_64getLanguageFromString(PyObject *__pyx_v_languageString); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_66__reduce_cython__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_68__setstate_cython__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord___pyx_unpickle_AnnotatedWord(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_index = {0, &__pyx_n_s_index, 0, 0, 0};
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_42354475;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_codeobj__16;
static PyObject *__pyx_codeobj__18;
/* Late includes */

/* "AnnotatedSentence/AnnotatedWord.pyx":13
 * cdef class AnnotatedWord(Word):
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  word: str,
 *                  layerType=None):
 */

/* Python wrapper */
static int __pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__[] = "\n        Constructor for the AnnotatedWord class. Gets the word with its annotation layers as input and sets the\n        corresponding layers.\n\n        PARAMETERS\n        ----------\n        word : str\n            Input word with annotation layers\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__;
#endif
static int __pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_word = 0;
  PyObject *__pyx_v_layerType = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_word,&__pyx_n_s_layerType,0};
    PyObject* values[2] = {0,0};

    /* "AnnotatedSentence/AnnotatedWord.pyx":15
 *     def __init__(self,
 *                  word: str,
 *                  layerType=None):             # <<<<<<<<<<<<<<
 *         """
 *         Constructor for the AnnotatedWord class. Gets the word with its annotation layers as input and sets the
 */
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_word)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_layerType);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 13, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_word = ((PyObject*)values[0]);
    __pyx_v_layerType = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 13, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_word), (&PyUnicode_Type), 1, "word", 1))) __PYX_ERR(0, 14, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), __pyx_v_word, __pyx_v_layerType);

  /* "AnnotatedSentence/AnnotatedWord.pyx":13
 * cdef class AnnotatedWord(Word):
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  word: str,
 *                  layerType=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_word, PyObject *__pyx_v_layerType) {
  PyObject *__pyx_v_split_layers = 0;
  PyObject *__pyx_v_values = 0;
  PyObject *__pyx_v_layer = 0;
  PyObject *__pyx_v_layer_value = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_layerType);

  /* "AnnotatedSentence/AnnotatedWord.pyx":27
 *         cdef list split_layers, values
 *         cdef str layer, layer_value
 *         self.__parse = None             # <<<<<<<<<<<<<<
 *         self.__metamorphic_parse = None
 *         self.__semantic = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___parse);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___parse));
  __pyx_v_self->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":28
 *         cdef str layer, layer_value
 *         self.__parse = None
 *         self.__metamorphic_parse = None             # <<<<<<<<<<<<<<
 *         self.__semantic = None
 *         self.__named_entity_type = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___metamorphic_parse);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse));
  __pyx_v_self->__pyx___metamorphic_parse = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":29
 *         self.__parse = None
 *         self.__metamorphic_parse = None
 *         self.__semantic = None             # <<<<<<<<<<<<<<
 *         self.__named_entity_type = None
 *         self.__argument = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___semantic);
  __Pyx_DECREF(__pyx_v_self->__pyx___semantic);
  __pyx_v_self->__pyx___semantic = ((PyObject*)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":30
 *         self.__metamorphic_parse = None
 *         self.__semantic = None
 *         self.__named_entity_type = None             # <<<<<<<<<<<<<<
 *         self.__argument = None
 *         self.__frame_element = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___named_entity_type);
  __Pyx_DECREF(__pyx_v_self->__pyx___named_entity_type);
  __pyx_v_self->__pyx___named_entity_type = Py_None;

  /* "AnnotatedSentence/AnnotatedWord.pyx":31
 *         self.__semantic = None
 *         self.__named_entity_type = None
 *         self.__argument = None             # <<<<<<<<<<<<<<
 *         self.__frame_element = None
 *         self.__shallow_parse = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___argument);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___argument));
  __pyx_v_self->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":32
 *         self.__named_entity_type = None
 *         self.__argument = None
 *         self.__frame_element = None             # <<<<<<<<<<<<<<
 *         self.__shallow_parse = None
 *         self.__universal_dependency = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___frame_element);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___frame_element));
  __pyx_v_self->__pyx___frame_element = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":33
 *         self.__argument = None
 *         self.__frame_element = None
 *         self.__shallow_parse = None             # <<<<<<<<<<<<<<
 *         self.__universal_dependency = None
 *         self.__slot = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___shallow_parse);
  __Pyx_DECREF(__pyx_v_self->__pyx___shallow_parse);
  __pyx_v_self->__pyx___shallow_parse = ((PyObject*)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":34
 *         self.__frame_element = None
 *         self.__shallow_parse = None
 *         self.__universal_dependency = None             # <<<<<<<<<<<<<<
 *         self.__slot = None
 *         self.__polarity = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___universal_dependency);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___universal_dependency));
  __pyx_v_self->__pyx___universal_dependency = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":35
 *         self.__shallow_parse = None
 *         self.__universal_dependency = None
 *         self.__slot = None             # <<<<<<<<<<<<<<
 *         self.__polarity = None
 *         self.__ccg = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___slot);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___slot));
  __pyx_v_self->__pyx___slot = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":36
 *         self.__universal_dependency = None
 *         self.__slot = None
 *         self.__polarity = None             # <<<<<<<<<<<<<<
 *         self.__ccg = None
 *         self.__pos_tag = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___polarity);
  __Pyx_DECREF(__pyx_v_self->__pyx___polarity);
  __pyx_v_self->__pyx___polarity = Py_None;

  /* "AnnotatedSentence/AnnotatedWord.pyx":37
 *         self.__slot = None
 *         self.__polarity = None
 *         self.__ccg = None             # <<<<<<<<<<<<<<
 *         self.__pos_tag = None
 *         self.__language = Language.TURKISH
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___ccg);
  __Pyx_DECREF(__pyx_v_self->__pyx___ccg);
  __pyx_v_self->__pyx___ccg = ((PyObject*)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":38
 *         self.__polarity = None
 *         self.__ccg = None
 *         self.__pos_tag = None             # <<<<<<<<<<<<<<
 *         self.__language = Language.TURKISH
 *         if layerType is None:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___pos_tag);
  __Pyx_DECREF(__pyx_v_self->__pyx___pos_tag);
  __pyx_v_self->__pyx___pos_tag = ((PyObject*)Py_None);

  /* "AnnotatedSentence/AnnotatedWord.pyx":39
 *         self.__ccg = None
 *         self.__pos_tag = None
 *         self.__language = Language.TURKISH             # <<<<<<<<<<<<<<
 *         if layerType is None:
 *             split_layers = re.compile("[{}]").split(word)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Language); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_TURKISH); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->__pyx___language);
  __Pyx_DECREF(__pyx_v_self->__pyx___language);
  __pyx_v_self->__pyx___language = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":40
 *         self.__pos_tag = None
 *         self.__language = Language.TURKISH
 *         if layerType is None:             # <<<<<<<<<<<<<<
 *             split_layers = re.compile("[{}]").split(word)
 *             for layer in split_layers:
 */
  __pyx_t_3 = (__pyx_v_layerType == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":41
 *         self.__language = Language.TURKISH
 *         if layerType is None:
 *             split_layers = re.compile("[{}]").split(word)             # <<<<<<<<<<<<<<
 *             for layer in split_layers:
 *                 if len(layer) == 0:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_compile); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_kp_u_) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_kp_u_);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_split); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_1, __pyx_v_word) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_word);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 41, __pyx_L1_error)
    __pyx_v_split_layers = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":42
 *         if layerType is None:
 *             split_layers = re.compile("[{}]").split(word)
 *             for layer in split_layers:             # <<<<<<<<<<<<<<
 *                 if len(layer) == 0:
 *                     continue
 */
    if (unlikely(__pyx_v_split_layers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 42, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_v_split_layers; __Pyx_INCREF(__pyx_t_2); __pyx_t_7 = 0;
    for (;;) {
      if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_6); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 42, __pyx_L1_error)
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      if (!(likely(PyUnicode_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_6)->tp_name), 0))) __PYX_ERR(0, 42, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_layer, ((PyObject*)__pyx_t_6));
      __pyx_t_6 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":43
 *             split_layers = re.compile("[{}]").split(word)
 *             for layer in split_layers:
 *                 if len(layer) == 0:             # <<<<<<<<<<<<<<
 *                     continue
 *                 if "=" not in layer:
 */
      if (unlikely(__pyx_v_layer == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 43, __pyx_L1_error)
      }
      __pyx_t_8 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_layer); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 43, __pyx_L1_error)
      __pyx_t_4 = ((__pyx_t_8 == 0) != 0);
      if (__pyx_t_4) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":44
 *             for layer in split_layers:
 *                 if len(layer) == 0:
 *                     continue             # <<<<<<<<<<<<<<
 *                 if "=" not in layer:
 *                     self.name = layer
 */
        goto __pyx_L4_continue;

        /* "AnnotatedSentence/AnnotatedWord.pyx":43
 *             split_layers = re.compile("[{}]").split(word)
 *             for layer in split_layers:
 *                 if len(layer) == 0:             # <<<<<<<<<<<<<<
 *                     continue
 *                 if "=" not in layer:
 */
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":45
 *                 if len(layer) == 0:
 *                     continue
 *                 if "=" not in layer:             # <<<<<<<<<<<<<<
 *                     self.name = layer
 *                     continue
 */
      if (unlikely(__pyx_v_layer == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 45, __pyx_L1_error)
      }
      __pyx_t_4 = (__Pyx_PyUnicode_ContainsTF(__pyx_kp_u__2, __pyx_v_layer, Py_NE)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 45, __pyx_L1_error)
      __pyx_t_3 = (__pyx_t_4 != 0);
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":46
 *                     continue
 *                 if "=" not in layer:
 *                     self.name = layer             # <<<<<<<<<<<<<<
 *                     continue
 *                 layerType = layer[:layer.index("=")]
 */
        __Pyx_INCREF(__pyx_v_layer);
        __Pyx_GIVEREF(__pyx_v_layer);
        __Pyx_GOTREF(__pyx_v_self->__pyx_base.name);
        __Pyx_DECREF(__pyx_v_self->__pyx_base.name);
        __pyx_v_self->__pyx_base.name = __pyx_v_layer;

        /* "AnnotatedSentence/AnnotatedWord.pyx":47
 *                 if "=" not in layer:
 *                     self.name = layer
 *                     continue             # <<<<<<<<<<<<<<
 *                 layerType = layer[:layer.index("=")]
 *                 layer_value = layer[layer.index("=") + 1:]
 */
        goto __pyx_L4_continue;

        /* "AnnotatedSentence/AnnotatedWord.pyx":45
 *                 if len(layer) == 0:
 *                     continue
 *                 if "=" not in layer:             # <<<<<<<<<<<<<<
 *                     self.name = layer
 *                     continue
 */
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":48
 *                     self.name = layer
 *                     continue
 *                 layerType = layer[:layer.index("=")]             # <<<<<<<<<<<<<<
 *                 layer_value = layer[layer.index("=") + 1:]
 *                 if layerType == "turkish" or layerType == "english" or layerType == "persian":
 */
      if (unlikely(__pyx_v_layer == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 48, __pyx_L1_error)
      }
      __pyx_t_6 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyUnicode_Type_index, __pyx_v_layer, __pyx_kp_u__2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 48, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = (__pyx_t_6 == Py_None);
      if (__pyx_t_3) {
        __pyx_t_8 = PY_SSIZE_T_MAX;
      } else {
        __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 48, __pyx_L1_error)
        __pyx_t_8 = __pyx_t_9;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyUnicode_Substring(__pyx_v_layer, 0, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 48, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF_SET(__pyx_v_layerType, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":49
 *                     continue
 *                 layerType = layer[:layer.index("=")]
 *                 layer_value = layer[layer.index("=") + 1:]             # <<<<<<<<<<<<<<
 *                 if layerType == "turkish" or layerType == "english" or layerType == "persian":
 *                     self.name = layer_value
 */
      if (unlikely(__pyx_v_layer == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 49, __pyx_L1_error)
      }
      __pyx_t_6 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyUnicode_Type_index, __pyx_v_layer, __pyx_kp_u__2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 49, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_6, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_3 = (__pyx_t_1 == Py_None);
      if (__pyx_t_3) {
        __pyx_t_8 = 0;
      } else {
        __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_1); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 49, __pyx_L1_error)
        __pyx_t_8 = __pyx_t_9;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_layer, __pyx_t_8, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_layer_value, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":50
 *                 layerType = layer[:layer.index("=")]
 *                 layer_value = layer[layer.index("=") + 1:]
 *                 if layerType == "turkish" or layerType == "english" or layerType == "persian":             # <<<<<<<<<<<<<<
 *                     self.name = layer_value
 *                     self.__language = AnnotatedWord.getLanguageFromString(layerType)
 */
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_turkish, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 50, __pyx_L1_error)
      if (!__pyx_t_4) {
      } else {
        __pyx_t_3 = __pyx_t_4;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_english, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 50, __pyx_L1_error)
      if (!__pyx_t_4) {
      } else {
        __pyx_t_3 = __pyx_t_4;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_persian, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 50, __pyx_L1_error)
      __pyx_t_3 = __pyx_t_4;
      __pyx_L9_bool_binop_done:;
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":51
 *                 layer_value = layer[layer.index("=") + 1:]
 *                 if layerType == "turkish" or layerType == "english" or layerType == "persian":
 *                     self.name = layer_value             # <<<<<<<<<<<<<<
 *                     self.__language = AnnotatedWord.getLanguageFromString(layerType)
 *                 elif layerType == "morphologicalAnalysis":
 */
        __Pyx_INCREF(__pyx_v_layer_value);
        __Pyx_GIVEREF(__pyx_v_layer_value);
        __Pyx_GOTREF(__pyx_v_self->__pyx_base.name);
        __Pyx_DECREF(__pyx_v_self->__pyx_base.name);
        __pyx_v_self->__pyx_base.name = __pyx_v_layer_value;

        /* "AnnotatedSentence/AnnotatedWord.pyx":52
 *                 if layerType == "turkish" or layerType == "english" or layerType == "persian":
 *                     self.name = layer_value
 *                     self.__language = AnnotatedWord.getLanguageFromString(layerType)             # <<<<<<<<<<<<<<
 *                 elif layerType == "morphologicalAnalysis":
 *                     self.__parse = MorphologicalParse(layer_value)
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord), __pyx_n_s_getLanguageFromString); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 52, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_v_layerType) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_layerType);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 52, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___language);
        __Pyx_DECREF(__pyx_v_self->__pyx___language);
        __pyx_v_self->__pyx___language = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":50
 *                 layerType = layer[:layer.index("=")]
 *                 layer_value = layer[layer.index("=") + 1:]
 *                 if layerType == "turkish" or layerType == "english" or layerType == "persian":             # <<<<<<<<<<<<<<
 *                     self.name = layer_value
 *                     self.__language = AnnotatedWord.getLanguageFromString(layerType)
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":53
 *                     self.name = layer_value
 *                     self.__language = AnnotatedWord.getLanguageFromString(layerType)
 *                 elif layerType == "morphologicalAnalysis":             # <<<<<<<<<<<<<<
 *                     self.__parse = MorphologicalParse(layer_value)
 *                 elif layerType == "metaMorphemes":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_morphologicalAnalysis, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 53, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":54
 *                     self.__language = AnnotatedWord.getLanguageFromString(layerType)
 *                 elif layerType == "morphologicalAnalysis":
 *                     self.__parse = MorphologicalParse(layer_value)             # <<<<<<<<<<<<<<
 *                 elif layerType == "metaMorphemes":
 *                     self.__metamorphic_parse = MetamorphicParse(layer_value)
 */
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), __pyx_v_layer_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 54, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___parse);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___parse));
        __pyx_v_self->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":53
 *                     self.name = layer_value
 *                     self.__language = AnnotatedWord.getLanguageFromString(layerType)
 *                 elif layerType == "morphologicalAnalysis":             # <<<<<<<<<<<<<<
 *                     self.__parse = MorphologicalParse(layer_value)
 *                 elif layerType == "metaMorphemes":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":55
 *                 elif layerType == "morphologicalAnalysis":
 *                     self.__parse = MorphologicalParse(layer_value)
 *                 elif layerType == "metaMorphemes":             # <<<<<<<<<<<<<<
 *                     self.__metamorphic_parse = MetamorphicParse(layer_value)
 *                 elif layerType == "namedEntity":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_metaMorphemes, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 55, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":56
 *                     self.__parse = MorphologicalParse(layer_value)
 *                 elif layerType == "metaMorphemes":
 *                     self.__metamorphic_parse = MetamorphicParse(layer_value)             # <<<<<<<<<<<<<<
 *                 elif layerType == "namedEntity":
 *                     self.__named_entity_type = NamedEntityType.getNamedEntityType(layer_value)
 */
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse), __pyx_v_layer_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___metamorphic_parse);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse));
        __pyx_v_self->__pyx___metamorphic_parse = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":55
 *                 elif layerType == "morphologicalAnalysis":
 *                     self.__parse = MorphologicalParse(layer_value)
 *                 elif layerType == "metaMorphemes":             # <<<<<<<<<<<<<<
 *                     self.__metamorphic_parse = MetamorphicParse(layer_value)
 *                 elif layerType == "namedEntity":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":57
 *                 elif layerType == "metaMorphemes":
 *                     self.__metamorphic_parse = MetamorphicParse(layer_value)
 *                 elif layerType == "namedEntity":             # <<<<<<<<<<<<<<
 *                     self.__named_entity_type = NamedEntityType.getNamedEntityType(layer_value)
 *                 elif layerType == "propbank" or layerType == "propBank":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_namedEntity, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 57, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":58
 *                     self.__metamorphic_parse = MetamorphicParse(layer_value)
 *                 elif layerType == "namedEntity":
 *                     self.__named_entity_type = NamedEntityType.getNamedEntityType(layer_value)             # <<<<<<<<<<<<<<
 *                 elif layerType == "propbank" or layerType == "propBank":
 *                     self.__argument = Argument(layer_value)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_NamedEntityType); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 58, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_getNamedEntityType); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 58, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_v_layer_value) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_layer_value);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 58, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___named_entity_type);
        __Pyx_DECREF(__pyx_v_self->__pyx___named_entity_type);
        __pyx_v_self->__pyx___named_entity_type = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":57
 *                 elif layerType == "metaMorphemes":
 *                     self.__metamorphic_parse = MetamorphicParse(layer_value)
 *                 elif layerType == "namedEntity":             # <<<<<<<<<<<<<<
 *                     self.__named_entity_type = NamedEntityType.getNamedEntityType(layer_value)
 *                 elif layerType == "propbank" or layerType == "propBank":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":59
 *                 elif layerType == "namedEntity":
 *                     self.__named_entity_type = NamedEntityType.getNamedEntityType(layer_value)
 *                 elif layerType == "propbank" or layerType == "propBank":             # <<<<<<<<<<<<<<
 *                     self.__argument = Argument(layer_value)
 *                 elif layerType == "framenet" or layerType == "frameNet":
 */
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_propbank, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 59, __pyx_L1_error)
      if (!__pyx_t_4) {
      } else {
        __pyx_t_3 = __pyx_t_4;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_propBank, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 59, __pyx_L1_error)
      __pyx_t_3 = __pyx_t_4;
      __pyx_L12_bool_binop_done:;
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":60
 *                     self.__named_entity_type = NamedEntityType.getNamedEntityType(layer_value)
 *                 elif layerType == "propbank" or layerType == "propBank":
 *                     self.__argument = Argument(layer_value)             # <<<<<<<<<<<<<<
 *                 elif layerType == "framenet" or layerType == "frameNet":
 *                     self.__frame_element = FrameElement(layer_value)
 */
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_8PropBank_8Argument_Argument), __pyx_v_layer_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 60, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___argument);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___argument));
        __pyx_v_self->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":59
 *                 elif layerType == "namedEntity":
 *                     self.__named_entity_type = NamedEntityType.getNamedEntityType(layer_value)
 *                 elif layerType == "propbank" or layerType == "propBank":             # <<<<<<<<<<<<<<
 *                     self.__argument = Argument(layer_value)
 *                 elif layerType == "framenet" or layerType == "frameNet":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":61
 *                 elif layerType == "propbank" or layerType == "propBank":
 *                     self.__argument = Argument(layer_value)
 *                 elif layerType == "framenet" or layerType == "frameNet":             # <<<<<<<<<<<<<<
 *                     self.__frame_element = FrameElement(layer_value)
 *                 elif layerType == "shallowParse":
 */
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_framenet, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 61, __pyx_L1_error)
      if (!__pyx_t_4) {
      } else {
        __pyx_t_3 = __pyx_t_4;
        goto __pyx_L14_bool_binop_done;
      }
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_frameNet, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 61, __pyx_L1_error)
      __pyx_t_3 = __pyx_t_4;
      __pyx_L14_bool_binop_done:;
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":62
 *                     self.__argument = Argument(layer_value)
 *                 elif layerType == "framenet" or layerType == "frameNet":
 *                     self.__frame_element = FrameElement(layer_value)             # <<<<<<<<<<<<<<
 *                 elif layerType == "shallowParse":
 *                     self.__shallow_parse = layer_value
 */
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_8FrameNet_12FrameElement_FrameElement), __pyx_v_layer_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 62, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___frame_element);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___frame_element));
        __pyx_v_self->__pyx___frame_element = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":61
 *                 elif layerType == "propbank" or layerType == "propBank":
 *                     self.__argument = Argument(layer_value)
 *                 elif layerType == "framenet" or layerType == "frameNet":             # <<<<<<<<<<<<<<
 *                     self.__frame_element = FrameElement(layer_value)
 *                 elif layerType == "shallowParse":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":63
 *                 elif layerType == "framenet" or layerType == "frameNet":
 *                     self.__frame_element = FrameElement(layer_value)
 *                 elif layerType == "shallowParse":             # <<<<<<<<<<<<<<
 *                     self.__shallow_parse = layer_value
 *                 elif layerType == "semantics":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_shallowParse, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 63, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":64
 *                     self.__frame_element = FrameElement(layer_value)
 *                 elif layerType == "shallowParse":
 *                     self.__shallow_parse = layer_value             # <<<<<<<<<<<<<<
 *                 elif layerType == "semantics":
 *                     self.__semantic = layer_value
 */
        __Pyx_INCREF(__pyx_v_layer_value);
        __Pyx_GIVEREF(__pyx_v_layer_value);
        __Pyx_GOTREF(__pyx_v_self->__pyx___shallow_parse);
        __Pyx_DECREF(__pyx_v_self->__pyx___shallow_parse);
        __pyx_v_self->__pyx___shallow_parse = __pyx_v_layer_value;

        /* "AnnotatedSentence/AnnotatedWord.pyx":63
 *                 elif layerType == "framenet" or layerType == "frameNet":
 *                     self.__frame_element = FrameElement(layer_value)
 *                 elif layerType == "shallowParse":             # <<<<<<<<<<<<<<
 *                     self.__shallow_parse = layer_value
 *                 elif layerType == "semantics":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":65
 *                 elif layerType == "shallowParse":
 *                     self.__shallow_parse = layer_value
 *                 elif layerType == "semantics":             # <<<<<<<<<<<<<<
 *                     self.__semantic = layer_value
 *                 elif layerType == "slot":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_semantics, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 65, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":66
 *                     self.__shallow_parse = layer_value
 *                 elif layerType == "semantics":
 *                     self.__semantic = layer_value             # <<<<<<<<<<<<<<
 *                 elif layerType == "slot":
 *                     self.__slot = Slot(layer_value)
 */
        __Pyx_INCREF(__pyx_v_layer_value);
        __Pyx_GIVEREF(__pyx_v_layer_value);
        __Pyx_GOTREF(__pyx_v_self->__pyx___semantic);
        __Pyx_DECREF(__pyx_v_self->__pyx___semantic);
        __pyx_v_self->__pyx___semantic = __pyx_v_layer_value;

        /* "AnnotatedSentence/AnnotatedWord.pyx":65
 *                 elif layerType == "shallowParse":
 *                     self.__shallow_parse = layer_value
 *                 elif layerType == "semantics":             # <<<<<<<<<<<<<<
 *                     self.__semantic = layer_value
 *                 elif layerType == "slot":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":67
 *                 elif layerType == "semantics":
 *                     self.__semantic = layer_value
 *                 elif layerType == "slot":             # <<<<<<<<<<<<<<
 *                     self.__slot = Slot(layer_value)
 *                 elif layerType == "polarity":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_slot, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 67, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":68
 *                     self.__semantic = layer_value
 *                 elif layerType == "slot":
 *                     self.__slot = Slot(layer_value)             # <<<<<<<<<<<<<<
 *                 elif layerType == "polarity":
 *                     self.setPolarity(layer_value)
 */
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_22NamedEntityRecognition_4Slot_Slot), __pyx_v_layer_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___slot);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___slot));
        __pyx_v_self->__pyx___slot = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":67
 *                 elif layerType == "semantics":
 *                     self.__semantic = layer_value
 *                 elif layerType == "slot":             # <<<<<<<<<<<<<<
 *                     self.__slot = Slot(layer_value)
 *                 elif layerType == "polarity":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":69
 *                 elif layerType == "slot":
 *                     self.__slot = Slot(layer_value)
 *                 elif layerType == "polarity":             # <<<<<<<<<<<<<<
 *                     self.setPolarity(layer_value)
 *                 elif layerType == "universalDependency":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_polarity, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 69, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":70
 *                     self.__slot = Slot(layer_value)
 *                 elif layerType == "polarity":
 *                     self.setPolarity(layer_value)             # <<<<<<<<<<<<<<
 *                 elif layerType == "universalDependency":
 *                     values = layer_value.split("$")
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->setPolarity(__pyx_v_self, __pyx_v_layer_value, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":69
 *                 elif layerType == "slot":
 *                     self.__slot = Slot(layer_value)
 *                 elif layerType == "polarity":             # <<<<<<<<<<<<<<
 *                     self.setPolarity(layer_value)
 *                 elif layerType == "universalDependency":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":71
 *                 elif layerType == "polarity":
 *                     self.setPolarity(layer_value)
 *                 elif layerType == "universalDependency":             # <<<<<<<<<<<<<<
 *                     values = layer_value.split("$")
 *                     self.__universal_dependency = UniversalDependencyRelation(int(values[0]), values[1])
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_universalDependency, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 71, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":72
 *                     self.setPolarity(layer_value)
 *                 elif layerType == "universalDependency":
 *                     values = layer_value.split("$")             # <<<<<<<<<<<<<<
 *                     self.__universal_dependency = UniversalDependencyRelation(int(values[0]), values[1])
 *                 elif layerType == "ccg":
 */
        __pyx_t_1 = PyUnicode_Split(__pyx_v_layer_value, __pyx_kp_u__3, -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_values, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":73
 *                 elif layerType == "universalDependency":
 *                     values = layer_value.split("$")
 *                     self.__universal_dependency = UniversalDependencyRelation(int(values[0]), values[1])             # <<<<<<<<<<<<<<
 *                 elif layerType == "ccg":
 *                     self.__ccg = layer_value
 */
        if (unlikely(__pyx_v_values == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 73, __pyx_L1_error)
        }
        __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_values, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 73, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(__pyx_v_values == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 73, __pyx_L1_error)
        }
        __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_values, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 73, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
        __pyx_t_5 = 0;
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation), __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->__pyx___universal_dependency);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___universal_dependency));
        __pyx_v_self->__pyx___universal_dependency = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":71
 *                 elif layerType == "polarity":
 *                     self.setPolarity(layer_value)
 *                 elif layerType == "universalDependency":             # <<<<<<<<<<<<<<
 *                     values = layer_value.split("$")
 *                     self.__universal_dependency = UniversalDependencyRelation(int(values[0]), values[1])
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":74
 *                     values = layer_value.split("$")
 *                     self.__universal_dependency = UniversalDependencyRelation(int(values[0]), values[1])
 *                 elif layerType == "ccg":             # <<<<<<<<<<<<<<
 *                     self.__ccg = layer_value
 *                 elif layerType == "posTag":
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_ccg, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 74, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":75
 *                     self.__universal_dependency = UniversalDependencyRelation(int(values[0]), values[1])
 *                 elif layerType == "ccg":
 *                     self.__ccg = layer_value             # <<<<<<<<<<<<<<
 *                 elif layerType == "posTag":
 *                     self.__pos_tag = layer_value
 */
        __Pyx_INCREF(__pyx_v_layer_value);
        __Pyx_GIVEREF(__pyx_v_layer_value);
        __Pyx_GOTREF(__pyx_v_self->__pyx___ccg);
        __Pyx_DECREF(__pyx_v_self->__pyx___ccg);
        __pyx_v_self->__pyx___ccg = __pyx_v_layer_value;

        /* "AnnotatedSentence/AnnotatedWord.pyx":74
 *                     values = layer_value.split("$")
 *                     self.__universal_dependency = UniversalDependencyRelation(int(values[0]), values[1])
 *                 elif layerType == "ccg":             # <<<<<<<<<<<<<<
 *                     self.__ccg = layer_value
 *                 elif layerType == "posTag":
 */
        goto __pyx_L8;
      }

      /* "AnnotatedSentence/AnnotatedWord.pyx":76
 *                 elif layerType == "ccg":
 *                     self.__ccg = layer_value
 *                 elif layerType == "posTag":             # <<<<<<<<<<<<<<
 *                     self.__pos_tag = layer_value
 *         elif isinstance(layerType, NamedEntityType):
 */
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_layerType, __pyx_n_u_posTag, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 76, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "AnnotatedSentence/AnnotatedWord.pyx":77
 *                     self.__ccg = layer_value
 *                 elif layerType == "posTag":
 *                     self.__pos_tag = layer_value             # <<<<<<<<<<<<<<
 *         elif isinstance(layerType, NamedEntityType):
 *             super().__init__(word)
 */
        __Pyx_INCREF(__pyx_v_layer_value);
        __Pyx_GIVEREF(__pyx_v_layer_value);
        __Pyx_GOTREF(__pyx_v_self->__pyx___pos_tag);
        __Pyx_DECREF(__pyx_v_self->__pyx___pos_tag);
        __pyx_v_self->__pyx___pos_tag = __pyx_v_layer_value;

        /* "AnnotatedSentence/AnnotatedWord.pyx":76
 *                 elif layerType == "ccg":
 *                     self.__ccg = layer_value
 *                 elif layerType == "posTag":             # <<<<<<<<<<<<<<
 *                     self.__pos_tag = layer_value
 *         elif isinstance(layerType, NamedEntityType):
 */
      }
      __pyx_L8:;

      /* "AnnotatedSentence/AnnotatedWord.pyx":42
 *         if layerType is None:
 *             split_layers = re.compile("[{}]").split(word)
 *             for layer in split_layers:             # <<<<<<<<<<<<<<
 *                 if len(layer) == 0:
 *                     continue
 */
      __pyx_L4_continue:;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":40
 *         self.__pos_tag = None
 *         self.__language = Language.TURKISH
 *         if layerType is None:             # <<<<<<<<<<<<<<
 *             split_layers = re.compile("[{}]").split(word)
 *             for layer in split_layers:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":78
 *                 elif layerType == "posTag":
 *                     self.__pos_tag = layer_value
 *         elif isinstance(layerType, NamedEntityType):             # <<<<<<<<<<<<<<
 *             super().__init__(word)
 *             self.__named_entity_type = layerType
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NamedEntityType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_layerType, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":79
 *                     self.__pos_tag = layer_value
 *         elif isinstance(layerType, NamedEntityType):
 *             super().__init__(word)             # <<<<<<<<<<<<<<
 *             self.__named_entity_type = layerType
 *             self.__argument = Argument("NONE")
 */
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    __Pyx_GIVEREF(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self));
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_1, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, __pyx_v_word) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_word);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":80
 *         elif isinstance(layerType, NamedEntityType):
 *             super().__init__(word)
 *             self.__named_entity_type = layerType             # <<<<<<<<<<<<<<
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, MorphologicalParse):
 */
    __Pyx_INCREF(__pyx_v_layerType);
    __Pyx_GIVEREF(__pyx_v_layerType);
    __Pyx_GOTREF(__pyx_v_self->__pyx___named_entity_type);
    __Pyx_DECREF(__pyx_v_self->__pyx___named_entity_type);
    __pyx_v_self->__pyx___named_entity_type = __pyx_v_layerType;

    /* "AnnotatedSentence/AnnotatedWord.pyx":81
 *             super().__init__(word)
 *             self.__named_entity_type = layerType
 *             self.__argument = Argument("NONE")             # <<<<<<<<<<<<<<
 *         elif isinstance(layerType, MorphologicalParse):
 *             super().__init__(word)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_8PropBank_8Argument_Argument), __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->__pyx___argument);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___argument));
    __pyx_v_self->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":78
 *                 elif layerType == "posTag":
 *                     self.__pos_tag = layer_value
 *         elif isinstance(layerType, NamedEntityType):             # <<<<<<<<<<<<<<
 *             super().__init__(word)
 *             self.__named_entity_type = layerType
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":82
 *             self.__named_entity_type = layerType
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, MorphologicalParse):             # <<<<<<<<<<<<<<
 *             super().__init__(word)
 *             self.__parse = layerType
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_layerType, __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse); 
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":83
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, MorphologicalParse):
 *             super().__init__(word)             # <<<<<<<<<<<<<<
 *             self.__parse = layerType
 *             self.__named_entity_type = NamedEntityType.NONE
 */
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    __Pyx_GIVEREF(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self));
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_1, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, __pyx_v_word) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_word);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":84
 *         elif isinstance(layerType, MorphologicalParse):
 *             super().__init__(word)
 *             self.__parse = layerType             # <<<<<<<<<<<<<<
 *             self.__named_entity_type = NamedEntityType.NONE
 *             self.__argument = Argument("NONE")
 */
    if (!(likely(((__pyx_v_layerType) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_layerType, __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse))))) __PYX_ERR(0, 84, __pyx_L1_error)
    __pyx_t_2 = __pyx_v_layerType;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->__pyx___parse);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___parse));
    __pyx_v_self->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":85
 *             super().__init__(word)
 *             self.__parse = layerType
 *             self.__named_entity_type = NamedEntityType.NONE             # <<<<<<<<<<<<<<
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, FsmParse):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NamedEntityType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_NONE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___named_entity_type);
    __Pyx_DECREF(__pyx_v_self->__pyx___named_entity_type);
    __pyx_v_self->__pyx___named_entity_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":86
 *             self.__parse = layerType
 *             self.__named_entity_type = NamedEntityType.NONE
 *             self.__argument = Argument("NONE")             # <<<<<<<<<<<<<<
 *         elif isinstance(layerType, FsmParse):
 *             super().__init__(word)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_8PropBank_8Argument_Argument), __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___argument);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___argument));
    __pyx_v_self->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":82
 *             self.__named_entity_type = layerType
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, MorphologicalParse):             # <<<<<<<<<<<<<<
 *             super().__init__(word)
 *             self.__parse = layerType
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":87
 *             self.__named_entity_type = NamedEntityType.NONE
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, FsmParse):             # <<<<<<<<<<<<<<
 *             super().__init__(word)
 *             self.__parse = layerType
 */
  __pyx_t_3 = __Pyx_TypeCheck(__pyx_v_layerType, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse); 
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":88
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, FsmParse):
 *             super().__init__(word)             # <<<<<<<<<<<<<<
 *             self.__parse = layerType
 *             self.__named_entity_type = NamedEntityType.NONE
 */
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    __Pyx_GIVEREF(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord));
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self));
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_6, __pyx_v_word) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_word);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":89
 *         elif isinstance(layerType, FsmParse):
 *             super().__init__(word)
 *             self.__parse = layerType             # <<<<<<<<<<<<<<
 *             self.__named_entity_type = NamedEntityType.NONE
 *             self.setMetamorphicParse(layerType.withList())
 */
    if (!(likely(((__pyx_v_layerType) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_layerType, __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse))))) __PYX_ERR(0, 89, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_layerType;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___parse);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___parse));
    __pyx_v_self->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":90
 *             super().__init__(word)
 *             self.__parse = layerType
 *             self.__named_entity_type = NamedEntityType.NONE             # <<<<<<<<<<<<<<
 *             self.setMetamorphicParse(layerType.withList())
 *             self.__argument = Argument("NONE")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NamedEntityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NONE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->__pyx___named_entity_type);
    __Pyx_DECREF(__pyx_v_self->__pyx___named_entity_type);
    __pyx_v_self->__pyx___named_entity_type = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":91
 *             self.__parse = layerType
 *             self.__named_entity_type = NamedEntityType.NONE
 *             self.setMetamorphicParse(layerType.withList())             # <<<<<<<<<<<<<<
 *             self.__argument = Argument("NONE")
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_layerType, __pyx_n_s_withList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 91, __pyx_L1_error)
    __pyx_t_1 = ((struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->setMetamorphicParse(__pyx_v_self, ((PyObject*)__pyx_t_2), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":92
 *             self.__named_entity_type = NamedEntityType.NONE
 *             self.setMetamorphicParse(layerType.withList())
 *             self.__argument = Argument("NONE")             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self) -> str:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_8PropBank_8Argument_Argument), __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___argument);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___argument));
    __pyx_v_self->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":87
 *             self.__named_entity_type = NamedEntityType.NONE
 *             self.__argument = Argument("NONE")
 *         elif isinstance(layerType, FsmParse):             # <<<<<<<<<<<<<<
 *             super().__init__(word)
 *             self.__parse = layerType
 */
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":13
 * cdef class AnnotatedWord(Word):
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  word: str,
 *                  layerType=None):
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_split_layers);
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_layer);
  __Pyx_XDECREF(__pyx_v_layer_value);
  __Pyx_XDECREF(__pyx_v_layerType);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":94
 *             self.__argument = Argument("NONE")
 * 
 *     def __str__(self) -> str:             # <<<<<<<<<<<<<<
 *         """
 *         Converts an AnnotatedWord to string. For each annotation layer, the method puts a left brace, layer name,
 */

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_3__str__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__[] = "\n        Converts an AnnotatedWord to string. For each annotation layer, the method puts a left brace, layer name,\n        equal sign and layer value finishing with right brace.\n\n        RETURNS\n        -------\n        str\n            String form of the AnnotatedWord.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__;
#endif
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_3__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "AnnotatedSentence/AnnotatedWord.pyx":105
 *         """
 *         cdef str result
 *         result = ""             # <<<<<<<<<<<<<<
 *         if self.__language == Language.TURKISH:
 *             result = "{turkish=" + self.name + "}"
 */
  __Pyx_INCREF(__pyx_kp_u__5);
  __pyx_v_result = __pyx_kp_u__5;

  /* "AnnotatedSentence/AnnotatedWord.pyx":106
 *         cdef str result
 *         result = ""
 *         if self.__language == Language.TURKISH:             # <<<<<<<<<<<<<<
 *             result = "{turkish=" + self.name + "}"
 *         elif self.__language == Language.ENGLISH:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Language); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_TURKISH); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->__pyx___language, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":107
 *         result = ""
 *         if self.__language == Language.TURKISH:
 *             result = "{turkish=" + self.name + "}"             # <<<<<<<<<<<<<<
 *         elif self.__language == Language.ENGLISH:
 *             result = "{english=" + self.name + "}"
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_turkish_2, __pyx_v_self->__pyx_base.name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":106
 *         cdef str result
 *         result = ""
 *         if self.__language == Language.TURKISH:             # <<<<<<<<<<<<<<
 *             result = "{turkish=" + self.name + "}"
 *         elif self.__language == Language.ENGLISH:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":108
 *         if self.__language == Language.TURKISH:
 *             result = "{turkish=" + self.name + "}"
 *         elif self.__language == Language.ENGLISH:             # <<<<<<<<<<<<<<
 *             result = "{english=" + self.name + "}"
 *         elif self.__language == Language.PERSIAN:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Language); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ENGLISH); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_self->__pyx___language, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":109
 *             result = "{turkish=" + self.name + "}"
 *         elif self.__language == Language.ENGLISH:
 *             result = "{english=" + self.name + "}"             # <<<<<<<<<<<<<<
 *         elif self.__language == Language.PERSIAN:
 *             result = "{persian=" + self.name + "}"
 */
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_english_2, __pyx_v_self->__pyx_base.name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_kp_u__6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":108
 *         if self.__language == Language.TURKISH:
 *             result = "{turkish=" + self.name + "}"
 *         elif self.__language == Language.ENGLISH:             # <<<<<<<<<<<<<<
 *             result = "{english=" + self.name + "}"
 *         elif self.__language == Language.PERSIAN:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":110
 *         elif self.__language == Language.ENGLISH:
 *             result = "{english=" + self.name + "}"
 *         elif self.__language == Language.PERSIAN:             # <<<<<<<<<<<<<<
 *             result = "{persian=" + self.name + "}"
 *         if self.__parse is not None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Language); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PERSIAN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->__pyx___language, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":111
 *             result = "{english=" + self.name + "}"
 *         elif self.__language == Language.PERSIAN:
 *             result = "{persian=" + self.name + "}"             # <<<<<<<<<<<<<<
 *         if self.__parse is not None:
 *             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_persian_2, __pyx_v_self->__pyx_base.name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":110
 *         elif self.__language == Language.ENGLISH:
 *             result = "{english=" + self.name + "}"
 *         elif self.__language == Language.PERSIAN:             # <<<<<<<<<<<<<<
 *             result = "{persian=" + self.name + "}"
 *         if self.__parse is not None:
 */
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":112
 *         elif self.__language == Language.PERSIAN:
 *             result = "{persian=" + self.name + "}"
 *         if self.__parse is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"
 *         if self.__metamorphic_parse is not None:
 */
  __pyx_t_3 = (((PyObject *)__pyx_v_self->__pyx___parse) != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":113
 *             result = "{persian=" + self.name + "}"
 *         if self.__parse is not None:
 *             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"             # <<<<<<<<<<<<<<
 *         if self.__metamorphic_parse is not None:
 *             result = result + "{metaMorphemes=" + self.__metamorphic_parse.__str__() + "}"
 */
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_v_result, __pyx_kp_u_morphologicalAnalysis_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___parse), __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 113, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":112
 *         elif self.__language == Language.PERSIAN:
 *             result = "{persian=" + self.name + "}"
 *         if self.__parse is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"
 *         if self.__metamorphic_parse is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":114
 *         if self.__parse is not None:
 *             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"
 *         if self.__metamorphic_parse is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{metaMorphemes=" + self.__metamorphic_parse.__str__() + "}"
 *         if self.__semantic is not None:
 */
  __pyx_t_4 = (((PyObject *)__pyx_v_self->__pyx___metamorphic_parse) != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":115
 *             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"
 *         if self.__metamorphic_parse is not None:
 *             result = result + "{metaMorphemes=" + self.__metamorphic_parse.__str__() + "}"             # <<<<<<<<<<<<<<
 *         if self.__semantic is not None:
 *             result = result + "{semantics=" + self.__semantic + "}"
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_metaMorphemes_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_5)->tp_name), 0))) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":114
 *         if self.__parse is not None:
 *             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"
 *         if self.__metamorphic_parse is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{metaMorphemes=" + self.__metamorphic_parse.__str__() + "}"
 *         if self.__semantic is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":116
 *         if self.__metamorphic_parse is not None:
 *             result = result + "{metaMorphemes=" + self.__metamorphic_parse.__str__() + "}"
 *         if self.__semantic is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{semantics=" + self.__semantic + "}"
 *         if self.__named_entity_type is not None:
 */
  __pyx_t_3 = (__pyx_v_self->__pyx___semantic != ((PyObject*)Py_None));
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":117
 *             result = result + "{metaMorphemes=" + self.__metamorphic_parse.__str__() + "}"
 *         if self.__semantic is not None:
 *             result = result + "{semantics=" + self.__semantic + "}"             # <<<<<<<<<<<<<<
 *         if self.__named_entity_type is not None:
 *             result = result + "{namedEntity=" + NamedEntityType.getNamedEntityString(self.__named_entity_type) + "}"
 */
    __pyx_t_5 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_semantics_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_5, __pyx_v_self->__pyx___semantic); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_kp_u__6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":116
 *         if self.__metamorphic_parse is not None:
 *             result = result + "{metaMorphemes=" + self.__metamorphic_parse.__str__() + "}"
 *         if self.__semantic is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{semantics=" + self.__semantic + "}"
 *         if self.__named_entity_type is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":118
 *         if self.__semantic is not None:
 *             result = result + "{semantics=" + self.__semantic + "}"
 *         if self.__named_entity_type is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{namedEntity=" + NamedEntityType.getNamedEntityString(self.__named_entity_type) + "}"
 *         if self.__argument is not None:
 */
  __pyx_t_4 = (__pyx_v_self->__pyx___named_entity_type != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":119
 *             result = result + "{semantics=" + self.__semantic + "}"
 *         if self.__named_entity_type is not None:
 *             result = result + "{namedEntity=" + NamedEntityType.getNamedEntityString(self.__named_entity_type) + "}"             # <<<<<<<<<<<<<<
 *         if self.__argument is not None:
 *             result = result + "{propbank=" + self.__argument.__str__() + "}"
 */
    __pyx_t_5 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_namedEntity_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NamedEntityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_getNamedEntityString); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_1, __pyx_v_self->__pyx___named_entity_type) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_self->__pyx___named_entity_type);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_kp_u__6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":118
 *         if self.__semantic is not None:
 *             result = result + "{semantics=" + self.__semantic + "}"
 *         if self.__named_entity_type is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{namedEntity=" + NamedEntityType.getNamedEntityString(self.__named_entity_type) + "}"
 *         if self.__argument is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":120
 *         if self.__named_entity_type is not None:
 *             result = result + "{namedEntity=" + NamedEntityType.getNamedEntityString(self.__named_entity_type) + "}"
 *         if self.__argument is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{propbank=" + self.__argument.__str__() + "}"
 *         if self.__frame_element is not None:
 */
  __pyx_t_3 = (((PyObject *)__pyx_v_self->__pyx___argument) != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":121
 *             result = result + "{namedEntity=" + NamedEntityType.getNamedEntityString(self.__named_entity_type) + "}"
 *         if self.__argument is not None:
 *             result = result + "{propbank=" + self.__argument.__str__() + "}"             # <<<<<<<<<<<<<<
 *         if self.__frame_element is not None:
 *             result = result + "{framenet=" + self.__frame_element.__str__() + "}"
 */
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_propbank_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___argument), __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_6 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_6)->tp_name), 0))) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":120
 *         if self.__named_entity_type is not None:
 *             result = result + "{namedEntity=" + NamedEntityType.getNamedEntityString(self.__named_entity_type) + "}"
 *         if self.__argument is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{propbank=" + self.__argument.__str__() + "}"
 *         if self.__frame_element is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":122
 *         if self.__argument is not None:
 *             result = result + "{propbank=" + self.__argument.__str__() + "}"
 *         if self.__frame_element is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{framenet=" + self.__frame_element.__str__() + "}"
 *         if self.__slot is not None:
 */
  __pyx_t_4 = (((PyObject *)__pyx_v_self->__pyx___frame_element) != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":123
 *             result = result + "{propbank=" + self.__argument.__str__() + "}"
 *         if self.__frame_element is not None:
 *             result = result + "{framenet=" + self.__frame_element.__str__() + "}"             # <<<<<<<<<<<<<<
 *         if self.__slot is not None:
 *             result = result + "{slot=" + self.__slot.__str__() + "}"
 */
    __pyx_t_6 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_framenet_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___frame_element), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_5 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_5)->tp_name), 0))) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":122
 *         if self.__argument is not None:
 *             result = result + "{propbank=" + self.__argument.__str__() + "}"
 *         if self.__frame_element is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{framenet=" + self.__frame_element.__str__() + "}"
 *         if self.__slot is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":124
 *         if self.__frame_element is not None:
 *             result = result + "{framenet=" + self.__frame_element.__str__() + "}"
 *         if self.__slot is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{slot=" + self.__slot.__str__() + "}"
 *         if self.__shallow_parse is not None:
 */
  __pyx_t_3 = (((PyObject *)__pyx_v_self->__pyx___slot) != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":125
 *             result = result + "{framenet=" + self.__frame_element.__str__() + "}"
 *         if self.__slot is not None:
 *             result = result + "{slot=" + self.__slot.__str__() + "}"             # <<<<<<<<<<<<<<
 *         if self.__shallow_parse is not None:
 *             result = result + "{shallowParse=" + self.__shallow_parse + "}"
 */
    __pyx_t_5 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_slot_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___slot), __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_kp_u__6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":124
 *         if self.__frame_element is not None:
 *             result = result + "{framenet=" + self.__frame_element.__str__() + "}"
 *         if self.__slot is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{slot=" + self.__slot.__str__() + "}"
 *         if self.__shallow_parse is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":126
 *         if self.__slot is not None:
 *             result = result + "{slot=" + self.__slot.__str__() + "}"
 *         if self.__shallow_parse is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{shallowParse=" + self.__shallow_parse + "}"
 *         if self.__polarity is not None:
 */
  __pyx_t_4 = (__pyx_v_self->__pyx___shallow_parse != ((PyObject*)Py_None));
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":127
 *             result = result + "{slot=" + self.__slot.__str__() + "}"
 *         if self.__shallow_parse is not None:
 *             result = result + "{shallowParse=" + self.__shallow_parse + "}"             # <<<<<<<<<<<<<<
 *         if self.__polarity is not None:
 *             result = result + "{polarity=" + self.getPolarityString() + "}"
 */
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_shallowParse_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_2, __pyx_v_self->__pyx___shallow_parse); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_6, __pyx_kp_u__6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":126
 *         if self.__slot is not None:
 *             result = result + "{slot=" + self.__slot.__str__() + "}"
 *         if self.__shallow_parse is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{shallowParse=" + self.__shallow_parse + "}"
 *         if self.__polarity is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":128
 *         if self.__shallow_parse is not None:
 *             result = result + "{shallowParse=" + self.__shallow_parse + "}"
 *         if self.__polarity is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{polarity=" + self.getPolarityString() + "}"
 *         if self.__universal_dependency is not None:
 */
  __pyx_t_3 = (__pyx_v_self->__pyx___polarity != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":129
 *             result = result + "{shallowParse=" + self.__shallow_parse + "}"
 *         if self.__polarity is not None:
 *             result = result + "{polarity=" + self.getPolarityString() + "}"             # <<<<<<<<<<<<<<
 *         if self.__universal_dependency is not None:
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \
 */
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_polarity_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = ((struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->getPolarityString(__pyx_v_self, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_t_5, __pyx_kp_u__6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":128
 *         if self.__shallow_parse is not None:
 *             result = result + "{shallowParse=" + self.__shallow_parse + "}"
 *         if self.__polarity is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{polarity=" + self.getPolarityString() + "}"
 *         if self.__universal_dependency is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":130
 *         if self.__polarity is not None:
 *             result = result + "{polarity=" + self.getPolarityString() + "}"
 *         if self.__universal_dependency is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \
 *                      self.__universal_dependency.__str__() + "}"
 */
  __pyx_t_4 = (((PyObject *)__pyx_v_self->__pyx___universal_dependency) != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":131
 *             result = result + "{polarity=" + self.getPolarityString() + "}"
 *         if self.__universal_dependency is not None:
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \             # <<<<<<<<<<<<<<
 *                      self.__universal_dependency.__str__() + "}"
 *         if self.__ccg is not None:
 */
    __pyx_t_6 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_universalDependency_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_v_self->__pyx___universal_dependency->__pyx_base.__pyx_vtab)->__pyx_base.to(((struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation *)__pyx_v_self->__pyx___universal_dependency), 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_5 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":132
 *         if self.__universal_dependency is not None:
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \
 *                      self.__universal_dependency.__str__() + "}"             # <<<<<<<<<<<<<<
 *         if self.__ccg is not None:
 *             result = result + "{ccg=" + self.__ccg + "}"
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___universal_dependency), __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":131
 *             result = result + "{polarity=" + self.getPolarityString() + "}"
 *         if self.__universal_dependency is not None:
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \             # <<<<<<<<<<<<<<
 *                      self.__universal_dependency.__str__() + "}"
 *         if self.__ccg is not None:
 */
    __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":132
 *         if self.__universal_dependency is not None:
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \
 *                      self.__universal_dependency.__str__() + "}"             # <<<<<<<<<<<<<<
 *         if self.__ccg is not None:
 *             result = result + "{ccg=" + self.__ccg + "}"
 */
    __pyx_t_1 = PyNumber_Add(__pyx_t_6, __pyx_kp_u__6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":130
 *         if self.__polarity is not None:
 *             result = result + "{polarity=" + self.getPolarityString() + "}"
 *         if self.__universal_dependency is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \
 *                      self.__universal_dependency.__str__() + "}"
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":133
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \
 *                      self.__universal_dependency.__str__() + "}"
 *         if self.__ccg is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{ccg=" + self.__ccg + "}"
 *         if self.__pos_tag is not None:
 */
  __pyx_t_3 = (__pyx_v_self->__pyx___ccg != ((PyObject*)Py_None));
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":134
 *                      self.__universal_dependency.__str__() + "}"
 *         if self.__ccg is not None:
 *             result = result + "{ccg=" + self.__ccg + "}"             # <<<<<<<<<<<<<<
 *         if self.__pos_tag is not None:
 *             result = result + "{posTag=" + self.__pos_tag + "}"
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_ccg_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_v_self->__pyx___ccg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_6, __pyx_kp_u__6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":133
 *             result = result + "{universalDependency=" + self.__universal_dependency.to().__str__() + "$" + \
 *                      self.__universal_dependency.__str__() + "}"
 *         if self.__ccg is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{ccg=" + self.__ccg + "}"
 *         if self.__pos_tag is not None:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":135
 *         if self.__ccg is not None:
 *             result = result + "{ccg=" + self.__ccg + "}"
 *         if self.__pos_tag is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{posTag=" + self.__pos_tag + "}"
 *         return result
 */
  __pyx_t_4 = (__pyx_v_self->__pyx___pos_tag != ((PyObject*)Py_None));
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":136
 *             result = result + "{ccg=" + self.__ccg + "}"
 *         if self.__pos_tag is not None:
 *             result = result + "{posTag=" + self.__pos_tag + "}"             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_posTag_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_v_self->__pyx___pos_tag); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_6, __pyx_kp_u__6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":135
 *         if self.__ccg is not None:
 *             result = result + "{ccg=" + self.__ccg + "}"
 *         if self.__pos_tag is not None:             # <<<<<<<<<<<<<<
 *             result = result + "{posTag=" + self.__pos_tag + "}"
 *         return result
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":137
 *         if self.__pos_tag is not None:
 *             result = result + "{posTag=" + self.__pos_tag + "}"
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getLayerInfo(self, object viewLayerType):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":94
 *             self.__argument = Argument("NONE")
 * 
 *     def __str__(self) -> str:             # <<<<<<<<<<<<<<
 *         """
 *         Converts an AnnotatedWord to string. For each annotation layer, the method puts a left brace, layer name,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":139
 *         return result
 * 
 *     cpdef str getLayerInfo(self, object viewLayerType):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the value of a given layer.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_5getLayerInfo(PyObject *__pyx_v_self, PyObject *__pyx_v_viewLayerType); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLayerInfo(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_viewLayerType, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLayerInfo", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getLayerInfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_5getLayerInfo)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_viewLayerType) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_viewLayerType);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 139, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":153
 *             The value of the given layer.
 *         """
 *         if viewLayerType == ViewLayerType.INFLECTIONAL_GROUP:             # <<<<<<<<<<<<<<
 *             if self.__parse is not None:
 *                 return self.__parse.__str__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_INFLECTIONAL_GROUP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":154
 *         """
 *         if viewLayerType == ViewLayerType.INFLECTIONAL_GROUP:
 *             if self.__parse is not None:             # <<<<<<<<<<<<<<
 *                 return self.__parse.__str__()
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:
 */
    __pyx_t_5 = (((PyObject *)__pyx_v_self->__pyx___parse) != Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":155
 *         if viewLayerType == ViewLayerType.INFLECTIONAL_GROUP:
 *             if self.__parse is not None:
 *                 return self.__parse.__str__()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:
 *             if self.__metamorphic_parse is not None:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___parse), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 155, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":154
 *         """
 *         if viewLayerType == ViewLayerType.INFLECTIONAL_GROUP:
 *             if self.__parse is not None:             # <<<<<<<<<<<<<<
 *                 return self.__parse.__str__()
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":153
 *             The value of the given layer.
 *         """
 *         if viewLayerType == ViewLayerType.INFLECTIONAL_GROUP:             # <<<<<<<<<<<<<<
 *             if self.__parse is not None:
 *                 return self.__parse.__str__()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":156
 *             if self.__parse is not None:
 *                 return self.__parse.__str__()
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:             # <<<<<<<<<<<<<<
 *             if self.__metamorphic_parse is not None:
 *                 return self.__metamorphic_parse.__str__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_META_MORPHEME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":157
 *                 return self.__parse.__str__()
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:
 *             if self.__metamorphic_parse is not None:             # <<<<<<<<<<<<<<
 *                 return self.__metamorphic_parse.__str__()
 *         elif viewLayerType == ViewLayerType.SEMANTICS:
 */
    __pyx_t_6 = (((PyObject *)__pyx_v_self->__pyx___metamorphic_parse) != Py_None);
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":158
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:
 *             if self.__metamorphic_parse is not None:
 *                 return self.__metamorphic_parse.__str__()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.SEMANTICS:
 *             return self.__semantic
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 158, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":157
 *                 return self.__parse.__str__()
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:
 *             if self.__metamorphic_parse is not None:             # <<<<<<<<<<<<<<
 *                 return self.__metamorphic_parse.__str__()
 *         elif viewLayerType == ViewLayerType.SEMANTICS:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":156
 *             if self.__parse is not None:
 *                 return self.__parse.__str__()
 *         elif viewLayerType == ViewLayerType.META_MORPHEME:             # <<<<<<<<<<<<<<
 *             if self.__metamorphic_parse is not None:
 *                 return self.__metamorphic_parse.__str__()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":159
 *             if self.__metamorphic_parse is not None:
 *                 return self.__metamorphic_parse.__str__()
 *         elif viewLayerType == ViewLayerType.SEMANTICS:             # <<<<<<<<<<<<<<
 *             return self.__semantic
 *         elif viewLayerType == ViewLayerType.NER:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SEMANTICS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":160
 *                 return self.__metamorphic_parse.__str__()
 *         elif viewLayerType == ViewLayerType.SEMANTICS:
 *             return self.__semantic             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.NER:
 *             if self.__named_entity_type is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->__pyx___semantic);
    __pyx_r = __pyx_v_self->__pyx___semantic;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":159
 *             if self.__metamorphic_parse is not None:
 *                 return self.__metamorphic_parse.__str__()
 *         elif viewLayerType == ViewLayerType.SEMANTICS:             # <<<<<<<<<<<<<<
 *             return self.__semantic
 *         elif viewLayerType == ViewLayerType.NER:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":161
 *         elif viewLayerType == ViewLayerType.SEMANTICS:
 *             return self.__semantic
 *         elif viewLayerType == ViewLayerType.NER:             # <<<<<<<<<<<<<<
 *             if self.__named_entity_type is not None:
 *                 return self.__named_entity_type.__str__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":162
 *             return self.__semantic
 *         elif viewLayerType == ViewLayerType.NER:
 *             if self.__named_entity_type is not None:             # <<<<<<<<<<<<<<
 *                 return self.__named_entity_type.__str__()
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:
 */
    __pyx_t_5 = (__pyx_v_self->__pyx___named_entity_type != Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":163
 *         elif viewLayerType == ViewLayerType.NER:
 *             if self.__named_entity_type is not None:
 *                 return self.__named_entity_type.__str__()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:
 *             return self.__shallow_parse
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx___named_entity_type, __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 163, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":162
 *             return self.__semantic
 *         elif viewLayerType == ViewLayerType.NER:
 *             if self.__named_entity_type is not None:             # <<<<<<<<<<<<<<
 *                 return self.__named_entity_type.__str__()
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":161
 *         elif viewLayerType == ViewLayerType.SEMANTICS:
 *             return self.__semantic
 *         elif viewLayerType == ViewLayerType.NER:             # <<<<<<<<<<<<<<
 *             if self.__named_entity_type is not None:
 *                 return self.__named_entity_type.__str__()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":164
 *             if self.__named_entity_type is not None:
 *                 return self.__named_entity_type.__str__()
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:             # <<<<<<<<<<<<<<
 *             return self.__shallow_parse
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SHALLOW_PARSE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":165
 *                 return self.__named_entity_type.__str__()
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:
 *             return self.__shallow_parse             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:
 *             return self.name
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->__pyx___shallow_parse);
    __pyx_r = __pyx_v_self->__pyx___shallow_parse;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":164
 *             if self.__named_entity_type is not None:
 *                 return self.__named_entity_type.__str__()
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:             # <<<<<<<<<<<<<<
 *             return self.__shallow_parse
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":166
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:
 *             return self.__shallow_parse
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:             # <<<<<<<<<<<<<<
 *             return self.name
 *         elif viewLayerType == ViewLayerType.PROPBANK:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_TURKISH_WORD); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":167
 *             return self.__shallow_parse
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:
 *             return self.name             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.PROPBANK:
 *             if self.__argument is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->__pyx_base.name);
    __pyx_r = __pyx_v_self->__pyx_base.name;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":166
 *         elif viewLayerType == ViewLayerType.SHALLOW_PARSE:
 *             return self.__shallow_parse
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:             # <<<<<<<<<<<<<<
 *             return self.name
 *         elif viewLayerType == ViewLayerType.PROPBANK:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":168
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:
 *             return self.name
 *         elif viewLayerType == ViewLayerType.PROPBANK:             # <<<<<<<<<<<<<<
 *             if self.__argument is not None:
 *                 return self.__argument.__str__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PROPBANK); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":169
 *             return self.name
 *         elif viewLayerType == ViewLayerType.PROPBANK:
 *             if self.__argument is not None:             # <<<<<<<<<<<<<<
 *                 return self.__argument.__str__()
 *         elif viewLayerType == ViewLayerType.FRAMENET:
 */
    __pyx_t_6 = (((PyObject *)__pyx_v_self->__pyx___argument) != Py_None);
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":170
 *         elif viewLayerType == ViewLayerType.PROPBANK:
 *             if self.__argument is not None:
 *                 return self.__argument.__str__()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.FRAMENET:
 *             if self.__frame_element is not None:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___argument), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 170, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":169
 *             return self.name
 *         elif viewLayerType == ViewLayerType.PROPBANK:
 *             if self.__argument is not None:             # <<<<<<<<<<<<<<
 *                 return self.__argument.__str__()
 *         elif viewLayerType == ViewLayerType.FRAMENET:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":168
 *         elif viewLayerType == ViewLayerType.TURKISH_WORD:
 *             return self.name
 *         elif viewLayerType == ViewLayerType.PROPBANK:             # <<<<<<<<<<<<<<
 *             if self.__argument is not None:
 *                 return self.__argument.__str__()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":171
 *             if self.__argument is not None:
 *                 return self.__argument.__str__()
 *         elif viewLayerType == ViewLayerType.FRAMENET:             # <<<<<<<<<<<<<<
 *             if self.__frame_element is not None:
 *                 return self.__frame_element.__str__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_FRAMENET); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":172
 *                 return self.__argument.__str__()
 *         elif viewLayerType == ViewLayerType.FRAMENET:
 *             if self.__frame_element is not None:             # <<<<<<<<<<<<<<
 *                 return self.__frame_element.__str__()
 *         elif viewLayerType == ViewLayerType.SLOT:
 */
    __pyx_t_5 = (((PyObject *)__pyx_v_self->__pyx___frame_element) != Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":173
 *         elif viewLayerType == ViewLayerType.FRAMENET:
 *             if self.__frame_element is not None:
 *                 return self.__frame_element.__str__()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.SLOT:
 *             if self.__slot is not None:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___frame_element), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 173, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":172
 *                 return self.__argument.__str__()
 *         elif viewLayerType == ViewLayerType.FRAMENET:
 *             if self.__frame_element is not None:             # <<<<<<<<<<<<<<
 *                 return self.__frame_element.__str__()
 *         elif viewLayerType == ViewLayerType.SLOT:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":171
 *             if self.__argument is not None:
 *                 return self.__argument.__str__()
 *         elif viewLayerType == ViewLayerType.FRAMENET:             # <<<<<<<<<<<<<<
 *             if self.__frame_element is not None:
 *                 return self.__frame_element.__str__()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":174
 *             if self.__frame_element is not None:
 *                 return self.__frame_element.__str__()
 *         elif viewLayerType == ViewLayerType.SLOT:             # <<<<<<<<<<<<<<
 *             if self.__slot is not None:
 *                 return self.__slot.__str__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SLOT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":175
 *                 return self.__frame_element.__str__()
 *         elif viewLayerType == ViewLayerType.SLOT:
 *             if self.__slot is not None:             # <<<<<<<<<<<<<<
 *                 return self.__slot.__str__()
 *         elif viewLayerType == ViewLayerType.POLARITY:
 */
    __pyx_t_6 = (((PyObject *)__pyx_v_self->__pyx___slot) != Py_None);
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":176
 *         elif viewLayerType == ViewLayerType.SLOT:
 *             if self.__slot is not None:
 *                 return self.__slot.__str__()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.POLARITY:
 *             if self.__polarity is not None:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___slot), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 176, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":175
 *                 return self.__frame_element.__str__()
 *         elif viewLayerType == ViewLayerType.SLOT:
 *             if self.__slot is not None:             # <<<<<<<<<<<<<<
 *                 return self.__slot.__str__()
 *         elif viewLayerType == ViewLayerType.POLARITY:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":174
 *             if self.__frame_element is not None:
 *                 return self.__frame_element.__str__()
 *         elif viewLayerType == ViewLayerType.SLOT:             # <<<<<<<<<<<<<<
 *             if self.__slot is not None:
 *                 return self.__slot.__str__()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":177
 *             if self.__slot is not None:
 *                 return self.__slot.__str__()
 *         elif viewLayerType == ViewLayerType.POLARITY:             # <<<<<<<<<<<<<<
 *             if self.__polarity is not None:
 *                 return self.getPolarityString()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_POLARITY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":178
 *                 return self.__slot.__str__()
 *         elif viewLayerType == ViewLayerType.POLARITY:
 *             if self.__polarity is not None:             # <<<<<<<<<<<<<<
 *                 return self.getPolarityString()
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:
 */
    __pyx_t_5 = (__pyx_v_self->__pyx___polarity != Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":179
 *         elif viewLayerType == ViewLayerType.POLARITY:
 *             if self.__polarity is not None:
 *                 return self.getPolarityString()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:
 *             if self.__universal_dependency is not None:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = ((struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->getPolarityString(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":178
 *                 return self.__slot.__str__()
 *         elif viewLayerType == ViewLayerType.POLARITY:
 *             if self.__polarity is not None:             # <<<<<<<<<<<<<<
 *                 return self.getPolarityString()
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":177
 *             if self.__slot is not None:
 *                 return self.__slot.__str__()
 *         elif viewLayerType == ViewLayerType.POLARITY:             # <<<<<<<<<<<<<<
 *             if self.__polarity is not None:
 *                 return self.getPolarityString()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":180
 *             if self.__polarity is not None:
 *                 return self.getPolarityString()
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:             # <<<<<<<<<<<<<<
 *             if self.__universal_dependency is not None:
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEPENDENCY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":181
 *                 return self.getPolarityString()
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:
 *             if self.__universal_dependency is not None:             # <<<<<<<<<<<<<<
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()
 *         elif viewLayerType == ViewLayerType.CCG:
 */
    __pyx_t_6 = (((PyObject *)__pyx_v_self->__pyx___universal_dependency) != Py_None);
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":182
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:
 *             if self.__universal_dependency is not None:
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.CCG:
 *             return self.__ccg
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_v_self->__pyx___universal_dependency->__pyx_base.__pyx_vtab)->__pyx_base.to(((struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation *)__pyx_v_self->__pyx___universal_dependency), 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___universal_dependency), __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 182, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":181
 *                 return self.getPolarityString()
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:
 *             if self.__universal_dependency is not None:             # <<<<<<<<<<<<<<
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()
 *         elif viewLayerType == ViewLayerType.CCG:
 */
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":180
 *             if self.__polarity is not None:
 *                 return self.getPolarityString()
 *         elif viewLayerType == ViewLayerType.DEPENDENCY:             # <<<<<<<<<<<<<<
 *             if self.__universal_dependency is not None:
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":183
 *             if self.__universal_dependency is not None:
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()
 *         elif viewLayerType == ViewLayerType.CCG:             # <<<<<<<<<<<<<<
 *             return self.__ccg
 *         elif viewLayerType == ViewLayerType.POS_TAG:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_CCG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":184
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()
 *         elif viewLayerType == ViewLayerType.CCG:
 *             return self.__ccg             # <<<<<<<<<<<<<<
 *         elif viewLayerType == ViewLayerType.POS_TAG:
 *             return self.__pos_tag
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->__pyx___ccg);
    __pyx_r = __pyx_v_self->__pyx___ccg;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":183
 *             if self.__universal_dependency is not None:
 *                 return self.__universal_dependency.to().__str__() + "$" + self.__universal_dependency.__str__()
 *         elif viewLayerType == ViewLayerType.CCG:             # <<<<<<<<<<<<<<
 *             return self.__ccg
 *         elif viewLayerType == ViewLayerType.POS_TAG:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":185
 *         elif viewLayerType == ViewLayerType.CCG:
 *             return self.__ccg
 *         elif viewLayerType == ViewLayerType.POS_TAG:             # <<<<<<<<<<<<<<
 *             return self.__pos_tag
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_POS_TAG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_viewLayerType, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":186
 *             return self.__ccg
 *         elif viewLayerType == ViewLayerType.POS_TAG:
 *             return self.__pos_tag             # <<<<<<<<<<<<<<
 *         else:
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->__pyx___pos_tag);
    __pyx_r = __pyx_v_self->__pyx___pos_tag;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":185
 *         elif viewLayerType == ViewLayerType.CCG:
 *             return self.__ccg
 *         elif viewLayerType == ViewLayerType.POS_TAG:             # <<<<<<<<<<<<<<
 *             return self.__pos_tag
 *         else:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":188
 *             return self.__pos_tag
 *         else:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *     cpdef MorphologicalParse getParse(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":139
 *         return result
 * 
 *     cpdef str getLayerInfo(self, object viewLayerType):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the value of a given layer.
 */

  /* function exit code */
  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getLayerInfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_5getLayerInfo(PyObject *__pyx_v_self, PyObject *__pyx_v_viewLayerType); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_4getLayerInfo[] = "\n        Returns the value of a given layer.\n\n        PARAMETERS\n        ----------\n        viewLayerType : ViewLayerType\n            Layer for which the value questioned.\n\n        RETURNS\n        -------\n        str\n            The value of the given layer.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_5getLayerInfo(PyObject *__pyx_v_self, PyObject *__pyx_v_viewLayerType) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLayerInfo (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_4getLayerInfo(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject *)__pyx_v_viewLayerType));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_4getLayerInfo(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_viewLayerType) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLayerInfo", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLayerInfo(__pyx_v_self, __pyx_v_viewLayerType, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getLayerInfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":190
 *             return None
 * 
 *     cpdef MorphologicalParse getParse(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the morphological parse layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_7getParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_7getParse)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse))))) __PYX_ERR(0, 190, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":199
 *             The morphological parse of the word.
 *         """
 *         return self.__parse             # <<<<<<<<<<<<<<
 * 
 *     cpdef setParse(self, str parseString):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___parse));
  __pyx_r = __pyx_v_self->__pyx___parse;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":190
 *             return None
 * 
 *     cpdef MorphologicalParse getParse(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the morphological parse layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_7getParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_6getParse[] = "\n        Returns the morphological parse layer of the word.\n\n        RETURNS\n        -------\n        MorphologicalParse\n            The morphological parse of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_7getParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getParse (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_6getParse(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_6getParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getParse(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":201
 *         return self.__parse
 * 
 *     cpdef setParse(self, str parseString):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the morphological parse layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_9setParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parseString); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_9setParse)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_parseString) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_parseString);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 201, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":210
 *             The new morphological parse of the word in string form.
 *         """
 *         if parseString is not None:             # <<<<<<<<<<<<<<
 *             self.__parse = MorphologicalParse(parseString)
 *         else:
 */
  __pyx_t_5 = (__pyx_v_parseString != ((PyObject*)Py_None));
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":211
 *         """
 *         if parseString is not None:
 *             self.__parse = MorphologicalParse(parseString)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__parse = None
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), __pyx_v_parseString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___parse);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___parse));
    __pyx_v_self->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":210
 *             The new morphological parse of the word in string form.
 *         """
 *         if parseString is not None:             # <<<<<<<<<<<<<<
 *             self.__parse = MorphologicalParse(parseString)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":213
 *             self.__parse = MorphologicalParse(parseString)
 *         else:
 *             self.__parse = None             # <<<<<<<<<<<<<<
 * 
 *     cpdef MetamorphicParse getMetamorphicParse(self):
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___parse);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___parse));
    __pyx_v_self->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)Py_None);
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":201
 *         return self.__parse
 * 
 *     cpdef setParse(self, str parseString):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the morphological parse layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_9setParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parseString); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_8setParse[] = "\n        Sets the morphological parse layer of the word.\n\n        PARAMETERS\n        ----------\n        parseString : str\n            The new morphological parse of the word in string form.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_9setParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parseString) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setParse (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_parseString), (&PyUnicode_Type), 1, "parseString", 1))) __PYX_ERR(0, 201, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_8setParse(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_parseString));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_8setParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setParse(__pyx_v_self, __pyx_v_parseString, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":215
 *             self.__parse = None
 * 
 *     cpdef MetamorphicParse getMetamorphicParse(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the metamorphic parse layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_11getMetamorphicParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getMetamorphicParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getMetamorphicParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_11getMetamorphicParse)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse))))) __PYX_ERR(0, 215, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":224
 *             The metamorphic parse of the word.
 *         """
 *         return self.__metamorphic_parse             # <<<<<<<<<<<<<<
 * 
 *     cpdef setMetamorphicParse(self, str parseString):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse));
  __pyx_r = __pyx_v_self->__pyx___metamorphic_parse;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":215
 *             self.__parse = None
 * 
 *     cpdef MetamorphicParse getMetamorphicParse(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the metamorphic parse layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getMetamorphicParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_11getMetamorphicParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_10getMetamorphicParse[] = "\n        Returns the metamorphic parse layer of the word.\n\n        RETURNS\n        -------\n        MetamorphicParse\n            The metamorphic parse of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_11getMetamorphicParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getMetamorphicParse (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_10getMetamorphicParse(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_10getMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getMetamorphicParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getMetamorphicParse(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getMetamorphicParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":226
 *         return self.__metamorphic_parse
 * 
 *     cpdef setMetamorphicParse(self, str parseString):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the metamorphic parse layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_13setMetamorphicParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parseString); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setMetamorphicParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setMetamorphicParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_13setMetamorphicParse)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_parseString) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_parseString);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 226, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":235
 *             The new metamorphic parse of the word in string form.
 *         """
 *         self.__metamorphic_parse = MetamorphicParse(parseString)             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getSemantic(self):
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse), __pyx_v_parseString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx___metamorphic_parse);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse));
  __pyx_v_self->__pyx___metamorphic_parse = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":226
 *         return self.__metamorphic_parse
 * 
 *     cpdef setMetamorphicParse(self, str parseString):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the metamorphic parse layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setMetamorphicParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_13setMetamorphicParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parseString); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_12setMetamorphicParse[] = "\n        Sets the metamorphic parse layer of the word.\n\n        PARAMETERS\n        ----------\n        parseString : str\n            The new metamorphic parse of the word in string form.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_13setMetamorphicParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parseString) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setMetamorphicParse (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_parseString), (&PyUnicode_Type), 1, "parseString", 1))) __PYX_ERR(0, 226, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_12setMetamorphicParse(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_parseString));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_12setMetamorphicParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parseString) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setMetamorphicParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setMetamorphicParse(__pyx_v_self, __pyx_v_parseString, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setMetamorphicParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":237
 *         self.__metamorphic_parse = MetamorphicParse(parseString)
 * 
 *     cpdef str getSemantic(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the semantic layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_15getSemantic(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSemantic", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getSemantic); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_15getSemantic)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 237, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":246
 *             Sense id of the word.
 *         """
 *         return self.__semantic             # <<<<<<<<<<<<<<
 * 
 *     cpdef setSemantic(self, str semantic):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___semantic);
  __pyx_r = __pyx_v_self->__pyx___semantic;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":237
 *         self.__metamorphic_parse = MetamorphicParse(parseString)
 * 
 *     cpdef str getSemantic(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the semantic layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getSemantic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_15getSemantic(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_14getSemantic[] = "\n        Returns the semantic layer of the word.\n\n        RETURNS\n        -------\n        str\n            Sense id of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_15getSemantic(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSemantic (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_14getSemantic(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_14getSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSemantic", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSemantic(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getSemantic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":248
 *         return self.__semantic
 * 
 *     cpdef setSemantic(self, str semantic):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the semantic layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_17setSemantic(PyObject *__pyx_v_self, PyObject *__pyx_v_semantic); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_semantic, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setSemantic", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setSemantic); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_17setSemantic)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_semantic) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_semantic);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":257
 *             New sense id of the word.
 *         """
 *         self.__semantic = semantic             # <<<<<<<<<<<<<<
 * 
 *     cpdef object getNamedEntityType(self):
 */
  __Pyx_INCREF(__pyx_v_semantic);
  __Pyx_GIVEREF(__pyx_v_semantic);
  __Pyx_GOTREF(__pyx_v_self->__pyx___semantic);
  __Pyx_DECREF(__pyx_v_self->__pyx___semantic);
  __pyx_v_self->__pyx___semantic = __pyx_v_semantic;

  /* "AnnotatedSentence/AnnotatedWord.pyx":248
 *         return self.__semantic
 * 
 *     cpdef setSemantic(self, str semantic):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the semantic layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setSemantic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_17setSemantic(PyObject *__pyx_v_self, PyObject *__pyx_v_semantic); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_16setSemantic[] = "\n        Sets the semantic layer of the word.\n\n        PARAMETERS\n        ----------\n        semantic : str\n            New sense id of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_17setSemantic(PyObject *__pyx_v_self, PyObject *__pyx_v_semantic) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setSemantic (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_semantic), (&PyUnicode_Type), 1, "semantic", 1))) __PYX_ERR(0, 248, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_16setSemantic(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_semantic));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_16setSemantic(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_semantic) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setSemantic", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSemantic(__pyx_v_self, __pyx_v_semantic, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setSemantic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":259
 *         self.__semantic = semantic
 * 
 *     cpdef object getNamedEntityType(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named entity layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_19getNamedEntityType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNamedEntityType", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getNamedEntityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_19getNamedEntityType)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":268
 *             Named entity tag of the word.
 *         """
 *         return self.__named_entity_type             # <<<<<<<<<<<<<<
 * 
 *     cpdef setNamedEntityType(self, str namedEntity):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___named_entity_type);
  __pyx_r = __pyx_v_self->__pyx___named_entity_type;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":259
 *         self.__semantic = semantic
 * 
 *     cpdef object getNamedEntityType(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named entity layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getNamedEntityType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_19getNamedEntityType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_18getNamedEntityType[] = "\n        Returns the named entity layer of the word.\n\n        RETURNS\n        -------\n        NamedEntityType\n            Named entity tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_19getNamedEntityType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNamedEntityType (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_18getNamedEntityType(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_18getNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNamedEntityType", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getNamedEntityType(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getNamedEntityType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":270
 *         return self.__named_entity_type
 * 
 *     cpdef setNamedEntityType(self, str namedEntity):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the named entity layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_21setNamedEntityType(PyObject *__pyx_v_self, PyObject *__pyx_v_namedEntity); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_namedEntity, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setNamedEntityType", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setNamedEntityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_21setNamedEntityType)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_namedEntity) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_namedEntity);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 270, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":279
 *             New named entity tag of the word.
 *         """
 *         if namedEntity is not None:             # <<<<<<<<<<<<<<
 *             self.__named_entity_type = NamedEntityType.getNamedEntityType(namedEntity)
 *         else:
 */
  __pyx_t_5 = (__pyx_v_namedEntity != ((PyObject*)Py_None));
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":280
 *         """
 *         if namedEntity is not None:
 *             self.__named_entity_type = NamedEntityType.getNamedEntityType(namedEntity)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__named_entity_type = None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NamedEntityType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getNamedEntityType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_namedEntity) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_namedEntity);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___named_entity_type);
    __Pyx_DECREF(__pyx_v_self->__pyx___named_entity_type);
    __pyx_v_self->__pyx___named_entity_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":279
 *             New named entity tag of the word.
 *         """
 *         if namedEntity is not None:             # <<<<<<<<<<<<<<
 *             self.__named_entity_type = NamedEntityType.getNamedEntityType(namedEntity)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":282
 *             self.__named_entity_type = NamedEntityType.getNamedEntityType(namedEntity)
 *         else:
 *             self.__named_entity_type = None             # <<<<<<<<<<<<<<
 * 
 *     cpdef Argument getArgument(self):
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___named_entity_type);
    __Pyx_DECREF(__pyx_v_self->__pyx___named_entity_type);
    __pyx_v_self->__pyx___named_entity_type = Py_None;
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":270
 *         return self.__named_entity_type
 * 
 *     cpdef setNamedEntityType(self, str namedEntity):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the named entity layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setNamedEntityType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_21setNamedEntityType(PyObject *__pyx_v_self, PyObject *__pyx_v_namedEntity); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_20setNamedEntityType[] = "\n        Sets the named entity layer of the word.\n\n        PARAMETERS\n        ----------\n        namedEntity : str\n            New named entity tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_21setNamedEntityType(PyObject *__pyx_v_self, PyObject *__pyx_v_namedEntity) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setNamedEntityType (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_namedEntity), (&PyUnicode_Type), 1, "namedEntity", 1))) __PYX_ERR(0, 270, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_20setNamedEntityType(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_namedEntity));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_20setNamedEntityType(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_namedEntity) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setNamedEntityType", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setNamedEntityType(__pyx_v_self, __pyx_v_namedEntity, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setNamedEntityType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":284
 *             self.__named_entity_type = None
 * 
 *     cpdef Argument getArgument(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the semantic role layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_23getArgument(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_8PropBank_8Argument_Argument *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_8PropBank_8Argument_Argument *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getArgument", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_23getArgument)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 284, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_8PropBank_8Argument_Argument))))) __PYX_ERR(0, 284, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_8PropBank_8Argument_Argument *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":293
 *             Semantic role tag of the word.
 *         """
 *         return self.__argument             # <<<<<<<<<<<<<<
 * 
 *     cpdef setArgument(self, str argument):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___argument));
  __pyx_r = __pyx_v_self->__pyx___argument;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":284
 *             self.__named_entity_type = None
 * 
 *     cpdef Argument getArgument(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the semantic role layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getArgument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_23getArgument(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_22getArgument[] = "\n        Returns the semantic role layer of the word.\n\n        RETURNS\n        -------\n        Argument\n            Semantic role tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_23getArgument(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getArgument (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_22getArgument(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_22getArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getArgument", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getArgument(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getArgument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":295
 *         return self.__argument
 * 
 *     cpdef setArgument(self, str argument):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the semantic role layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_25setArgument(PyObject *__pyx_v_self, PyObject *__pyx_v_argument); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_argument, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setArgument", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_25setArgument)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_argument) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_argument);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 295, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":304
 *             New semantic role tag of the word.
 *         """
 *         if argument is not None:             # <<<<<<<<<<<<<<
 *             self.__argument = Argument(argument)
 *         else:
 */
  __pyx_t_5 = (__pyx_v_argument != ((PyObject*)Py_None));
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":305
 *         """
 *         if argument is not None:
 *             self.__argument = Argument(argument)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__argument = None
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_8PropBank_8Argument_Argument), __pyx_v_argument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___argument);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___argument));
    __pyx_v_self->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":304
 *             New semantic role tag of the word.
 *         """
 *         if argument is not None:             # <<<<<<<<<<<<<<
 *             self.__argument = Argument(argument)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":307
 *             self.__argument = Argument(argument)
 *         else:
 *             self.__argument = None             # <<<<<<<<<<<<<<
 * 
 *     cpdef FrameElement getFrameElement(self):
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___argument);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___argument));
    __pyx_v_self->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)Py_None);
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":295
 *         return self.__argument
 * 
 *     cpdef setArgument(self, str argument):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the semantic role layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setArgument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_25setArgument(PyObject *__pyx_v_self, PyObject *__pyx_v_argument); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_24setArgument[] = "\n        Sets the semantic role layer of the word.\n\n        PARAMETERS\n        ----------\n        argument : Argument\n            New semantic role tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_25setArgument(PyObject *__pyx_v_self, PyObject *__pyx_v_argument) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setArgument (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_argument), (&PyUnicode_Type), 1, "argument", 1))) __PYX_ERR(0, 295, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_24setArgument(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_argument));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_24setArgument(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_argument) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setArgument", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setArgument(__pyx_v_self, __pyx_v_argument, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setArgument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":309
 *             self.__argument = None
 * 
 *     cpdef FrameElement getFrameElement(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the framenet layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_27getFrameElement(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFrameElement", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getFrameElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_27getFrameElement)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 309, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_8FrameNet_12FrameElement_FrameElement))))) __PYX_ERR(0, 309, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":318
 *             Framenet tag of the word.
 *         """
 *         return self.__frame_element             # <<<<<<<<<<<<<<
 * 
 *     cpdef setFrameElement(self, str frameElement):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___frame_element));
  __pyx_r = __pyx_v_self->__pyx___frame_element;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":309
 *             self.__argument = None
 * 
 *     cpdef FrameElement getFrameElement(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the framenet layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getFrameElement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_27getFrameElement(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_26getFrameElement[] = "\n        Returns the framenet layer of the word.\n\n        RETURNS\n        -------\n        FrameElement\n            Framenet tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_27getFrameElement(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFrameElement (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_26getFrameElement(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_26getFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFrameElement", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFrameElement(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getFrameElement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":320
 *         return self.__frame_element
 * 
 *     cpdef setFrameElement(self, str frameElement):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the framenet layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_29setFrameElement(PyObject *__pyx_v_self, PyObject *__pyx_v_frameElement); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_frameElement, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setFrameElement", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setFrameElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_29setFrameElement)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_frameElement) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_frameElement);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 320, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":329
 *             New framenet tag of the word.
 *         """
 *         if frameElement is not None:             # <<<<<<<<<<<<<<
 *             self.__frame_element = Argument(frameElement)
 *         else:
 */
  __pyx_t_5 = (__pyx_v_frameElement != ((PyObject*)Py_None));
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":330
 *         """
 *         if frameElement is not None:
 *             self.__frame_element = Argument(frameElement)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__frame_element = None
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_8PropBank_8Argument_Argument), __pyx_v_frameElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_8FrameNet_12FrameElement_FrameElement)))) __PYX_ERR(0, 330, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___frame_element);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___frame_element));
    __pyx_v_self->__pyx___frame_element = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":329
 *             New framenet tag of the word.
 *         """
 *         if frameElement is not None:             # <<<<<<<<<<<<<<
 *             self.__frame_element = Argument(frameElement)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":332
 *             self.__frame_element = Argument(frameElement)
 *         else:
 *             self.__frame_element = None             # <<<<<<<<<<<<<<
 * 
 *     cpdef Slot getSlot(self):
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___frame_element);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___frame_element));
    __pyx_v_self->__pyx___frame_element = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)Py_None);
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":320
 *         return self.__frame_element
 * 
 *     cpdef setFrameElement(self, str frameElement):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the framenet layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setFrameElement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_29setFrameElement(PyObject *__pyx_v_self, PyObject *__pyx_v_frameElement); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_28setFrameElement[] = "\n        Sets the framenet layer of the word.\n\n        PARAMETERS\n        ----------\n        frameElement : str\n            New framenet tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_29setFrameElement(PyObject *__pyx_v_self, PyObject *__pyx_v_frameElement) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setFrameElement (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_frameElement), (&PyUnicode_Type), 1, "frameElement", 1))) __PYX_ERR(0, 320, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_28setFrameElement(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_frameElement));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_28setFrameElement(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_frameElement) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setFrameElement", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setFrameElement(__pyx_v_self, __pyx_v_frameElement, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setFrameElement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":334
 *             self.__frame_element = None
 * 
 *     cpdef Slot getSlot(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the slot layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_31getSlot(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSlot", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getSlot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_31getSlot)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_22NamedEntityRecognition_4Slot_Slot))))) __PYX_ERR(0, 334, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":343
 *             Slot tag of the word.
 *         """
 *         return self.__slot             # <<<<<<<<<<<<<<
 * 
 *     cpdef setSlot(self, str slot):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___slot));
  __pyx_r = __pyx_v_self->__pyx___slot;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":334
 *             self.__frame_element = None
 * 
 *     cpdef Slot getSlot(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the slot layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getSlot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_31getSlot(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_30getSlot[] = "\n        Returns the slot layer of the word.\n\n        RETURNS\n        -------\n        Slot\n            Slot tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_31getSlot(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSlot (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_30getSlot(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_30getSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSlot", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSlot(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getSlot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":345
 *         return self.__slot
 * 
 *     cpdef setSlot(self, str slot):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the slot layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_33setSlot(PyObject *__pyx_v_self, PyObject *__pyx_v_slot); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_slot, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setSlot", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setSlot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 345, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_33setSlot)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_slot) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_slot);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":354
 *             New slot tag of the word.
 *         """
 *         if slot is not None:             # <<<<<<<<<<<<<<
 *             self.__slot = Slot(slot)
 *         else:
 */
  __pyx_t_5 = (__pyx_v_slot != ((PyObject*)Py_None));
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":355
 *         """
 *         if slot is not None:
 *             self.__slot = Slot(slot)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__slot = None
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_22NamedEntityRecognition_4Slot_Slot), __pyx_v_slot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 355, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___slot);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___slot));
    __pyx_v_self->__pyx___slot = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":354
 *             New slot tag of the word.
 *         """
 *         if slot is not None:             # <<<<<<<<<<<<<<
 *             self.__slot = Slot(slot)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":357
 *             self.__slot = Slot(slot)
 *         else:
 *             self.__slot = None             # <<<<<<<<<<<<<<
 * 
 *     cpdef object getPolarity(self):
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___slot);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___slot));
    __pyx_v_self->__pyx___slot = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)Py_None);
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":345
 *         return self.__slot
 * 
 *     cpdef setSlot(self, str slot):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the slot layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setSlot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_33setSlot(PyObject *__pyx_v_self, PyObject *__pyx_v_slot); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_32setSlot[] = "\n        Sets the slot layer of the word.\n\n        PARAMETERS\n        ----------\n        slot : str\n            New slot tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_33setSlot(PyObject *__pyx_v_self, PyObject *__pyx_v_slot) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setSlot (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_slot), (&PyUnicode_Type), 1, "slot", 1))) __PYX_ERR(0, 345, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_32setSlot(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_slot));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_32setSlot(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_slot) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setSlot", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSlot(__pyx_v_self, __pyx_v_slot, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setSlot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":359
 *             self.__slot = None
 * 
 *     cpdef object getPolarity(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the polarity layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_35getPolarity(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPolarity", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPolarity); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_35getPolarity)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":368
 *             Polarity tag of the word.
 *         """
 *         return self.__polarity             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getPolarityString(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___polarity);
  __pyx_r = __pyx_v_self->__pyx___polarity;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":359
 *             self.__slot = None
 * 
 *     cpdef object getPolarity(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the polarity layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getPolarity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_35getPolarity(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_34getPolarity[] = "\n        Returns the polarity layer of the word.\n\n        RETURNS\n        -------\n        PolarityType\n            Polarity tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_35getPolarity(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPolarity (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_34getPolarity(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_34getPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPolarity", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarity(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getPolarity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":370
 *         return self.__polarity
 * 
 *     cpdef str getPolarityString(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the polarity layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_37getPolarityString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarityString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPolarityString", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPolarityString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_37getPolarityString)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 370, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":379
 *             Polarity string of the word.
 *         """
 *         if self.__polarity == PolarityType.POSITIVE:             # <<<<<<<<<<<<<<
 *             return "positive"
 *         elif self.__polarity == PolarityType.NEGATIVE:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PolarityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_POSITIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->__pyx___polarity, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":380
 *         """
 *         if self.__polarity == PolarityType.POSITIVE:
 *             return "positive"             # <<<<<<<<<<<<<<
 *         elif self.__polarity == PolarityType.NEGATIVE:
 *             return "negative"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_positive);
    __pyx_r = __pyx_n_u_positive;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":379
 *             Polarity string of the word.
 *         """
 *         if self.__polarity == PolarityType.POSITIVE:             # <<<<<<<<<<<<<<
 *             return "positive"
 *         elif self.__polarity == PolarityType.NEGATIVE:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":381
 *         if self.__polarity == PolarityType.POSITIVE:
 *             return "positive"
 *         elif self.__polarity == PolarityType.NEGATIVE:             # <<<<<<<<<<<<<<
 *             return "negative"
 *         elif self.__polarity == PolarityType.NEUTRAL:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PolarityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NEGATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->__pyx___polarity, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":382
 *             return "positive"
 *         elif self.__polarity == PolarityType.NEGATIVE:
 *             return "negative"             # <<<<<<<<<<<<<<
 *         elif self.__polarity == PolarityType.NEUTRAL:
 *             return "neutral"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_negative);
    __pyx_r = __pyx_n_u_negative;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":381
 *         if self.__polarity == PolarityType.POSITIVE:
 *             return "positive"
 *         elif self.__polarity == PolarityType.NEGATIVE:             # <<<<<<<<<<<<<<
 *             return "negative"
 *         elif self.__polarity == PolarityType.NEUTRAL:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":383
 *         elif self.__polarity == PolarityType.NEGATIVE:
 *             return "negative"
 *         elif self.__polarity == PolarityType.NEUTRAL:             # <<<<<<<<<<<<<<
 *             return "neutral"
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PolarityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NEUTRAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->__pyx___polarity, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":384
 *             return "negative"
 *         elif self.__polarity == PolarityType.NEUTRAL:
 *             return "neutral"             # <<<<<<<<<<<<<<
 *         else:
 *             return "neutral"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_neutral);
    __pyx_r = __pyx_n_u_neutral;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":383
 *         elif self.__polarity == PolarityType.NEGATIVE:
 *             return "negative"
 *         elif self.__polarity == PolarityType.NEUTRAL:             # <<<<<<<<<<<<<<
 *             return "neutral"
 *         else:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":386
 *             return "neutral"
 *         else:
 *             return "neutral"             # <<<<<<<<<<<<<<
 * 
 *     cpdef setPolarity(self, str polarity):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_neutral);
    __pyx_r = __pyx_n_u_neutral;
    goto __pyx_L0;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":370
 *         return self.__polarity
 * 
 *     cpdef str getPolarityString(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the polarity layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getPolarityString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_37getPolarityString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_36getPolarityString[] = "\n        Returns the polarity layer of the word.\n\n        RETURNS\n        -------\n        str\n            Polarity string of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_37getPolarityString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPolarityString (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_36getPolarityString(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_36getPolarityString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPolarityString", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarityString(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getPolarityString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":388
 *             return "neutral"
 * 
 *     cpdef setPolarity(self, str polarity):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the polarity layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_39setPolarity(PyObject *__pyx_v_self, PyObject *__pyx_v_polarity); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_polarity, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setPolarity", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setPolarity); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_39setPolarity)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_polarity) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_polarity);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 388, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":397
 *             New polarity tag of the word.
 *         """
 *         if polarity is not None:             # <<<<<<<<<<<<<<
 *             if polarity == "positive" or polarity == "pos":
 *                 self.__polarity = PolarityType.POSITIVE
 */
  __pyx_t_5 = (__pyx_v_polarity != ((PyObject*)Py_None));
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":398
 *         """
 *         if polarity is not None:
 *             if polarity == "positive" or polarity == "pos":             # <<<<<<<<<<<<<<
 *                 self.__polarity = PolarityType.POSITIVE
 *             elif polarity == "negative" or polarity == "neg":
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_polarity, __pyx_n_u_positive, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 398, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_polarity, __pyx_n_u_pos, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 398, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_7 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_6) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":399
 *         if polarity is not None:
 *             if polarity == "positive" or polarity == "pos":
 *                 self.__polarity = PolarityType.POSITIVE             # <<<<<<<<<<<<<<
 *             elif polarity == "negative" or polarity == "neg":
 *                 self.__polarity = PolarityType.NEGATIVE
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PolarityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_POSITIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_v_self->__pyx___polarity);
      __Pyx_DECREF(__pyx_v_self->__pyx___polarity);
      __pyx_v_self->__pyx___polarity = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":398
 *         """
 *         if polarity is not None:
 *             if polarity == "positive" or polarity == "pos":             # <<<<<<<<<<<<<<
 *                 self.__polarity = PolarityType.POSITIVE
 *             elif polarity == "negative" or polarity == "neg":
 */
      goto __pyx_L4;
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":400
 *             if polarity == "positive" or polarity == "pos":
 *                 self.__polarity = PolarityType.POSITIVE
 *             elif polarity == "negative" or polarity == "neg":             # <<<<<<<<<<<<<<
 *                 self.__polarity = PolarityType.NEGATIVE
 *             else:
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_polarity, __pyx_n_u_negative, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 400, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_polarity, __pyx_n_u_neg, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 400, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_7 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_6) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":401
 *                 self.__polarity = PolarityType.POSITIVE
 *             elif polarity == "negative" or polarity == "neg":
 *                 self.__polarity = PolarityType.NEGATIVE             # <<<<<<<<<<<<<<
 *             else:
 *                 self.__polarity = PolarityType.NEUTRAL
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PolarityType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_NEGATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->__pyx___polarity);
      __Pyx_DECREF(__pyx_v_self->__pyx___polarity);
      __pyx_v_self->__pyx___polarity = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":400
 *             if polarity == "positive" or polarity == "pos":
 *                 self.__polarity = PolarityType.POSITIVE
 *             elif polarity == "negative" or polarity == "neg":             # <<<<<<<<<<<<<<
 *                 self.__polarity = PolarityType.NEGATIVE
 *             else:
 */
      goto __pyx_L4;
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":403
 *                 self.__polarity = PolarityType.NEGATIVE
 *             else:
 *                 self.__polarity = PolarityType.NEUTRAL             # <<<<<<<<<<<<<<
 *         else:
 *             self.__polarity = None
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PolarityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NEUTRAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 403, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_v_self->__pyx___polarity);
      __Pyx_DECREF(__pyx_v_self->__pyx___polarity);
      __pyx_v_self->__pyx___polarity = __pyx_t_2;
      __pyx_t_2 = 0;
    }
    __pyx_L4:;

    /* "AnnotatedSentence/AnnotatedWord.pyx":397
 *             New polarity tag of the word.
 *         """
 *         if polarity is not None:             # <<<<<<<<<<<<<<
 *             if polarity == "positive" or polarity == "pos":
 *                 self.__polarity = PolarityType.POSITIVE
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":405
 *                 self.__polarity = PolarityType.NEUTRAL
 *         else:
 *             self.__polarity = None             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getShallowParse(self):
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___polarity);
    __Pyx_DECREF(__pyx_v_self->__pyx___polarity);
    __pyx_v_self->__pyx___polarity = Py_None;
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":388
 *             return "neutral"
 * 
 *     cpdef setPolarity(self, str polarity):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the polarity layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setPolarity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_39setPolarity(PyObject *__pyx_v_self, PyObject *__pyx_v_polarity); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_38setPolarity[] = "\n        Sets the polarity layer of the word.\n\n        PARAMETERS\n        ----------\n        polarity : str\n            New polarity tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_39setPolarity(PyObject *__pyx_v_self, PyObject *__pyx_v_polarity) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setPolarity (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_polarity), (&PyUnicode_Type), 1, "polarity", 1))) __PYX_ERR(0, 388, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_38setPolarity(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_polarity));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_38setPolarity(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_polarity) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setPolarity", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPolarity(__pyx_v_self, __pyx_v_polarity, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setPolarity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":407
 *             self.__polarity = None
 * 
 *     cpdef str getShallowParse(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the shallow parse layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_41getShallowParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getShallowParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getShallowParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_41getShallowParse)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 407, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":416
 *             Shallow parse tag of the word.
 *         """
 *         return self.__shallow_parse             # <<<<<<<<<<<<<<
 * 
 *     cpdef setShallowParse(self, str parse):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___shallow_parse);
  __pyx_r = __pyx_v_self->__pyx___shallow_parse;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":407
 *             self.__polarity = None
 * 
 *     cpdef str getShallowParse(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the shallow parse layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getShallowParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_41getShallowParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_40getShallowParse[] = "\n        Returns the shallow parse layer of the word.\n\n        RETURNS\n        -------\n        str\n            Shallow parse tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_41getShallowParse(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getShallowParse (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_40getShallowParse(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_40getShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getShallowParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getShallowParse(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getShallowParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":418
 *         return self.__shallow_parse
 * 
 *     cpdef setShallowParse(self, str parse):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the shallow parse layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_43setShallowParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parse); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parse, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setShallowParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setShallowParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_43setShallowParse)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_parse) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_parse);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 418, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":427
 *             New shallow parse tag of the word.
 *         """
 *         self.__shallow_parse = parse             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getCcg(self):
 */
  __Pyx_INCREF(__pyx_v_parse);
  __Pyx_GIVEREF(__pyx_v_parse);
  __Pyx_GOTREF(__pyx_v_self->__pyx___shallow_parse);
  __Pyx_DECREF(__pyx_v_self->__pyx___shallow_parse);
  __pyx_v_self->__pyx___shallow_parse = __pyx_v_parse;

  /* "AnnotatedSentence/AnnotatedWord.pyx":418
 *         return self.__shallow_parse
 * 
 *     cpdef setShallowParse(self, str parse):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the shallow parse layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setShallowParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_43setShallowParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parse); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_42setShallowParse[] = "\n        Sets the shallow parse layer of the word.\n\n        PARAMETERS\n        ----------\n        parse : str\n            New shallow parse tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_43setShallowParse(PyObject *__pyx_v_self, PyObject *__pyx_v_parse) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setShallowParse (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_parse), (&PyUnicode_Type), 1, "parse", 1))) __PYX_ERR(0, 418, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_42setShallowParse(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_parse));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_42setShallowParse(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_parse) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setShallowParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setShallowParse(__pyx_v_self, __pyx_v_parse, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setShallowParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":429
 *         self.__shallow_parse = parse
 * 
 *     cpdef str getCcg(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the ccg layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_45getCcg(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCcg", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getCcg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_45getCcg)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 429, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":438
 *             Ccg tag of the word.
 *         """
 *         return self.__ccg             # <<<<<<<<<<<<<<
 * 
 *     cpdef setCcg(self, str ccg):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___ccg);
  __pyx_r = __pyx_v_self->__pyx___ccg;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":429
 *         self.__shallow_parse = parse
 * 
 *     cpdef str getCcg(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the ccg layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getCcg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_45getCcg(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_44getCcg[] = "\n        Returns the ccg layer of the word.\n\n        RETURNS\n        -------\n        str\n            Ccg tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_45getCcg(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCcg (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_44getCcg(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_44getCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCcg", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getCcg(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getCcg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":440
 *         return self.__ccg
 * 
 *     cpdef setCcg(self, str ccg):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the ccg layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_47setCcg(PyObject *__pyx_v_self, PyObject *__pyx_v_ccg); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_ccg, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setCcg", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setCcg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_47setCcg)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_ccg) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_ccg);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 440, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":449
 *             New ccg tag of the word.
 *         """
 *         self.__ccg = ccg             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getPosTag(self):
 */
  __Pyx_INCREF(__pyx_v_ccg);
  __Pyx_GIVEREF(__pyx_v_ccg);
  __Pyx_GOTREF(__pyx_v_self->__pyx___ccg);
  __Pyx_DECREF(__pyx_v_self->__pyx___ccg);
  __pyx_v_self->__pyx___ccg = __pyx_v_ccg;

  /* "AnnotatedSentence/AnnotatedWord.pyx":440
 *         return self.__ccg
 * 
 *     cpdef setCcg(self, str ccg):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the ccg layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setCcg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_47setCcg(PyObject *__pyx_v_self, PyObject *__pyx_v_ccg); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_46setCcg[] = "\n        Sets the ccg layer of the word.\n\n        PARAMETERS\n        ----------\n        parse : str\n            New ccg tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_47setCcg(PyObject *__pyx_v_self, PyObject *__pyx_v_ccg) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setCcg (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ccg), (&PyUnicode_Type), 1, "ccg", 1))) __PYX_ERR(0, 440, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_46setCcg(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_ccg));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_46setCcg(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_ccg) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setCcg", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setCcg(__pyx_v_self, __pyx_v_ccg, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setCcg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":451
 *         self.__ccg = ccg
 * 
 *     cpdef str getPosTag(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the pos tag layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_49getPosTag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPosTag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPosTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_49getPosTag)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 451, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":460
 *             Pos tag of the word.
 *         """
 *         return self.__pos_tag             # <<<<<<<<<<<<<<
 * 
 *     cpdef setPosTag(self, str posTag):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___pos_tag);
  __pyx_r = __pyx_v_self->__pyx___pos_tag;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":451
 *         self.__ccg = ccg
 * 
 *     cpdef str getPosTag(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the pos tag layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getPosTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_49getPosTag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_48getPosTag[] = "\n        Returns the pos tag layer of the word.\n\n        RETURNS\n        -------\n        str\n            Pos tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_49getPosTag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPosTag (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_48getPosTag(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_48getPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPosTag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPosTag(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getPosTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":462
 *         return self.__pos_tag
 * 
 *     cpdef setPosTag(self, str posTag):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the posTag layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_51setPosTag(PyObject *__pyx_v_self, PyObject *__pyx_v_posTag); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_posTag, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setPosTag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setPosTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_51setPosTag)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_posTag) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_posTag);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":471
 *             New pos tag of the word.
 *         """
 *         self.__pos_tag = posTag             # <<<<<<<<<<<<<<
 * 
 *     cpdef UniversalDependencyRelation getUniversalDependency(self):
 */
  __Pyx_INCREF(__pyx_v_posTag);
  __Pyx_GIVEREF(__pyx_v_posTag);
  __Pyx_GOTREF(__pyx_v_self->__pyx___pos_tag);
  __Pyx_DECREF(__pyx_v_self->__pyx___pos_tag);
  __pyx_v_self->__pyx___pos_tag = __pyx_v_posTag;

  /* "AnnotatedSentence/AnnotatedWord.pyx":462
 *         return self.__pos_tag
 * 
 *     cpdef setPosTag(self, str posTag):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the posTag layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setPosTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_51setPosTag(PyObject *__pyx_v_self, PyObject *__pyx_v_posTag); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_50setPosTag[] = "\n        Sets the posTag layer of the word.\n\n        PARAMETERS\n        ----------\n        posTag : str\n            New pos tag of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_51setPosTag(PyObject *__pyx_v_self, PyObject *__pyx_v_posTag) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setPosTag (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_posTag), (&PyUnicode_Type), 1, "posTag", 1))) __PYX_ERR(0, 462, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_50setPosTag(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject*)__pyx_v_posTag));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_50setPosTag(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_posTag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setPosTag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPosTag(__pyx_v_self, __pyx_v_posTag, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setPosTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":473
 *         self.__pos_tag = posTag
 * 
 *     cpdef UniversalDependencyRelation getUniversalDependency(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the universal dependency layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_53getUniversalDependency(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependency", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getUniversalDependency); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_53getUniversalDependency)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 473, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation))))) __PYX_ERR(0, 473, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":482
 *             Universal dependency relation of the word.
 *         """
 *         return self.__universal_dependency             # <<<<<<<<<<<<<<
 * 
 *     cpdef setUniversalDependency(self, int to, str dependencyType):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___universal_dependency));
  __pyx_r = __pyx_v_self->__pyx___universal_dependency;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":473
 *         self.__pos_tag = posTag
 * 
 *     cpdef UniversalDependencyRelation getUniversalDependency(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the universal dependency layer of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getUniversalDependency", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_53getUniversalDependency(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_52getUniversalDependency[] = "\n        Returns the universal dependency layer of the word.\n\n        RETURNS\n        -------\n        UniversalDependencyRelation\n            Universal dependency relation of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_53getUniversalDependency(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getUniversalDependency (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_52getUniversalDependency(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_52getUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependency", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependency(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getUniversalDependency", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":484
 *         return self.__universal_dependency
 * 
 *     cpdef setUniversalDependency(self, int to, str dependencyType):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the universal dependency layer of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_55setUniversalDependency(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_to, PyObject *__pyx_v_dependencyType, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setUniversalDependency", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setUniversalDependency); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_55setUniversalDependency)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_to); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_3, __pyx_v_dependencyType};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 484, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_3, __pyx_v_dependencyType};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 484, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 484, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_t_3);
          __Pyx_INCREF(__pyx_v_dependencyType);
          __Pyx_GIVEREF(__pyx_v_dependencyType);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_dependencyType);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 484, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":495
 *             type of dependency the word is related to.
 *         """
 *         if to < 0:             # <<<<<<<<<<<<<<
 *             self.__universal_dependency = None
 *         else:
 */
  __pyx_t_8 = ((__pyx_v_to < 0) != 0);
  if (__pyx_t_8) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":496
 *         """
 *         if to < 0:
 *             self.__universal_dependency = None             # <<<<<<<<<<<<<<
 *         else:
 *             self.__universal_dependency = UniversalDependencyRelation(to, dependencyType)
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___universal_dependency);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___universal_dependency));
    __pyx_v_self->__pyx___universal_dependency = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)Py_None);

    /* "AnnotatedSentence/AnnotatedWord.pyx":495
 *             type of dependency the word is related to.
 *         """
 *         if to < 0:             # <<<<<<<<<<<<<<
 *             self.__universal_dependency = None
 *         else:
 */
    goto __pyx_L3;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":498
 *             self.__universal_dependency = None
 *         else:
 *             self.__universal_dependency = UniversalDependencyRelation(to, dependencyType)             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getUniversalDependencyFormat(self, int sentenceLength):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_to); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_dependencyType);
    __Pyx_GIVEREF(__pyx_v_dependencyType);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_dependencyType);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___universal_dependency);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->__pyx___universal_dependency));
    __pyx_v_self->__pyx___universal_dependency = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":484
 *         return self.__universal_dependency
 * 
 *     cpdef setUniversalDependency(self, int to, str dependencyType):             # <<<<<<<<<<<<<<
 *         """
 *         Sets the universal dependency layer of the word.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setUniversalDependency", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_55setUniversalDependency(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_54setUniversalDependency[] = "\n        Sets the universal dependency layer of the word.\n\n        PARAMETERS\n        ----------\n        to : int\n            to Word related to.\n        dependencyType : str\n            type of dependency the word is related to.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_55setUniversalDependency(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_to;
  PyObject *__pyx_v_dependencyType = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setUniversalDependency (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_to,&__pyx_n_s_dependencyType,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_to)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dependencyType)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setUniversalDependency", 1, 2, 2, 1); __PYX_ERR(0, 484, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setUniversalDependency") < 0)) __PYX_ERR(0, 484, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_to = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_to == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 484, __pyx_L3_error)
    __pyx_v_dependencyType = ((PyObject*)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setUniversalDependency", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 484, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setUniversalDependency", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dependencyType), (&PyUnicode_Type), 1, "dependencyType", 1))) __PYX_ERR(0, 484, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_54setUniversalDependency(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), __pyx_v_to, __pyx_v_dependencyType);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_54setUniversalDependency(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_to, PyObject *__pyx_v_dependencyType) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setUniversalDependency", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setUniversalDependency(__pyx_v_self, __pyx_v_to, __pyx_v_dependencyType, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.setUniversalDependency", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":500
 *             self.__universal_dependency = UniversalDependencyRelation(to, dependencyType)
 * 
 *     cpdef str getUniversalDependencyFormat(self, int sentenceLength):             # <<<<<<<<<<<<<<
 *         cdef str result
 *         cdef list features
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_57getUniversalDependencyFormat(PyObject *__pyx_v_self, PyObject *__pyx_arg_sentenceLength); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependencyFormat(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_sentenceLength, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_features = 0;
  int __pyx_v_first;
  PyObject *__pyx_v_uPos = 0;
  PyObject *__pyx_v_feature = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependencyFormat", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getUniversalDependencyFormat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 500, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_57getUniversalDependencyFormat)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_sentenceLength); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 500, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 500, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 500, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":505
 *         cdef bint first
 *         cdef str uPos
 *         if self.__parse is not None:             # <<<<<<<<<<<<<<
 *             uPos = self.__parse.getUniversalDependencyPos()
 *             result = self.name + "\t" + self.__parse.getWord().getName() + "\t" + \
 */
  __pyx_t_6 = (((PyObject *)__pyx_v_self->__pyx___parse) != Py_None);
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":506
 *         cdef str uPos
 *         if self.__parse is not None:
 *             uPos = self.__parse.getUniversalDependencyPos()             # <<<<<<<<<<<<<<
 *             result = self.name + "\t" + self.__parse.getWord().getName() + "\t" + \
 *                      uPos + "\t_\t"
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx___parse->__pyx_vtab)->getUniversalDependencyPos(__pyx_v_self->__pyx___parse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uPos = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":507
 *         if self.__parse is not None:
 *             uPos = self.__parse.getUniversalDependencyPos()
 *             result = self.name + "\t" + self.__parse.getWord().getName() + "\t" + \             # <<<<<<<<<<<<<<
 *                      uPos + "\t_\t"
 *             features = self.__parse.getUniversalDependencyFeatures(uPos)
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_self->__pyx_base.name, __pyx_kp_u__7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx___parse->__pyx_vtab)->getWord(__pyx_v_self->__pyx___parse, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_kp_u__7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":508
 *             uPos = self.__parse.getUniversalDependencyPos()
 *             result = self.name + "\t" + self.__parse.getWord().getName() + "\t" + \
 *                      uPos + "\t_\t"             # <<<<<<<<<<<<<<
 *             features = self.__parse.getUniversalDependencyFeatures(uPos)
 *             if len(features) == 0:
 */
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_4, __pyx_v_uPos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_kp_u__8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_result = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":509
 *             result = self.name + "\t" + self.__parse.getWord().getName() + "\t" + \
 *                      uPos + "\t_\t"
 *             features = self.__parse.getUniversalDependencyFeatures(uPos)             # <<<<<<<<<<<<<<
 *             if len(features) == 0:
 *                 result = result + "_"
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx___parse->__pyx_vtab)->getUniversalDependencyFeatures(__pyx_v_self->__pyx___parse, __pyx_v_uPos, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_features = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":510
 *                      uPos + "\t_\t"
 *             features = self.__parse.getUniversalDependencyFeatures(uPos)
 *             if len(features) == 0:             # <<<<<<<<<<<<<<
 *                 result = result + "_"
 *             else:
 */
    if (unlikely(__pyx_v_features == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 510, __pyx_L1_error)
    }
    __pyx_t_8 = PyList_GET_SIZE(__pyx_v_features); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 510, __pyx_L1_error)
    __pyx_t_7 = ((__pyx_t_8 == 0) != 0);
    if (__pyx_t_7) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":511
 *             features = self.__parse.getUniversalDependencyFeatures(uPos)
 *             if len(features) == 0:
 *                 result = result + "_"             # <<<<<<<<<<<<<<
 *             else:
 *                 first = True
 */
      __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_v_result, __pyx_n_u__9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":510
 *                      uPos + "\t_\t"
 *             features = self.__parse.getUniversalDependencyFeatures(uPos)
 *             if len(features) == 0:             # <<<<<<<<<<<<<<
 *                 result = result + "_"
 *             else:
 */
      goto __pyx_L4;
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":513
 *                 result = result + "_"
 *             else:
 *                 first = True             # <<<<<<<<<<<<<<
 *                 for feature in features:
 *                     if first:
 */
    /*else*/ {
      __pyx_v_first = 1;

      /* "AnnotatedSentence/AnnotatedWord.pyx":514
 *             else:
 *                 first = True
 *                 for feature in features:             # <<<<<<<<<<<<<<
 *                     if first:
 *                         first = False
 */
      if (unlikely(__pyx_v_features == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 514, __pyx_L1_error)
      }
      __pyx_t_4 = __pyx_v_features; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
      for (;;) {
        if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_2); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 514, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_feature, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":515
 *                 first = True
 *                 for feature in features:
 *                     if first:             # <<<<<<<<<<<<<<
 *                         first = False
 *                     else:
 */
        __pyx_t_7 = (__pyx_v_first != 0);
        if (__pyx_t_7) {

          /* "AnnotatedSentence/AnnotatedWord.pyx":516
 *                 for feature in features:
 *                     if first:
 *                         first = False             # <<<<<<<<<<<<<<
 *                     else:
 *                         result += "|"
 */
          __pyx_v_first = 0;

          /* "AnnotatedSentence/AnnotatedWord.pyx":515
 *                 first = True
 *                 for feature in features:
 *                     if first:             # <<<<<<<<<<<<<<
 *                         first = False
 *                     else:
 */
          goto __pyx_L7;
        }

        /* "AnnotatedSentence/AnnotatedWord.pyx":518
 *                         first = False
 *                     else:
 *                         result += "|"             # <<<<<<<<<<<<<<
 *                     result += feature
 *             result += "\t"
 */
        /*else*/ {
          __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u__10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 518, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
          __pyx_t_2 = 0;
        }
        __pyx_L7:;

        /* "AnnotatedSentence/AnnotatedWord.pyx":519
 *                     else:
 *                         result += "|"
 *                     result += feature             # <<<<<<<<<<<<<<
 *             result += "\t"
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:
 */
        __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_v_feature); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 519, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "AnnotatedSentence/AnnotatedWord.pyx":514
 *             else:
 *                 first = True
 *                 for feature in features:             # <<<<<<<<<<<<<<
 *                     if first:
 *                         first = False
 */
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L4:;

    /* "AnnotatedSentence/AnnotatedWord.pyx":520
 *                         result += "|"
 *                     result += feature
 *             result += "\t"             # <<<<<<<<<<<<<<
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \
 */
    __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u__7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":521
 *                     result += feature
 *             result += "\t"
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:             # <<<<<<<<<<<<<<
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \
 *                           self.__universal_dependency.__str__().lower() + "\t"
 */
    __pyx_t_6 = (((PyObject *)__pyx_v_self->__pyx___universal_dependency) != Py_None);
    __pyx_t_9 = (__pyx_t_6 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_9 = ((((struct __pyx_vtabstruct_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_v_self->__pyx___universal_dependency->__pyx_base.__pyx_vtab)->__pyx_base.to(((struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation *)__pyx_v_self->__pyx___universal_dependency), 0) <= __pyx_v_sentenceLength) != 0);
    __pyx_t_7 = __pyx_t_9;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_7) {

      /* "AnnotatedSentence/AnnotatedWord.pyx":522
 *             result += "\t"
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \             # <<<<<<<<<<<<<<
 *                           self.__universal_dependency.__str__().lower() + "\t"
 *             else:
 */
      __pyx_t_2 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_v_self->__pyx___universal_dependency->__pyx_base.__pyx_vtab)->__pyx_base.to(((struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation *)__pyx_v_self->__pyx___universal_dependency), 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":523
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \
 *                           self.__universal_dependency.__str__().lower() + "\t"             # <<<<<<<<<<<<<<
 *             else:
 *                 result += "_\t_\t"
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx___universal_dependency), __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lower); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":522
 *             result += "\t"
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \             # <<<<<<<<<<<<<<
 *                           self.__universal_dependency.__str__().lower() + "\t"
 *             else:
 */
      __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":523
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \
 *                           self.__universal_dependency.__str__().lower() + "\t"             # <<<<<<<<<<<<<<
 *             else:
 *                 result += "_\t_\t"
 */
      __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":522
 *             result += "\t"
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \             # <<<<<<<<<<<<<<
 *                           self.__universal_dependency.__str__().lower() + "\t"
 *             else:
 */
      __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 522, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "AnnotatedSentence/AnnotatedWord.pyx":521
 *                     result += feature
 *             result += "\t"
 *             if self.__universal_dependency is not None and self.__universal_dependency.to() <= sentenceLength:             # <<<<<<<<<<<<<<
 *                 result += self.__universal_dependency.to().__str__() + "\t" + \
 *                           self.__universal_dependency.__str__().lower() + "\t"
 */
      goto __pyx_L8;
    }

    /* "AnnotatedSentence/AnnotatedWord.pyx":525
 *                           self.__universal_dependency.__str__().lower() + "\t"
 *             else:
 *                 result += "_\t_\t"             # <<<<<<<<<<<<<<
 *             result += "_\t_"
 *             return result
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_v_result, __pyx_kp_u__11); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;
    }
    __pyx_L8:;

    /* "AnnotatedSentence/AnnotatedWord.pyx":526
 *             else:
 *                 result += "_\t_\t"
 *             result += "_\t_"             # <<<<<<<<<<<<<<
 *             return result
 *         else:
 */
    __pyx_t_3 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u__12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":527
 *                 result += "_\t_\t"
 *             result += "_\t_"
 *             return result             # <<<<<<<<<<<<<<
 *         else:
 *             return self.name + "\t" + self.name + "\t_\t_\t_\t_\t_\t_\t_"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":505
 *         cdef bint first
 *         cdef str uPos
 *         if self.__parse is not None:             # <<<<<<<<<<<<<<
 *             uPos = self.__parse.getUniversalDependencyPos()
 *             result = self.name + "\t" + self.__parse.getWord().getName() + "\t" + \
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":529
 *             return result
 *         else:
 *             return self.name + "\t" + self.name + "\t_\t_\t_\t_\t_\t_\t_"             # <<<<<<<<<<<<<<
 * 
 *     cpdef getFormattedString(self, object wordFormat):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_self->__pyx_base.name, __pyx_kp_u__7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_3, __pyx_v_self->__pyx_base.name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":500
 *             self.__universal_dependency = UniversalDependencyRelation(to, dependencyType)
 * 
 *     cpdef str getUniversalDependencyFormat(self, int sentenceLength):             # <<<<<<<<<<<<<<
 *         cdef str result
 *         cdef list features
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getUniversalDependencyFormat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_features);
  __Pyx_XDECREF(__pyx_v_uPos);
  __Pyx_XDECREF(__pyx_v_feature);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_57getUniversalDependencyFormat(PyObject *__pyx_v_self, PyObject *__pyx_arg_sentenceLength); /*proto*/
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_57getUniversalDependencyFormat(PyObject *__pyx_v_self, PyObject *__pyx_arg_sentenceLength) {
  int __pyx_v_sentenceLength;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getUniversalDependencyFormat (wrapper)", 0);
  assert(__pyx_arg_sentenceLength); {
    __pyx_v_sentenceLength = __Pyx_PyInt_As_int(__pyx_arg_sentenceLength); if (unlikely((__pyx_v_sentenceLength == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 500, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getUniversalDependencyFormat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_56getUniversalDependencyFormat(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((int)__pyx_v_sentenceLength));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_56getUniversalDependencyFormat(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_v_sentenceLength) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependencyFormat", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependencyFormat(__pyx_v_self, __pyx_v_sentenceLength, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getUniversalDependencyFormat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":531
 *             return self.name + "\t" + self.name + "\t_\t_\t_\t_\t_\t_\t_"
 * 
 *     cpdef getFormattedString(self, object wordFormat):             # <<<<<<<<<<<<<<
 *         if wordFormat == WordFormat.SURFACE:
 *             return self.name
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_59getFormattedString(PyObject *__pyx_v_self, PyObject *__pyx_v_wordFormat); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFormattedString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_wordFormat, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFormattedString", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getFormattedString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_59getFormattedString)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_wordFormat) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_wordFormat);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 531, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":532
 * 
 *     cpdef getFormattedString(self, object wordFormat):
 *         if wordFormat == WordFormat.SURFACE:             # <<<<<<<<<<<<<<
 *             return self.name
 *         return self.name
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_WordFormat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SURFACE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_wordFormat, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":533
 *     cpdef getFormattedString(self, object wordFormat):
 *         if wordFormat == WordFormat.SURFACE:
 *             return self.name             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->__pyx_base.name);
    __pyx_r = __pyx_v_self->__pyx_base.name;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":532
 * 
 *     cpdef getFormattedString(self, object wordFormat):
 *         if wordFormat == WordFormat.SURFACE:             # <<<<<<<<<<<<<<
 *             return self.name
 *         return self.name
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":534
 *         if wordFormat == WordFormat.SURFACE:
 *             return self.name
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 *     cpdef checkGazetteer(self, Gazetteer gazetteer):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.name);
  __pyx_r = __pyx_v_self->__pyx_base.name;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":531
 *             return self.name + "\t" + self.name + "\t_\t_\t_\t_\t_\t_\t_"
 * 
 *     cpdef getFormattedString(self, object wordFormat):             # <<<<<<<<<<<<<<
 *         if wordFormat == WordFormat.SURFACE:
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getFormattedString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_59getFormattedString(PyObject *__pyx_v_self, PyObject *__pyx_v_wordFormat); /*proto*/
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_59getFormattedString(PyObject *__pyx_v_self, PyObject *__pyx_v_wordFormat) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFormattedString (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_58getFormattedString(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject *)__pyx_v_wordFormat));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_58getFormattedString(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v_wordFormat) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFormattedString", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFormattedString(__pyx_v_self, __pyx_v_wordFormat, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getFormattedString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":536
 *         return self.name
 * 
 *     cpdef checkGazetteer(self, Gazetteer gazetteer):             # <<<<<<<<<<<<<<
 *         cdef str word_lower_case
 *         word_lower_case = self.name.lower()
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_61checkGazetteer(PyObject *__pyx_v_self, PyObject *__pyx_v_gazetteer); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_checkGazetteer(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *__pyx_v_gazetteer, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_word_lower_case = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkGazetteer", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_checkGazetteer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_61checkGazetteer)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_gazetteer)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_gazetteer));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 536, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":538
 *     cpdef checkGazetteer(self, Gazetteer gazetteer):
 *         cdef str word_lower_case
 *         word_lower_case = self.name.lower()             # <<<<<<<<<<<<<<
 *         if gazetteer.contains(word_lower_case) and self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base.name, __pyx_n_s_lower); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 538, __pyx_L1_error)
  __pyx_v_word_lower_case = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":539
 *         cdef str word_lower_case
 *         word_lower_case = self.name.lower()
 *         if gazetteer.contains(word_lower_case) and self.__parse.containsTag(MorphologicalTag.PROPERNOUN):             # <<<<<<<<<<<<<<
 *             self.setNamedEntityType(gazetteer.getName())
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer *)__pyx_v_gazetteer->__pyx_vtab)->contains(__pyx_v_gazetteer, __pyx_v_word_lower_case, 0) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PROPERNOUN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx___parse->__pyx_vtab)->containsTag(__pyx_v_self->__pyx___parse, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":540
 *         word_lower_case = self.name.lower()
 *         if gazetteer.contains(word_lower_case) and self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())             # <<<<<<<<<<<<<<
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \
 *                 self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer *)__pyx_v_gazetteer->__pyx_vtab)->getName(__pyx_v_gazetteer, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = ((struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->setNamedEntityType(__pyx_v_self, ((PyObject*)__pyx_t_2), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":539
 *         cdef str word_lower_case
 *         word_lower_case = self.name.lower()
 *         if gazetteer.contains(word_lower_case) and self.__parse.containsTag(MorphologicalTag.PROPERNOUN):             # <<<<<<<<<<<<<<
 *             self.setNamedEntityType(gazetteer.getName())
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":541
 *         if gazetteer.contains(word_lower_case) and self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \             # <<<<<<<<<<<<<<
 *                 self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())
 */
  if (unlikely(__pyx_v_word_lower_case == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 541, __pyx_L1_error)
  }
  __pyx_t_6 = (__Pyx_PyUnicode_ContainsTF(__pyx_kp_u__14, __pyx_v_word_lower_case, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 541, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  if (unlikely(__pyx_v_word_lower_case == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 541, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyUnicode_Type_index, __pyx_v_word_lower_case, __pyx_kp_u__14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__pyx_t_1 == Py_None);
  if (__pyx_t_7) {
    __pyx_t_8 = PY_SSIZE_T_MAX;
  } else {
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_1); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 541, __pyx_L1_error)
    __pyx_t_8 = __pyx_t_9;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_word_lower_case, 0, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (((struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer *)__pyx_v_gazetteer->__pyx_vtab)->contains(__pyx_v_gazetteer, ((PyObject*)__pyx_t_1), 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":542
 *             self.setNamedEntityType(gazetteer.getName())
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \
 *                 self.__parse.containsTag(MorphologicalTag.PROPERNOUN):             # <<<<<<<<<<<<<<
 *             self.setNamedEntityType(gazetteer.getName())
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PROPERNOUN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx___parse->__pyx_vtab)->containsTag(__pyx_v_self->__pyx___parse, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_7;
  __pyx_L7_bool_binop_done:;

  /* "AnnotatedSentence/AnnotatedWord.pyx":541
 *         if gazetteer.contains(word_lower_case) and self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \             # <<<<<<<<<<<<<<
 *                 self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())
 */
  if (__pyx_t_5) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":543
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \
 *                 self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())             # <<<<<<<<<<<<<<
 * 
 *     cpdef object getLanguage(self):
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer *)__pyx_v_gazetteer->__pyx_vtab)->getName(__pyx_v_gazetteer, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = ((struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->setNamedEntityType(__pyx_v_self, ((PyObject*)__pyx_t_2), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":541
 *         if gazetteer.contains(word_lower_case) and self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())
 *         if "'" in word_lower_case and gazetteer.contains(word_lower_case[:word_lower_case.index("'")]) and \             # <<<<<<<<<<<<<<
 *                 self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
 *             self.setNamedEntityType(gazetteer.getName())
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":536
 *         return self.name
 * 
 *     cpdef checkGazetteer(self, Gazetteer gazetteer):             # <<<<<<<<<<<<<<
 *         cdef str word_lower_case
 *         word_lower_case = self.name.lower()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.checkGazetteer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_word_lower_case);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_61checkGazetteer(PyObject *__pyx_v_self, PyObject *__pyx_v_gazetteer); /*proto*/
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_61checkGazetteer(PyObject *__pyx_v_self, PyObject *__pyx_v_gazetteer) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkGazetteer (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_gazetteer), __pyx_ptype_22NamedEntityRecognition_9Gazetteer_Gazetteer, 1, "gazetteer", 0))) __PYX_ERR(0, 536, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_60checkGazetteer(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *)__pyx_v_gazetteer));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_60checkGazetteer(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *__pyx_v_gazetteer) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("checkGazetteer", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_checkGazetteer(__pyx_v_self, __pyx_v_gazetteer, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.checkGazetteer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":545
 *             self.setNamedEntityType(gazetteer.getName())
 * 
 *     cpdef object getLanguage(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the language of the word.
 */

static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_63getLanguage(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLanguage(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLanguage", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getLanguage); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_63getLanguage)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 545, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":553
 *         The language of the word.
 *         """
 *         return self.__language             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___language);
  __pyx_r = __pyx_v_self->__pyx___language;
  goto __pyx_L0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":545
 *             self.setNamedEntityType(gazetteer.getName())
 * 
 *     cpdef object getLanguage(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the language of the word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getLanguage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_63getLanguage(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_62getLanguage[] = "\n        Returns the language of the word.\n\n        RETURNS\n        ----------\n        The language of the word.\n        ";
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_63getLanguage(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLanguage (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_62getLanguage(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_62getLanguage(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLanguage", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLanguage(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getLanguage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "AnnotatedSentence/AnnotatedWord.pyx":556
 * 
 *     @staticmethod
 *     def getLanguageFromString(languageString: str) -> Language:             # <<<<<<<<<<<<<<
 *         """
 *         Converts a language string to language.
 */

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_65getLanguageFromString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_64getLanguageFromString[] = "\n        Converts a language string to language.\n\n        PARAMETERS\n        ----------\n        languageString : str\n            String defining the language name.\n\n        RETURNS\n        ----------\n        Language corresponding to the languageString.\n        ";
static PyMethodDef __pyx_mdef_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_65getLanguageFromString = {"getLanguageFromString", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_65getLanguageFromString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_64getLanguageFromString};
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_65getLanguageFromString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_languageString = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLanguageFromString (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_languageString,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_languageString)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "getLanguageFromString") < 0)) __PYX_ERR(0, 556, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_languageString = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getLanguageFromString", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 556, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getLanguageFromString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_languageString), (&PyUnicode_Type), 1, "languageString", 1))) __PYX_ERR(0, 556, __pyx_L1_error)
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_64getLanguageFromString(__pyx_v_languageString);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_64getLanguageFromString(PyObject *__pyx_v_languageString) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLanguageFromString", 0);

  /* "AnnotatedSentence/AnnotatedWord.pyx":569
 *         Language corresponding to the languageString.
 *         """
 *         if languageString == "turkish" or languageString == "Turkish":             # <<<<<<<<<<<<<<
 *             return Language.TURKISH
 *         elif languageString == "english" or languageString == "English":
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_languageString, __pyx_n_u_turkish, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 569, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_languageString, __pyx_n_u_Turkish, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 569, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":570
 *         """
 *         if languageString == "turkish" or languageString == "Turkish":
 *             return Language.TURKISH             # <<<<<<<<<<<<<<
 *         elif languageString == "english" or languageString == "English":
 *             return Language.ENGLISH
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Language); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_TURKISH); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":569
 *         Language corresponding to the languageString.
 *         """
 *         if languageString == "turkish" or languageString == "Turkish":             # <<<<<<<<<<<<<<
 *             return Language.TURKISH
 *         elif languageString == "english" or languageString == "English":
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":571
 *         if languageString == "turkish" or languageString == "Turkish":
 *             return Language.TURKISH
 *         elif languageString == "english" or languageString == "English":             # <<<<<<<<<<<<<<
 *             return Language.ENGLISH
 *         elif languageString == "persian" or languageString == "Persian":
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_languageString, __pyx_n_u_english, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 571, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_languageString, __pyx_n_u_English, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 571, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":572
 *             return Language.TURKISH
 *         elif languageString == "english" or languageString == "English":
 *             return Language.ENGLISH             # <<<<<<<<<<<<<<
 *         elif languageString == "persian" or languageString == "Persian":
 *             return Language.PERSIAN
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Language); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ENGLISH); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":571
 *         if languageString == "turkish" or languageString == "Turkish":
 *             return Language.TURKISH
 *         elif languageString == "english" or languageString == "English":             # <<<<<<<<<<<<<<
 *             return Language.ENGLISH
 *         elif languageString == "persian" or languageString == "Persian":
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":573
 *         elif languageString == "english" or languageString == "English":
 *             return Language.ENGLISH
 *         elif languageString == "persian" or languageString == "Persian":             # <<<<<<<<<<<<<<
 *             return Language.PERSIAN
 *         else:
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_languageString, __pyx_n_u_persian, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 573, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_languageString, __pyx_n_u_Persian, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 573, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_1) {

    /* "AnnotatedSentence/AnnotatedWord.pyx":574
 *             return Language.ENGLISH
 *         elif languageString == "persian" or languageString == "Persian":
 *             return Language.PERSIAN             # <<<<<<<<<<<<<<
 *         else:
 *             return Language.TURKISH
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Language); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_PERSIAN); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "AnnotatedSentence/AnnotatedWord.pyx":573
 *         elif languageString == "english" or languageString == "English":
 *             return Language.ENGLISH
 *         elif languageString == "persian" or languageString == "Persian":             # <<<<<<<<<<<<<<
 *             return Language.PERSIAN
 *         else:
 */
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":576
 *             return Language.PERSIAN
 *         else:
 *             return Language.TURKISH             # <<<<<<<<<<<<<<
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Language); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 576, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_TURKISH); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 576, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "AnnotatedSentence/AnnotatedWord.pyx":556
 * 
 *     @staticmethod
 *     def getLanguageFromString(languageString: str) -> Language:             # <<<<<<<<<<<<<<
 *         """
 *         Converts a language string to language.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.getLanguageFromString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_67__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_67__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_66__reduce_cython__(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_66__reduce_cython__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.__argument, self.__ccg, self.__frame_element, self.__language, self.__metamorphic_parse, self.__named_entity_type, self.__parse, self.__polarity, self.__pos_tag, self.__semantic, self.__shallow_parse, self.__slot, self.__universal_dependency, self.name)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(14); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___argument));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___argument));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->__pyx___argument));
  __Pyx_INCREF(__pyx_v_self->__pyx___ccg);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___ccg);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->__pyx___ccg);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___frame_element));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___frame_element));
  PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_v_self->__pyx___frame_element));
  __Pyx_INCREF(__pyx_v_self->__pyx___language);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___language);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_self->__pyx___language);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___metamorphic_parse));
  PyTuple_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_v_self->__pyx___metamorphic_parse));
  __Pyx_INCREF(__pyx_v_self->__pyx___named_entity_type);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___named_entity_type);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_v_self->__pyx___named_entity_type);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___parse));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___parse));
  PyTuple_SET_ITEM(__pyx_t_1, 6, ((PyObject *)__pyx_v_self->__pyx___parse));
  __Pyx_INCREF(__pyx_v_self->__pyx___polarity);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___polarity);
  PyTuple_SET_ITEM(__pyx_t_1, 7, __pyx_v_self->__pyx___polarity);
  __Pyx_INCREF(__pyx_v_self->__pyx___pos_tag);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___pos_tag);
  PyTuple_SET_ITEM(__pyx_t_1, 8, __pyx_v_self->__pyx___pos_tag);
  __Pyx_INCREF(__pyx_v_self->__pyx___semantic);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___semantic);
  PyTuple_SET_ITEM(__pyx_t_1, 9, __pyx_v_self->__pyx___semantic);
  __Pyx_INCREF(__pyx_v_self->__pyx___shallow_parse);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___shallow_parse);
  PyTuple_SET_ITEM(__pyx_t_1, 10, __pyx_v_self->__pyx___shallow_parse);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___slot));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___slot));
  PyTuple_SET_ITEM(__pyx_t_1, 11, ((PyObject *)__pyx_v_self->__pyx___slot));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx___universal_dependency));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx___universal_dependency));
  PyTuple_SET_ITEM(__pyx_t_1, 12, ((PyObject *)__pyx_v_self->__pyx___universal_dependency));
  __Pyx_INCREF(__pyx_v_self->__pyx_base.name);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.name);
  PyTuple_SET_ITEM(__pyx_t_1, 13, __pyx_v_self->__pyx_base.name);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.__argument, self.__ccg, self.__frame_element, self.__language, self.__metamorphic_parse, self.__named_entity_type, self.__parse, self.__polarity, self.__pos_tag, self.__semantic, self.__shallow_parse, self.__slot, self.__universal_dependency, self.name)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.__argument, self.__ccg, self.__frame_element, self.__language, self.__metamorphic_parse, self.__named_entity_type, self.__parse, self.__polarity, self.__pos_tag, self.__semantic, self.__shallow_parse, self.__slot, self.__universal_dependency, self.name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.__argument is not None or self.__ccg is not None or self.__frame_element is not None or self.__language is not None or self.__metamorphic_parse is not None or self.__named_entity_type is not None or self.__parse is not None or self.__polarity is not None or self.__pos_tag is not None or self.__semantic is not None or self.__shallow_parse is not None or self.__slot is not None or self.__universal_dependency is not None or self.name is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.__argument, self.__ccg, self.__frame_element, self.__language, self.__metamorphic_parse, self.__named_entity_type, self.__parse, self.__polarity, self.__pos_tag, self.__semantic, self.__shallow_parse, self.__slot, self.__universal_dependency, self.name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.__argument is not None or self.__ccg is not None or self.__frame_element is not None or self.__language is not None or self.__metamorphic_parse is not None or self.__named_entity_type is not None or self.__parse is not None or self.__polarity is not None or self.__pos_tag is not None or self.__semantic is not None or self.__shallow_parse is not None or self.__slot is not None or self.__universal_dependency is not None or self.name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, None), state
 */
  /*else*/ {
    __pyx_t_2 = (((PyObject *)__pyx_v_self->__pyx___argument) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx___ccg != ((PyObject*)Py_None));
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (((PyObject *)__pyx_v_self->__pyx___frame_element) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx___language != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (((PyObject *)__pyx_v_self->__pyx___metamorphic_parse) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx___named_entity_type != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (((PyObject *)__pyx_v_self->__pyx___parse) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx___polarity != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_self->__pyx___pos_tag != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx___semantic != ((PyObject*)Py_None));
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_self->__pyx___shallow_parse != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (((PyObject *)__pyx_v_self->__pyx___slot) != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (((PyObject *)__pyx_v_self->__pyx___universal_dependency) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx_base.name != ((PyObject*)Py_None));
    __pyx_t_2 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__argument is not None or self.__ccg is not None or self.__frame_element is not None or self.__language is not None or self.__metamorphic_parse is not None or self.__named_entity_type is not None or self.__parse is not None or self.__polarity is not None or self.__pos_tag is not None or self.__semantic is not None or self.__shallow_parse is not None or self.__slot is not None or self.__universal_dependency is not None or self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.__argument is not None or self.__ccg is not None or self.__frame_element is not None or self.__language is not None or self.__metamorphic_parse is not None or self.__named_entity_type is not None or self.__parse is not None or self.__polarity is not None or self.__pos_tag is not None or self.__semantic is not None or self.__shallow_parse is not None or self.__slot is not None or self.__universal_dependency is not None or self.name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_AnnotatedWord); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_42354475);
    __Pyx_GIVEREF(__pyx_int_42354475);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_42354475);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__argument is not None or self.__ccg is not None or self.__frame_element is not None or self.__language is not None or self.__metamorphic_parse is not None or self.__named_entity_type is not None or self.__parse is not None or self.__polarity is not None or self.__pos_tag is not None or self.__semantic is not None or self.__shallow_parse is not None or self.__slot is not None or self.__universal_dependency is not None or self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, None), state
 *     else:
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_AnnotatedWord__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_AnnotatedWord); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_42354475);
    __Pyx_GIVEREF(__pyx_int_42354475);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_42354475);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AnnotatedWord__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_69__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_69__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_68__setstate_cython__(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_68__setstate_cython__(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_AnnotatedWord__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_17AnnotatedSentence_13AnnotatedWord___pyx_unpickle_AnnotatedWord__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_AnnotatedWord, (type(self), 0x286472b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_AnnotatedWord__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.AnnotatedWord.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_AnnotatedWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_1__pyx_unpickle_AnnotatedWord(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_17AnnotatedSentence_13AnnotatedWord_1__pyx_unpickle_AnnotatedWord = {"__pyx_unpickle_AnnotatedWord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_1__pyx_unpickle_AnnotatedWord, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_17AnnotatedSentence_13AnnotatedWord_1__pyx_unpickle_AnnotatedWord(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_AnnotatedWord (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_AnnotatedWord", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_AnnotatedWord", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_AnnotatedWord") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_AnnotatedWord", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.__pyx_unpickle_AnnotatedWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_17AnnotatedSentence_13AnnotatedWord___pyx_unpickle_AnnotatedWord(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_17AnnotatedSentence_13AnnotatedWord___pyx_unpickle_AnnotatedWord(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_AnnotatedWord", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x286472b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x286472b) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x286472b:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))" % __pyx_checksum)
 *     __pyx_result = AnnotatedWord.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x286472b:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = AnnotatedWord.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x28, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x286472b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))" % __pyx_checksum)
 *     __pyx_result = AnnotatedWord.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AnnotatedWord__set_state(<AnnotatedWord> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))" % __pyx_checksum)
 *     __pyx_result = AnnotatedWord.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_AnnotatedWord__set_state(<AnnotatedWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = AnnotatedWord.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AnnotatedWord__set_state(<AnnotatedWord> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_AnnotatedWord__set_state(AnnotatedWord __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_17AnnotatedSentence_13AnnotatedWord___pyx_unpickle_AnnotatedWord__set_state(((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x286472b = (__argument, __ccg, __frame_element, __language, __metamorphic_parse, __named_entity_type, __parse, __polarity, __pos_tag, __semantic, __shallow_parse, __slot, __universal_dependency, name))" % __pyx_checksum)
 *     __pyx_result = AnnotatedWord.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_AnnotatedWord__set_state(<AnnotatedWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_AnnotatedWord__set_state(<AnnotatedWord> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_AnnotatedWord__set_state(AnnotatedWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__argument = __pyx_state[0]; __pyx_result.__ccg = __pyx_state[1]; __pyx_result.__frame_element = __pyx_state[2]; __pyx_result.__language = __pyx_state[3]; __pyx_result.__metamorphic_parse = __pyx_state[4]; __pyx_result.__named_entity_type = __pyx_state[5]; __pyx_result.__parse = __pyx_state[6]; __pyx_result.__polarity = __pyx_state[7]; __pyx_result.__pos_tag = __pyx_state[8]; __pyx_result.__semantic = __pyx_state[9]; __pyx_result.__shallow_parse = __pyx_state[10]; __pyx_result.__slot = __pyx_state[11]; __pyx_result.__universal_dependency = __pyx_state[12]; __pyx_result.name = __pyx_state[13]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_AnnotatedWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.__pyx_unpickle_AnnotatedWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_AnnotatedWord__set_state(<AnnotatedWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_AnnotatedWord__set_state(AnnotatedWord __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__argument = __pyx_state[0]; __pyx_result.__ccg = __pyx_state[1]; __pyx_result.__frame_element = __pyx_state[2]; __pyx_result.__language = __pyx_state[3]; __pyx_result.__metamorphic_parse = __pyx_state[4]; __pyx_result.__named_entity_type = __pyx_state[5]; __pyx_result.__parse = __pyx_state[6]; __pyx_result.__polarity = __pyx_state[7]; __pyx_result.__pos_tag = __pyx_state[8]; __pyx_result.__semantic = __pyx_state[9]; __pyx_result.__shallow_parse = __pyx_state[10]; __pyx_result.__slot = __pyx_state[11]; __pyx_result.__universal_dependency = __pyx_state[12]; __pyx_result.name = __pyx_state[13]
 *     if len(__pyx_state) > 14 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_17AnnotatedSentence_13AnnotatedWord___pyx_unpickle_AnnotatedWord__set_state(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_AnnotatedWord__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_AnnotatedWord__set_state(AnnotatedWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__argument = __pyx_state[0]; __pyx_result.__ccg = __pyx_state[1]; __pyx_result.__frame_element = __pyx_state[2]; __pyx_result.__language = __pyx_state[3]; __pyx_result.__metamorphic_parse = __pyx_state[4]; __pyx_result.__named_entity_type = __pyx_state[5]; __pyx_result.__parse = __pyx_state[6]; __pyx_result.__polarity = __pyx_state[7]; __pyx_result.__pos_tag = __pyx_state[8]; __pyx_result.__semantic = __pyx_state[9]; __pyx_result.__shallow_parse = __pyx_state[10]; __pyx_result.__slot = __pyx_state[11]; __pyx_result.__universal_dependency = __pyx_state[12]; __pyx_result.name = __pyx_state[13]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 14 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[14])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_8PropBank_8Argument_Argument))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___argument);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___argument));
  __pyx_v___pyx_result->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___ccg);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___ccg);
  __pyx_v___pyx_result->__pyx___ccg = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_8FrameNet_12FrameElement_FrameElement))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___frame_element);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___frame_element));
  __pyx_v___pyx_result->__pyx___frame_element = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___language);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___language);
  __pyx_v___pyx_result->__pyx___language = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___metamorphic_parse);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___metamorphic_parse));
  __pyx_v___pyx_result->__pyx___metamorphic_parse = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___named_entity_type);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___named_entity_type);
  __pyx_v___pyx_result->__pyx___named_entity_type = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___parse);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___parse));
  __pyx_v___pyx_result->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___polarity);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___polarity);
  __pyx_v___pyx_result->__pyx___polarity = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___pos_tag);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___pos_tag);
  __pyx_v___pyx_result->__pyx___pos_tag = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___semantic);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___semantic);
  __pyx_v___pyx_result->__pyx___semantic = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___shallow_parse);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___shallow_parse);
  __pyx_v___pyx_result->__pyx___shallow_parse = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 11, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_22NamedEntityRecognition_4Slot_Slot))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___slot);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___slot));
  __pyx_v___pyx_result->__pyx___slot = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 12, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___universal_dependency);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->__pyx___universal_dependency));
  __pyx_v___pyx_result->__pyx___universal_dependency = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 13, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.name);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.name);
  __pyx_v___pyx_result->__pyx_base.name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_AnnotatedWord__set_state(AnnotatedWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__argument = __pyx_state[0]; __pyx_result.__ccg = __pyx_state[1]; __pyx_result.__frame_element = __pyx_state[2]; __pyx_result.__language = __pyx_state[3]; __pyx_result.__metamorphic_parse = __pyx_state[4]; __pyx_result.__named_entity_type = __pyx_state[5]; __pyx_result.__parse = __pyx_state[6]; __pyx_result.__polarity = __pyx_state[7]; __pyx_result.__pos_tag = __pyx_state[8]; __pyx_result.__semantic = __pyx_state[9]; __pyx_result.__shallow_parse = __pyx_state[10]; __pyx_result.__slot = __pyx_state[11]; __pyx_result.__universal_dependency = __pyx_state[12]; __pyx_result.name = __pyx_state[13]
 *     if len(__pyx_state) > 14 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[14])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 14) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.__argument = __pyx_state[0]; __pyx_result.__ccg = __pyx_state[1]; __pyx_result.__frame_element = __pyx_state[2]; __pyx_result.__language = __pyx_state[3]; __pyx_result.__metamorphic_parse = __pyx_state[4]; __pyx_result.__named_entity_type = __pyx_state[5]; __pyx_result.__parse = __pyx_state[6]; __pyx_result.__polarity = __pyx_state[7]; __pyx_result.__pos_tag = __pyx_state[8]; __pyx_result.__semantic = __pyx_state[9]; __pyx_result.__shallow_parse = __pyx_state[10]; __pyx_result.__slot = __pyx_state[11]; __pyx_result.__universal_dependency = __pyx_state[12]; __pyx_result.name = __pyx_state[13]
 *     if len(__pyx_state) > 14 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[14])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 14, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_AnnotatedWord__set_state(AnnotatedWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__argument = __pyx_state[0]; __pyx_result.__ccg = __pyx_state[1]; __pyx_result.__frame_element = __pyx_state[2]; __pyx_result.__language = __pyx_state[3]; __pyx_result.__metamorphic_parse = __pyx_state[4]; __pyx_result.__named_entity_type = __pyx_state[5]; __pyx_result.__parse = __pyx_state[6]; __pyx_result.__polarity = __pyx_state[7]; __pyx_result.__pos_tag = __pyx_state[8]; __pyx_result.__semantic = __pyx_state[9]; __pyx_result.__shallow_parse = __pyx_state[10]; __pyx_result.__slot = __pyx_state[11]; __pyx_result.__universal_dependency = __pyx_state[12]; __pyx_result.name = __pyx_state[13]
 *     if len(__pyx_state) > 14 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[14])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_AnnotatedWord__set_state(<AnnotatedWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_AnnotatedWord__set_state(AnnotatedWord __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__argument = __pyx_state[0]; __pyx_result.__ccg = __pyx_state[1]; __pyx_result.__frame_element = __pyx_state[2]; __pyx_result.__language = __pyx_state[3]; __pyx_result.__metamorphic_parse = __pyx_state[4]; __pyx_result.__named_entity_type = __pyx_state[5]; __pyx_result.__parse = __pyx_state[6]; __pyx_result.__polarity = __pyx_state[7]; __pyx_result.__pos_tag = __pyx_state[8]; __pyx_result.__semantic = __pyx_state[9]; __pyx_result.__shallow_parse = __pyx_state[10]; __pyx_result.__slot = __pyx_state[11]; __pyx_result.__universal_dependency = __pyx_state[12]; __pyx_result.name = __pyx_state[13]
 *     if len(__pyx_state) > 14 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("AnnotatedSentence.AnnotatedWord.__pyx_unpickle_AnnotatedWord__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord;

static PyObject *__pyx_tp_new_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *p;
  PyObject *o = __pyx_ptype_10Dictionary_4Word_Word->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__pyx_vtabptr_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord;
  p->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)Py_None); Py_INCREF(Py_None);
  p->__pyx___metamorphic_parse = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)Py_None); Py_INCREF(Py_None);
  p->__pyx___semantic = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___named_entity_type = Py_None; Py_INCREF(Py_None);
  p->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)Py_None); Py_INCREF(Py_None);
  p->__pyx___frame_element = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)Py_None); Py_INCREF(Py_None);
  p->__pyx___shallow_parse = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___universal_dependency = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)Py_None); Py_INCREF(Py_None);
  p->__pyx___slot = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)Py_None); Py_INCREF(Py_None);
  p->__pyx___polarity = Py_None; Py_INCREF(Py_None);
  p->__pyx___ccg = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___pos_tag = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___language = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord(PyObject *o) {
  struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *p = (struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx___parse);
  Py_CLEAR(p->__pyx___metamorphic_parse);
  Py_CLEAR(p->__pyx___semantic);
  Py_CLEAR(p->__pyx___named_entity_type);
  Py_CLEAR(p->__pyx___argument);
  Py_CLEAR(p->__pyx___frame_element);
  Py_CLEAR(p->__pyx___shallow_parse);
  Py_CLEAR(p->__pyx___universal_dependency);
  Py_CLEAR(p->__pyx___slot);
  Py_CLEAR(p->__pyx___polarity);
  Py_CLEAR(p->__pyx___ccg);
  Py_CLEAR(p->__pyx___pos_tag);
  Py_CLEAR(p->__pyx___language);
  #if CYTHON_USE_TYPE_SLOTS
  if (PyType_IS_GC(Py_TYPE(o)->tp_base))
  #endif
  PyObject_GC_Track(o);
  if (likely(__pyx_ptype_10Dictionary_4Word_Word)) __pyx_ptype_10Dictionary_4Word_Word->tp_dealloc(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord);
}

static int __pyx_tp_traverse_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *p = (struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)o;
  e = ((likely(__pyx_ptype_10Dictionary_4Word_Word)) ? ((__pyx_ptype_10Dictionary_4Word_Word->tp_traverse) ? __pyx_ptype_10Dictionary_4Word_Word->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord)); if (e) return e;
  if (p->__pyx___parse) {
    e = (*v)(((PyObject *)p->__pyx___parse), a); if (e) return e;
  }
  if (p->__pyx___metamorphic_parse) {
    e = (*v)(((PyObject *)p->__pyx___metamorphic_parse), a); if (e) return e;
  }
  if (p->__pyx___named_entity_type) {
    e = (*v)(p->__pyx___named_entity_type, a); if (e) return e;
  }
  if (p->__pyx___argument) {
    e = (*v)(((PyObject *)p->__pyx___argument), a); if (e) return e;
  }
  if (p->__pyx___frame_element) {
    e = (*v)(((PyObject *)p->__pyx___frame_element), a); if (e) return e;
  }
  if (p->__pyx___universal_dependency) {
    e = (*v)(((PyObject *)p->__pyx___universal_dependency), a); if (e) return e;
  }
  if (p->__pyx___slot) {
    e = (*v)(((PyObject *)p->__pyx___slot), a); if (e) return e;
  }
  if (p->__pyx___polarity) {
    e = (*v)(p->__pyx___polarity, a); if (e) return e;
  }
  if (p->__pyx___language) {
    e = (*v)(p->__pyx___language, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *p = (struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *)o;
  if (likely(__pyx_ptype_10Dictionary_4Word_Word)) { if (__pyx_ptype_10Dictionary_4Word_Word->tp_clear) __pyx_ptype_10Dictionary_4Word_Word->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord);
  tmp = ((PyObject*)p->__pyx___parse);
  p->__pyx___parse = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___metamorphic_parse);
  p->__pyx___metamorphic_parse = ((struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___named_entity_type);
  p->__pyx___named_entity_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___argument);
  p->__pyx___argument = ((struct __pyx_obj_8PropBank_8Argument_Argument *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___frame_element);
  p->__pyx___frame_element = ((struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___universal_dependency);
  p->__pyx___universal_dependency = ((struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___slot);
  p->__pyx___slot = ((struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___polarity);
  p->__pyx___polarity = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx___language);
  p->__pyx___language = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord[] = {
  {"getLayerInfo", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_5getLayerInfo, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_4getLayerInfo},
  {"getParse", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_7getParse, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_6getParse},
  {"setParse", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_9setParse, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_8setParse},
  {"getMetamorphicParse", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_11getMetamorphicParse, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_10getMetamorphicParse},
  {"setMetamorphicParse", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_13setMetamorphicParse, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_12setMetamorphicParse},
  {"getSemantic", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_15getSemantic, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_14getSemantic},
  {"setSemantic", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_17setSemantic, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_16setSemantic},
  {"getNamedEntityType", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_19getNamedEntityType, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_18getNamedEntityType},
  {"setNamedEntityType", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_21setNamedEntityType, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_20setNamedEntityType},
  {"getArgument", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_23getArgument, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_22getArgument},
  {"setArgument", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_25setArgument, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_24setArgument},
  {"getFrameElement", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_27getFrameElement, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_26getFrameElement},
  {"setFrameElement", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_29setFrameElement, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_28setFrameElement},
  {"getSlot", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_31getSlot, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_30getSlot},
  {"setSlot", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_33setSlot, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_32setSlot},
  {"getPolarity", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_35getPolarity, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_34getPolarity},
  {"getPolarityString", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_37getPolarityString, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_36getPolarityString},
  {"setPolarity", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_39setPolarity, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_38setPolarity},
  {"getShallowParse", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_41getShallowParse, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_40getShallowParse},
  {"setShallowParse", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_43setShallowParse, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_42setShallowParse},
  {"getCcg", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_45getCcg, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_44getCcg},
  {"setCcg", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_47setCcg, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_46setCcg},
  {"getPosTag", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_49getPosTag, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_48getPosTag},
  {"setPosTag", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_51setPosTag, METH_O, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_50setPosTag},
  {"getUniversalDependency", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_53getUniversalDependency, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_52getUniversalDependency},
  {"setUniversalDependency", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_55setUniversalDependency, METH_VARARGS|METH_KEYWORDS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_54setUniversalDependency},
  {"getUniversalDependencyFormat", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_57getUniversalDependencyFormat, METH_O, 0},
  {"getFormattedString", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_59getFormattedString, METH_O, 0},
  {"checkGazetteer", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_61checkGazetteer, METH_O, 0},
  {"getLanguage", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_63getLanguage, METH_NOARGS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_62getLanguage},
  {"getLanguageFromString", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_65getLanguageFromString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_64getLanguageFromString},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_67__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_69__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord = {
  PyVarObject_HEAD_INIT(0, 0)
  "AnnotatedSentence.AnnotatedWord.AnnotatedWord", /*tp_name*/
  sizeof(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_3__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n     * In order to add another layer, do the following:\n     * 1. Select a name for the layer.\n     * 2. Add a new constant to ViewLayerType.\n     * 3. Add private attribute.\n     * 4. Add an if-else to the constructor, where you set the private attribute with the layer name.\n     * 5. Update toString method.\n     * 6. Add initial value to the private attribute in other constructors.\n     * 7. Update getLayerInfo.\n     * 8. Add getter and setter methods.\n    ", /*tp_doc*/
  __pyx_tp_traverse_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, /*tp_traverse*/
  __pyx_tp_clear_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_AnnotatedWord(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_AnnotatedWord},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "AnnotatedWord",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
  {&__pyx_kp_s_AnnotatedSentence_AnnotatedWord, __pyx_k_AnnotatedSentence_AnnotatedWord, sizeof(__pyx_k_AnnotatedSentence_AnnotatedWord), 0, 0, 1, 0},
  {&__pyx_n_s_AnnotatedSentence_AnnotatedWord_2, __pyx_k_AnnotatedSentence_AnnotatedWord_2, sizeof(__pyx_k_AnnotatedSentence_AnnotatedWord_2), 0, 0, 1, 1},
  {&__pyx_n_s_AnnotatedSentence_Language, __pyx_k_AnnotatedSentence_Language, sizeof(__pyx_k_AnnotatedSentence_Language), 0, 0, 1, 1},
  {&__pyx_n_s_AnnotatedSentence_ViewLayerType, __pyx_k_AnnotatedSentence_ViewLayerType, sizeof(__pyx_k_AnnotatedSentence_ViewLayerType), 0, 0, 1, 1},
  {&__pyx_n_s_AnnotatedWord, __pyx_k_AnnotatedWord, sizeof(__pyx_k_AnnotatedWord), 0, 0, 1, 1},
  {&__pyx_n_s_CCG, __pyx_k_CCG, sizeof(__pyx_k_CCG), 0, 0, 1, 1},
  {&__pyx_n_s_Corpus_WordFormat, __pyx_k_Corpus_WordFormat, sizeof(__pyx_k_Corpus_WordFormat), 0, 0, 1, 1},
  {&__pyx_n_s_DEPENDENCY, __pyx_k_DEPENDENCY, sizeof(__pyx_k_DEPENDENCY), 0, 0, 1, 1},
  {&__pyx_n_s_ENGLISH, __pyx_k_ENGLISH, sizeof(__pyx_k_ENGLISH), 0, 0, 1, 1},
  {&__pyx_n_u_English, __pyx_k_English, sizeof(__pyx_k_English), 0, 1, 0, 1},
  {&__pyx_n_s_FRAMENET, __pyx_k_FRAMENET, sizeof(__pyx_k_FRAMENET), 0, 0, 1, 1},
  {&__pyx_n_s_INFLECTIONAL_GROUP, __pyx_k_INFLECTIONAL_GROUP, sizeof(__pyx_k_INFLECTIONAL_GROUP), 0, 0, 1, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x28, __pyx_k_Incompatible_checksums_s_vs_0x28, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x28), 0, 0, 1, 0},
  {&__pyx_n_s_Language, __pyx_k_Language, sizeof(__pyx_k_Language), 0, 0, 1, 1},
  {&__pyx_n_s_META_MORPHEME, __pyx_k_META_MORPHEME, sizeof(__pyx_k_META_MORPHEME), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalAnalysis_Morphologi, __pyx_k_MorphologicalAnalysis_Morphologi, sizeof(__pyx_k_MorphologicalAnalysis_Morphologi), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalTag, __pyx_k_MorphologicalTag, sizeof(__pyx_k_MorphologicalTag), 0, 0, 1, 1},
  {&__pyx_n_s_NEGATIVE, __pyx_k_NEGATIVE, sizeof(__pyx_k_NEGATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_NER, __pyx_k_NER, sizeof(__pyx_k_NER), 0, 0, 1, 1},
  {&__pyx_n_s_NEUTRAL, __pyx_k_NEUTRAL, sizeof(__pyx_k_NEUTRAL), 0, 0, 1, 1},
  {&__pyx_n_s_NONE, __pyx_k_NONE, sizeof(__pyx_k_NONE), 0, 0, 1, 1},
  {&__pyx_n_u_NONE, __pyx_k_NONE, sizeof(__pyx_k_NONE), 0, 1, 0, 1},
  {&__pyx_n_s_NamedEntityRecognition_NamedEnti, __pyx_k_NamedEntityRecognition_NamedEnti, sizeof(__pyx_k_NamedEntityRecognition_NamedEnti), 0, 0, 1, 1},
  {&__pyx_n_s_NamedEntityType, __pyx_k_NamedEntityType, sizeof(__pyx_k_NamedEntityType), 0, 0, 1, 1},
  {&__pyx_n_s_PERSIAN, __pyx_k_PERSIAN, sizeof(__pyx_k_PERSIAN), 0, 0, 1, 1},
  {&__pyx_n_s_POLARITY, __pyx_k_POLARITY, sizeof(__pyx_k_POLARITY), 0, 0, 1, 1},
  {&__pyx_n_s_POSITIVE, __pyx_k_POSITIVE, sizeof(__pyx_k_POSITIVE), 0, 0, 1, 1},
  {&__pyx_n_s_POS_TAG, __pyx_k_POS_TAG, sizeof(__pyx_k_POS_TAG), 0, 0, 1, 1},
  {&__pyx_n_s_PROPBANK, __pyx_k_PROPBANK, sizeof(__pyx_k_PROPBANK), 0, 0, 1, 1},
  {&__pyx_n_s_PROPERNOUN, __pyx_k_PROPERNOUN, sizeof(__pyx_k_PROPERNOUN), 0, 0, 1, 1},
  {&__pyx_n_u_Persian, __pyx_k_Persian, sizeof(__pyx_k_Persian), 0, 1, 0, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_PolarityType, __pyx_k_PolarityType, sizeof(__pyx_k_PolarityType), 0, 0, 1, 1},
  {&__pyx_n_s_SEMANTICS, __pyx_k_SEMANTICS, sizeof(__pyx_k_SEMANTICS), 0, 0, 1, 1},
  {&__pyx_n_s_SHALLOW_PARSE, __pyx_k_SHALLOW_PARSE, sizeof(__pyx_k_SHALLOW_PARSE), 0, 0, 1, 1},
  {&__pyx_n_s_SLOT, __pyx_k_SLOT, sizeof(__pyx_k_SLOT), 0, 0, 1, 1},
  {&__pyx_n_s_SURFACE, __pyx_k_SURFACE, sizeof(__pyx_k_SURFACE), 0, 0, 1, 1},
  {&__pyx_n_s_SentiNet_PolarityType, __pyx_k_SentiNet_PolarityType, sizeof(__pyx_k_SentiNet_PolarityType), 0, 0, 1, 1},
  {&__pyx_n_s_TURKISH, __pyx_k_TURKISH, sizeof(__pyx_k_TURKISH), 0, 0, 1, 1},
  {&__pyx_n_s_TURKISH_WORD, __pyx_k_TURKISH_WORD, sizeof(__pyx_k_TURKISH_WORD), 0, 0, 1, 1},
  {&__pyx_n_u_Turkish, __pyx_k_Turkish, sizeof(__pyx_k_Turkish), 0, 1, 0, 1},
  {&__pyx_n_s_ViewLayerType, __pyx_k_ViewLayerType, sizeof(__pyx_k_ViewLayerType), 0, 0, 1, 1},
  {&__pyx_n_s_WordFormat, __pyx_k_WordFormat, sizeof(__pyx_k_WordFormat), 0, 0, 1, 1},
  {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
  {&__pyx_kp_u__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 1, 0, 0},
  {&__pyx_kp_u__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 1, 0, 0},
  {&__pyx_kp_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 0},
  {&__pyx_kp_u__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 1, 0, 0},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
  {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
  {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
  {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
  {&__pyx_n_u__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 1, 0, 1},
  {&__pyx_n_u_ccg, __pyx_k_ccg, sizeof(__pyx_k_ccg), 0, 1, 0, 1},
  {&__pyx_kp_u_ccg_2, __pyx_k_ccg_2, sizeof(__pyx_k_ccg_2), 0, 1, 0, 0},
  {&__pyx_n_s_checkGazetteer, __pyx_k_checkGazetteer, sizeof(__pyx_k_checkGazetteer), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
  {&__pyx_n_s_dependencyType, __pyx_k_dependencyType, sizeof(__pyx_k_dependencyType), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_u_english, __pyx_k_english, sizeof(__pyx_k_english), 0, 1, 0, 1},
  {&__pyx_kp_u_english_2, __pyx_k_english_2, sizeof(__pyx_k_english_2), 0, 1, 0, 0},
  {&__pyx_n_u_frameNet, __pyx_k_frameNet, sizeof(__pyx_k_frameNet), 0, 1, 0, 1},
  {&__pyx_n_u_framenet, __pyx_k_framenet, sizeof(__pyx_k_framenet), 0, 1, 0, 1},
  {&__pyx_kp_u_framenet_2, __pyx_k_framenet_2, sizeof(__pyx_k_framenet_2), 0, 1, 0, 0},
  {&__pyx_n_s_getArgument, __pyx_k_getArgument, sizeof(__pyx_k_getArgument), 0, 0, 1, 1},
  {&__pyx_n_s_getCcg, __pyx_k_getCcg, sizeof(__pyx_k_getCcg), 0, 0, 1, 1},
  {&__pyx_n_s_getFormattedString, __pyx_k_getFormattedString, sizeof(__pyx_k_getFormattedString), 0, 0, 1, 1},
  {&__pyx_n_s_getFrameElement, __pyx_k_getFrameElement, sizeof(__pyx_k_getFrameElement), 0, 0, 1, 1},
  {&__pyx_n_s_getLanguage, __pyx_k_getLanguage, sizeof(__pyx_k_getLanguage), 0, 0, 1, 1},
  {&__pyx_n_s_getLanguageFromString, __pyx_k_getLanguageFromString, sizeof(__pyx_k_getLanguageFromString), 0, 0, 1, 1},
  {&__pyx_n_s_getLayerInfo, __pyx_k_getLayerInfo, sizeof(__pyx_k_getLayerInfo), 0, 0, 1, 1},
  {&__pyx_n_s_getMetamorphicParse, __pyx_k_getMetamorphicParse, sizeof(__pyx_k_getMetamorphicParse), 0, 0, 1, 1},
  {&__pyx_n_s_getNamedEntityString, __pyx_k_getNamedEntityString, sizeof(__pyx_k_getNamedEntityString), 0, 0, 1, 1},
  {&__pyx_n_s_getNamedEntityType, __pyx_k_getNamedEntityType, sizeof(__pyx_k_getNamedEntityType), 0, 0, 1, 1},
  {&__pyx_n_s_getParse, __pyx_k_getParse, sizeof(__pyx_k_getParse), 0, 0, 1, 1},
  {&__pyx_n_s_getPolarity, __pyx_k_getPolarity, sizeof(__pyx_k_getPolarity), 0, 0, 1, 1},
  {&__pyx_n_s_getPolarityString, __pyx_k_getPolarityString, sizeof(__pyx_k_getPolarityString), 0, 0, 1, 1},
  {&__pyx_n_s_getPosTag, __pyx_k_getPosTag, sizeof(__pyx_k_getPosTag), 0, 0, 1, 1},
  {&__pyx_n_s_getSemantic, __pyx_k_getSemantic, sizeof(__pyx_k_getSemantic), 0, 0, 1, 1},
  {&__pyx_n_s_getShallowParse, __pyx_k_getShallowParse, sizeof(__pyx_k_getShallowParse), 0, 0, 1, 1},
  {&__pyx_n_s_getSlot, __pyx_k_getSlot, sizeof(__pyx_k_getSlot), 0, 0, 1, 1},
  {&__pyx_n_s_getUniversalDependency, __pyx_k_getUniversalDependency, sizeof(__pyx_k_getUniversalDependency), 0, 0, 1, 1},
  {&__pyx_n_s_getUniversalDependencyFormat, __pyx_k_getUniversalDependencyFormat, sizeof(__pyx_k_getUniversalDependencyFormat), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_languageString, __pyx_k_languageString, sizeof(__pyx_k_languageString), 0, 0, 1, 1},
  {&__pyx_n_s_layerType, __pyx_k_layerType, sizeof(__pyx_k_layerType), 0, 0, 1, 1},
  {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_u_metaMorphemes, __pyx_k_metaMorphemes, sizeof(__pyx_k_metaMorphemes), 0, 1, 0, 1},
  {&__pyx_kp_u_metaMorphemes_2, __pyx_k_metaMorphemes_2, sizeof(__pyx_k_metaMorphemes_2), 0, 1, 0, 0},
  {&__pyx_n_u_morphologicalAnalysis, __pyx_k_morphologicalAnalysis, sizeof(__pyx_k_morphologicalAnalysis), 0, 1, 0, 1},
  {&__pyx_kp_u_morphologicalAnalysis_2, __pyx_k_morphologicalAnalysis_2, sizeof(__pyx_k_morphologicalAnalysis_2), 0, 1, 0, 0},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_u_namedEntity, __pyx_k_namedEntity, sizeof(__pyx_k_namedEntity), 0, 1, 0, 1},
  {&__pyx_kp_u_namedEntity_2, __pyx_k_namedEntity_2, sizeof(__pyx_k_namedEntity_2), 0, 1, 0, 0},
  {&__pyx_n_u_neg, __pyx_k_neg, sizeof(__pyx_k_neg), 0, 1, 0, 1},
  {&__pyx_n_u_negative, __pyx_k_negative, sizeof(__pyx_k_negative), 0, 1, 0, 1},
  {&__pyx_n_u_neutral, __pyx_k_neutral, sizeof(__pyx_k_neutral), 0, 1, 0, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_u_persian, __pyx_k_persian, sizeof(__pyx_k_persian), 0, 1, 0, 1},
  {&__pyx_kp_u_persian_2, __pyx_k_persian_2, sizeof(__pyx_k_persian_2), 0, 1, 0, 0},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_u_polarity, __pyx_k_polarity, sizeof(__pyx_k_polarity), 0, 1, 0, 1},
  {&__pyx_kp_u_polarity_2, __pyx_k_polarity_2, sizeof(__pyx_k_polarity_2), 0, 1, 0, 0},
  {&__pyx_n_u_pos, __pyx_k_pos, sizeof(__pyx_k_pos), 0, 1, 0, 1},
  {&__pyx_n_u_posTag, __pyx_k_posTag, sizeof(__pyx_k_posTag), 0, 1, 0, 1},
  {&__pyx_kp_u_posTag_2, __pyx_k_posTag_2, sizeof(__pyx_k_posTag_2), 0, 1, 0, 0},
  {&__pyx_n_u_positive, __pyx_k_positive, sizeof(__pyx_k_positive), 0, 1, 0, 1},
  {&__pyx_n_u_propBank, __pyx_k_propBank, sizeof(__pyx_k_propBank), 0, 1, 0, 1},
  {&__pyx_n_u_propbank, __pyx_k_propbank, sizeof(__pyx_k_propbank), 0, 1, 0, 1},
  {&__pyx_kp_u_propbank_2, __pyx_k_propbank_2, sizeof(__pyx_k_propbank_2), 0, 1, 0, 0},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_AnnotatedWord, __pyx_k_pyx_unpickle_AnnotatedWord, sizeof(__pyx_k_pyx_unpickle_AnnotatedWord), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_u_semantics, __pyx_k_semantics, sizeof(__pyx_k_semantics), 0, 1, 0, 1},
  {&__pyx_kp_u_semantics_2, __pyx_k_semantics_2, sizeof(__pyx_k_semantics_2), 0, 1, 0, 0},
  {&__pyx_n_s_setArgument, __pyx_k_setArgument, sizeof(__pyx_k_setArgument), 0, 0, 1, 1},
  {&__pyx_n_s_setCcg, __pyx_k_setCcg, sizeof(__pyx_k_setCcg), 0, 0, 1, 1},
  {&__pyx_n_s_setFrameElement, __pyx_k_setFrameElement, sizeof(__pyx_k_setFrameElement), 0, 0, 1, 1},
  {&__pyx_n_s_setMetamorphicParse, __pyx_k_setMetamorphicParse, sizeof(__pyx_k_setMetamorphicParse), 0, 0, 1, 1},
  {&__pyx_n_s_setNamedEntityType, __pyx_k_setNamedEntityType, sizeof(__pyx_k_setNamedEntityType), 0, 0, 1, 1},
  {&__pyx_n_s_setParse, __pyx_k_setParse, sizeof(__pyx_k_setParse), 0, 0, 1, 1},
  {&__pyx_n_s_setPolarity, __pyx_k_setPolarity, sizeof(__pyx_k_setPolarity), 0, 0, 1, 1},
  {&__pyx_n_s_setPosTag, __pyx_k_setPosTag, sizeof(__pyx_k_setPosTag), 0, 0, 1, 1},
  {&__pyx_n_s_setSemantic, __pyx_k_setSemantic, sizeof(__pyx_k_setSemantic), 0, 0, 1, 1},
  {&__pyx_n_s_setShallowParse, __pyx_k_setShallowParse, sizeof(__pyx_k_setShallowParse), 0, 0, 1, 1},
  {&__pyx_n_s_setSlot, __pyx_k_setSlot, sizeof(__pyx_k_setSlot), 0, 0, 1, 1},
  {&__pyx_n_s_setUniversalDependency, __pyx_k_setUniversalDependency, sizeof(__pyx_k_setUniversalDependency), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_u_shallowParse, __pyx_k_shallowParse, sizeof(__pyx_k_shallowParse), 0, 1, 0, 1},
  {&__pyx_kp_u_shallowParse_2, __pyx_k_shallowParse_2, sizeof(__pyx_k_shallowParse_2), 0, 1, 0, 0},
  {&__pyx_n_u_slot, __pyx_k_slot, sizeof(__pyx_k_slot), 0, 1, 0, 1},
  {&__pyx_kp_u_slot_2, __pyx_k_slot_2, sizeof(__pyx_k_slot_2), 0, 1, 0, 0},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_staticmethod, __pyx_k_staticmethod, sizeof(__pyx_k_staticmethod), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_to, __pyx_k_to, sizeof(__pyx_k_to), 0, 0, 1, 1},
  {&__pyx_n_u_turkish, __pyx_k_turkish, sizeof(__pyx_k_turkish), 0, 1, 0, 1},
  {&__pyx_kp_u_turkish_2, __pyx_k_turkish_2, sizeof(__pyx_k_turkish_2), 0, 1, 0, 0},
  {&__pyx_n_u_universalDependency, __pyx_k_universalDependency, sizeof(__pyx_k_universalDependency), 0, 1, 0, 1},
  {&__pyx_kp_u_universalDependency_2, __pyx_k_universalDependency_2, sizeof(__pyx_k_universalDependency_2), 0, 1, 0, 0},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_withList, __pyx_k_withList, sizeof(__pyx_k_withList), 0, 0, 1, 1},
  {&__pyx_n_s_word, __pyx_k_word, sizeof(__pyx_k_word), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_n_s_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 555, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(0, 79, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "AnnotatedSentence/AnnotatedWord.pyx":81
 *             super().__init__(word)
 *             self.__named_entity_type = layerType
 *             self.__argument = Argument("NONE")             # <<<<<<<<<<<<<<
 *         elif isinstance(layerType, MorphologicalParse):
 *             super().__init__(word)
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_n_u_NONE); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "AnnotatedSentence/AnnotatedWord.pyx":556
 * 
 *     @staticmethod
 *     def getLanguageFromString(languageString: str) -> Language:             # <<<<<<<<<<<<<<
 *         """
 *         Converts a language string to language.
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_n_s_languageString); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_AnnotatedSentence_AnnotatedWord, __pyx_n_s_getLanguageFromString, 556, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) __PYX_ERR(0, 556, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_AnnotatedWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__17 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);
  __pyx_codeobj__18 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__17, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_AnnotatedWord, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__18)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyUnicode_Type_index.type = (PyObject*)&PyUnicode_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_42354475 = PyInt_FromLong(42354475L); if (unlikely(!__pyx_int_42354475)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Word"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Word_Word = __Pyx_ImportType(__pyx_t_1, "Dictionary.Word", "Word", sizeof(struct __pyx_obj_10Dictionary_4Word_Word), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Word_Word) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Word_Word = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Word_Word->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Word_Word)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord = &__pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.__pyx_base = *__pyx_vtabptr_10Dictionary_4Word_Word;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getLayerInfo = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLayerInfo;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getParse = (struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getParse;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setParse = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setParse;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getMetamorphicParse = (struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getMetamorphicParse;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setMetamorphicParse = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setMetamorphicParse;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getSemantic = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSemantic;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setSemantic = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSemantic;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getNamedEntityType = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getNamedEntityType;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setNamedEntityType = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setNamedEntityType;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getArgument = (struct __pyx_obj_8PropBank_8Argument_Argument *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getArgument;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setArgument = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setArgument;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getFrameElement = (struct __pyx_obj_8FrameNet_12FrameElement_FrameElement *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFrameElement;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setFrameElement = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setFrameElement;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getSlot = (struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getSlot;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setSlot = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setSlot;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getPolarity = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarity;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getPolarityString = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPolarityString;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setPolarity = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPolarity;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getShallowParse = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getShallowParse;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setShallowParse = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setShallowParse;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getCcg = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getCcg;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setCcg = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setCcg;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getPosTag = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getPosTag;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setPosTag = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setPosTag;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getUniversalDependency = (struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependency;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.setUniversalDependency = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_setUniversalDependency;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getUniversalDependencyFormat = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getUniversalDependencyFormat;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getFormattedString = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getFormattedString;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.checkGazetteer = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_checkGazetteer;
  __pyx_vtable_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.getLanguage = (PyObject *(*)(struct __pyx_obj_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord *, int __pyx_skip_dispatch))__pyx_f_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_getLanguage;
  __pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.tp_base = __pyx_ptype_10Dictionary_4Word_Word;
  if (PyType_Ready(&__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.tp_dictoffset && __pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 11, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__.doc = __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord___init__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, "__str__"); if (unlikely(!wrapper)) __PYX_ERR(0, 11, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__.doc = __pyx_doc_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_2__str__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord.tp_dict, __pyx_vtabptr_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_AnnotatedWord, (PyObject *)&__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  __pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord = &__pyx_type_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("DependencyParser.DependencyRelation"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_16DependencyParser_18DependencyRelation_DependencyRelation = __Pyx_ImportType(__pyx_t_1, "DependencyParser.DependencyRelation", "DependencyRelation", sizeof(struct __pyx_obj_16DependencyParser_18DependencyRelation_DependencyRelation), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_16DependencyParser_18DependencyRelation_DependencyRelation) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_vtabptr_16DependencyParser_18DependencyRelation_DependencyRelation = (struct __pyx_vtabstruct_16DependencyParser_18DependencyRelation_DependencyRelation*)__Pyx_GetVtable(__pyx_ptype_16DependencyParser_18DependencyRelation_DependencyRelation->tp_dict); if (unlikely(!__pyx_vtabptr_16DependencyParser_18DependencyRelation_DependencyRelation)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DependencyParser.ParserEvaluationScore"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore = __Pyx_ImportType(__pyx_t_1, "DependencyParser.ParserEvaluationScore", "ParserEvaluationScore", sizeof(struct __pyx_obj_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore) __PYX_ERR(3, 1, __pyx_L1_error)
  __pyx_vtabptr_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore = (struct __pyx_vtabstruct_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore*)__Pyx_GetVtable(__pyx_ptype_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore->tp_dict); if (unlikely(!__pyx_vtabptr_16DependencyParser_21ParserEvaluationScore_ParserEvaluationScore)) __PYX_ERR(3, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("DependencyParser.Universal.UniversalDependencyRelation"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation = __Pyx_ImportType(__pyx_t_1, "DependencyParser.Universal.UniversalDependencyRelation", "UniversalDependencyRelation", sizeof(struct __pyx_obj_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation) __PYX_ERR(4, 4, __pyx_L1_error)
  __pyx_vtabptr_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation = (struct __pyx_vtabstruct_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation*)__Pyx_GetVtable(__pyx_ptype_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation->tp_dict); if (unlikely(!__pyx_vtabptr_16DependencyParser_9Universal_27UniversalDependencyRelation_UniversalDependencyRelation)) __PYX_ERR(4, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("FrameNet.FrameElement"); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8FrameNet_12FrameElement_FrameElement = __Pyx_ImportType(__pyx_t_1, "FrameNet.FrameElement", "FrameElement", sizeof(struct __pyx_obj_8FrameNet_12FrameElement_FrameElement), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_8FrameNet_12FrameElement_FrameElement) __PYX_ERR(5, 1, __pyx_L1_error)
  __pyx_vtabptr_8FrameNet_12FrameElement_FrameElement = (struct __pyx_vtabstruct_8FrameNet_12FrameElement_FrameElement*)__Pyx_GetVtable(__pyx_ptype_8FrameNet_12FrameElement_FrameElement->tp_dict); if (unlikely(!__pyx_vtabptr_8FrameNet_12FrameElement_FrameElement)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.InflectionalGroup"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.InflectionalGroup", "InflectionalGroup", sizeof(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup) __PYX_ERR(6, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = (struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.MorphologicalParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.MorphologicalParse", "MorphologicalParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) __PYX_ERR(7, 6, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse)) __PYX_ERR(7, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.MetamorphicParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.MetamorphicParse", "MetamorphicParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse) __PYX_ERR(8, 6, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_16MetamorphicParse_MetamorphicParse)) __PYX_ERR(8, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("NamedEntityRecognition.Gazetteer"); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_22NamedEntityRecognition_9Gazetteer_Gazetteer = __Pyx_ImportType(__pyx_t_1, "NamedEntityRecognition.Gazetteer", "Gazetteer", sizeof(struct __pyx_obj_22NamedEntityRecognition_9Gazetteer_Gazetteer), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_22NamedEntityRecognition_9Gazetteer_Gazetteer) __PYX_ERR(9, 1, __pyx_L1_error)
  __pyx_vtabptr_22NamedEntityRecognition_9Gazetteer_Gazetteer = (struct __pyx_vtabstruct_22NamedEntityRecognition_9Gazetteer_Gazetteer*)__Pyx_GetVtable(__pyx_ptype_22NamedEntityRecognition_9Gazetteer_Gazetteer->tp_dict); if (unlikely(!__pyx_vtabptr_22NamedEntityRecognition_9Gazetteer_Gazetteer)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("NamedEntityRecognition.Slot"); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_22NamedEntityRecognition_4Slot_Slot = __Pyx_ImportType(__pyx_t_1, "NamedEntityRecognition.Slot", "Slot", sizeof(struct __pyx_obj_22NamedEntityRecognition_4Slot_Slot), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_22NamedEntityRecognition_4Slot_Slot) __PYX_ERR(10, 1, __pyx_L1_error)
  __pyx_vtabptr_22NamedEntityRecognition_4Slot_Slot = (struct __pyx_vtabstruct_22NamedEntityRecognition_4Slot_Slot*)__Pyx_GetVtable(__pyx_ptype_22NamedEntityRecognition_4Slot_Slot->tp_dict); if (unlikely(!__pyx_vtabptr_22NamedEntityRecognition_4Slot_Slot)) __PYX_ERR(10, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("PropBank.Argument"); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_8PropBank_8Argument_Argument = __Pyx_ImportType(__pyx_t_1, "PropBank.Argument", "Argument", sizeof(struct __pyx_obj_8PropBank_8Argument_Argument), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_8PropBank_8Argument_Argument) __PYX_ERR(11, 1, __pyx_L1_error)
  __pyx_vtabptr_8PropBank_8Argument_Argument = (struct __pyx_vtabstruct_8PropBank_8Argument_Argument*)__Pyx_GetVtable(__pyx_ptype_8PropBank_8Argument_Argument->tp_dict); if (unlikely(!__pyx_vtabptr_8PropBank_8Argument_Argument)) __PYX_ERR(11, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.State"); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_5State_State = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.State", "State", sizeof(struct __pyx_obj_21MorphologicalAnalysis_5State_State), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_5State_State) __PYX_ERR(12, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_5State_State = (struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_5State_State->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_5State_State)) __PYX_ERR(12, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FsmParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FsmParse", "FsmParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse) __PYX_ERR(13, 5, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse)) __PYX_ERR(13, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initAnnotatedWord(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initAnnotatedWord(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_AnnotatedWord(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_AnnotatedWord(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_AnnotatedWord(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'AnnotatedWord' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_AnnotatedWord(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("AnnotatedWord", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_AnnotatedSentence__AnnotatedWord) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "AnnotatedSentence.AnnotatedWord")) {
      if (unlikely(PyDict_SetItemString(modules, "AnnotatedSentence.AnnotatedWord", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "AnnotatedSentence/AnnotatedWord.pyx":1
 * import re             # <<<<<<<<<<<<<<
 * from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_re, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":2
 * import re
 * from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag             # <<<<<<<<<<<<<<
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 * from SentiNet.PolarityType import PolarityType
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_MorphologicalTag);
  __Pyx_GIVEREF(__pyx_n_s_MorphologicalTag);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_MorphologicalTag);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_MorphologicalAnalysis_Morphologi, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MorphologicalTag, __pyx_t_1) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":4
 * from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 * from SentiNet.PolarityType import PolarityType             # <<<<<<<<<<<<<<
 * from AnnotatedSentence.ViewLayerType import ViewLayerType
 * from Corpus.WordFormat import WordFormat
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_PolarityType);
  __Pyx_GIVEREF(__pyx_n_s_PolarityType);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PolarityType);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_SentiNet_PolarityType, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_PolarityType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PolarityType, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":5
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 * from SentiNet.PolarityType import PolarityType
 * from AnnotatedSentence.ViewLayerType import ViewLayerType             # <<<<<<<<<<<<<<
 * from Corpus.WordFormat import WordFormat
 * from NamedEntityRecognition.NamedEntityType import NamedEntityType
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_ViewLayerType);
  __Pyx_GIVEREF(__pyx_n_s_ViewLayerType);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_ViewLayerType);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_AnnotatedSentence_ViewLayerType, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_ViewLayerType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ViewLayerType, __pyx_t_1) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":6
 * from SentiNet.PolarityType import PolarityType
 * from AnnotatedSentence.ViewLayerType import ViewLayerType
 * from Corpus.WordFormat import WordFormat             # <<<<<<<<<<<<<<
 * from NamedEntityRecognition.NamedEntityType import NamedEntityType
 * from AnnotatedSentence.Language import Language
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_WordFormat);
  __Pyx_GIVEREF(__pyx_n_s_WordFormat);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_WordFormat);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_Corpus_WordFormat, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_WordFormat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WordFormat, __pyx_t_2) < 0) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":7
 * from AnnotatedSentence.ViewLayerType import ViewLayerType
 * from Corpus.WordFormat import WordFormat
 * from NamedEntityRecognition.NamedEntityType import NamedEntityType             # <<<<<<<<<<<<<<
 * from AnnotatedSentence.Language import Language
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_NamedEntityType);
  __Pyx_GIVEREF(__pyx_n_s_NamedEntityType);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_NamedEntityType);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_NamedEntityRecognition_NamedEnti, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_NamedEntityType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NamedEntityType, __pyx_t_1) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":8
 * from Corpus.WordFormat import WordFormat
 * from NamedEntityRecognition.NamedEntityType import NamedEntityType
 * from AnnotatedSentence.Language import Language             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_Language);
  __Pyx_GIVEREF(__pyx_n_s_Language);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Language);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_AnnotatedSentence_Language, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Language); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Language, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":556
 * 
 *     @staticmethod
 *     def getLanguageFromString(languageString: str) -> Language:             # <<<<<<<<<<<<<<
 *         """
 *         Converts a language string to language.
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_17AnnotatedSentence_13AnnotatedWord_13AnnotatedWord_65getLanguageFromString, NULL, __pyx_n_s_AnnotatedSentence_AnnotatedWord_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord->tp_dict, __pyx_n_s_getLanguageFromString, __pyx_t_1) < 0) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord);

  /* "AnnotatedSentence/AnnotatedWord.pyx":555
 *         return self.__language
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def getLanguageFromString(languageString: str) -> Language:
 *         """
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord, __pyx_n_s_getLanguageFromString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord->tp_dict, __pyx_n_s_getLanguageFromString, __pyx_t_2) < 0) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_17AnnotatedSentence_13AnnotatedWord_AnnotatedWord);

  /* "(tree fragment)":1
 * def __pyx_unpickle_AnnotatedWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_17AnnotatedSentence_13AnnotatedWord_1__pyx_unpickle_AnnotatedWord, NULL, __pyx_n_s_AnnotatedSentence_AnnotatedWord_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_AnnotatedWord, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "AnnotatedSentence/AnnotatedWord.pyx":1
 * import re             # <<<<<<<<<<<<<<
 * from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init AnnotatedSentence.AnnotatedWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init AnnotatedSentence.AnnotatedWord");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if (PY_VERSION_HEX >= 0x030600B1 && flag == METH_FASTCALL) {
            if (PY_VERSION_HEX >= 0x030700A0) {
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            } else {
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            }
        } else if (PY_VERSION_HEX >= 0x030700A0 && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* PyUnicode_Substring */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
    if (unlikely(__Pyx_PyUnicode_READY(text) == -1)) return NULL;
    length = __Pyx_PyUnicode_GET_LENGTH(text);
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    if (stop <= start)
        return __Pyx_NewRef(__pyx_empty_unicode);
#if CYTHON_PEP393_ENABLED
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#else
    return PyUnicode_FromUnicode(PyUnicode_AS_UNICODE(text)+start, stop-start);
#endif
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_dealloc != current_tp_dealloc)
        type = type->tp_base;
    while (type && type->tp_dealloc == current_tp_dealloc)
        type = type->tp_base;
    if (type)
        type->tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_traverse != current_tp_traverse)
        type = type->tp_base;
    while (type && type->tp_traverse == current_tp_traverse)
        type = type->tp_base;
    if (type && type->tp_traverse)
        return type->tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_clear != current_tp_clear)
        type = type->tp_base;
    while (type && type->tp_clear == current_tp_clear)
        type = type->tp_base;
    if (type && type->tp_clear)
        type->tp_clear(obj);
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* GetNameInClass */
static PyObject *__Pyx_GetGlobalNameAfterAttributeLookup(PyObject *name) {
    PyObject *result;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    result = __Pyx_PyObject_GetAttrStr(nmspace, name);
    if (!result) {
        result = __Pyx_GetGlobalNameAfterAttributeLookup(name);
    }
    return result;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
